<?php
namespace Visarzo\Helper\Elementor\Widgets;

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Core\Schemes;
use Visarzo\Helper\Elementor\Settings\Header;

class Blog_Selector extends Widget_Base {



	public function get_name() {
		return 'visarzo_blog_selector';
	}

	public function get_title() {
		return esc_html__( 'Visarzo Blog Seleector', 'visarzo-core' );
	}

	public function get_icon() {
		return 'fa fa-object-ungroup';
	}

	public function get_categories() {
		return array( 'visarzo' );
	}

	private function get_posts_custom() {
		$options = array();

		$args = array(
			'post_type'   => array( 'post' ),
			'post_status' => 'publish',
			'showposts'   => -1,
		);

		$query = new \WP_Query( $args );

		// The Loop
		if ( $query->have_posts() ) {

			while ( $query->have_posts() ) {
				$query->the_post();
				$options[ get_the_ID() ] = get_the_title();
			}
		}

		wp_reset_postdata();

		return $options;
	}


	protected function register_controls() {

		$this->start_controls_section(
			'section_blogs',
			array(
				'label' => esc_html__( 'Blogs', 'visarzo-core' ),
			)
		);

		$this->add_control(
			'select_layout',
			array(
				'label'   => esc_html__( 'Select Layout', 'visarzo-core' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'style_1' => esc_html__( 'Style 1', 'visarzo-core' ),
					'style_2' => esc_html__( 'Style 2', 'visarzo-core' ),
					'style_3' => esc_html__( 'Style 3', 'visarzo-core' ),

				),
				'default' => esc_html__( 'style_1', 'visarzo-core' ),
			)
		);
		$this->add_control(
			'html_tag',
			array(
				'label'   => esc_html__( 'Html Tag', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'h1'   => esc_html__( 'H1', 'visarzo-core' ),
					'h2'   => esc_html__( 'H2', 'visarzo-core' ),
					'h3'   => esc_html__( 'H3', 'visarzo-core' ),
					'h4'   => esc_html__( 'H4', 'visarzo-core' ),
					'h5'   => esc_html__( 'H5', 'visarzo-core' ),
					'h6'   => esc_html__( 'H6', 'visarzo-core' ),
					'div'  => esc_html__( 'div', 'visarzo-core' ),
					'span' => esc_html__( 'span', 'visarzo-core' ),
					'p'    => esc_html__( 'p', 'visarzo-core' ),
				),
				'default' => 'h2',

			)
		);

		$this->add_control(
			'tagline',
			array(
				'label'       => esc_html__( 'Tagline', 'visarzo-core' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => esc_html__( 'HOW WE HELP CLIENTS', 'visarzo-core' ),
			)
		);

		$this->add_control(
			'title',
			array(
				'label'       => esc_html__( 'Title', 'visarzo-core' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::TEXTAREA,
				'default'     => 'World Immigration News & Updates',
			)
		);
		$this->add_control(
			'content',
			array(
				'label' => esc_html__( 'Content', 'visarzo-core' ),
				'type'  => \Elementor\Controls_Manager::TEXTAREA,
			)
		);
		$this->end_controls_section();
		$this->start_controls_section(
			'blog_item',
			array(
				'label' => esc_html__( 'ITEM', 'visarzo-core' ),
			)
		);
		Header::visarzo_coloumn_control( $this, 6, 2 );
		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'post_name',
			array(
				'label'   => esc_html__( 'Select Posts', 'visarzo-core' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => $this->get_posts_custom(),
			)
		);

		$repeater->add_control(
			'show_external_name',
			array(
				'label'   => esc_html__( 'Show external name for this post', 'visarzo-core' ),
				'type'    => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'false',
			)
		);

		$repeater->add_control(
			'external_name',
			array(
				'label'       => esc_html__( 'Name of the post', 'visarzo-core' ),
				'type'        => \Elementor\Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'External name of the post', 'visarzo-core' ),
				'condition'   => array(
					'show_external_name' => 'yes',
				),
			)
		);

		$repeater->add_control(
			'external_image',
			array(
				'label'   => esc_html__( 'Show external image for this post', 'visarzo-core' ),
				'type'    => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'false',
			)
		);

		$repeater->add_control(
			'post_image',
			array(
				'label'     => esc_html__( 'Post image', 'visarzo-core' ),
				'type'      => \Elementor\Controls_Manager::MEDIA,
				'default'   => array(
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				),
				'condition' => array(
					'external_image' => 'yes',
				),
			)
		);
		Header::visarzo_get_wow_animation_control( $repeater );

		$this->add_control(
			'items1',
			array(
				'label'   => esc_html__( 'Repeater List', 'visarzo-core' ),
				'type'    => \Elementor\Controls_Manager::REPEATER,
				'fields'  => $repeater->get_controls(),
				'default' => array(
					array(
						'list_title'   => esc_html__( 'Title #1', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
					array(
						'list_title'   => esc_html__( 'Title #2', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
				),
			)
		);

		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings();

		$select_layout = $settings['select_layout'];
		$tagline       = $settings['tagline'];
		$title         = $settings['title'];
		$html_tag      = $settings['html_tag'];
		$content       = $settings['content'];

		?>


		
		<section class="news-section">
			<div class="auto-container">
				<div class="top-inner">
					<div class="row clearfix">
						<div class="col-lg-5 col-md-12 col-sm-12 title-column">
							<div class="sec-title">
								<p><?php echo $tagline; ?></p>
								<<?php echo $html_tag; ?> class="heading"><?php echo $title; ?></<?php echo $html_tag; ?>>
								<div class="dotted-box">
									<span class="dotted"></span>
									<span class="dotted"></span>
									<span class="dotted"></span>
								</div>
							</div>
						</div>
						<div class="col-lg-7 col-md-12 col-sm-12 text-column">
							<div class="text">
								<p><?php echo $content; ?></p>
							</div>
						</div>
					</div>
				</div>
				<div class="row clearfix">
				<?php
				foreach ( $settings['items1'] as $item ) {

					$external_image     = $item['external_image'];
					$show_external_name = $item['show_external_name'];

					$args  = array(
						'p'         => $item['post_name'],
						'post_type' => 'post',
					);
					$query = new \WP_Query( $args );
					$count = 1;
					if ( $query->have_posts() ) {
						while ( $query->have_posts() ) {
							$query->the_post();
							$tags            = wp_get_post_categories( get_the_ID() );
							$image           = get_post_meta( get_the_ID(), 'visarzo_metabox_content_image', true );
							$animation_class = $item['animation_class'];
							$duration_time   = $item['duration_time'];
							$delay_time      = $item['delay_time'];

							?>
					<div class="<?php echo Header::visarzo_coloumn( $this, $settings ); ?> col-md-6 col-sm-12 news-block">
						<div class="news-block-one wow <?php echo $animation_class; ?> animated animated" data-wow-delay="<?php echo $delay_time; ?>" data-wow-duration="<?php echo $duration_time; ?>">
							<div class="inner-box">
								<figure class="image-box">
									<a href="<?php echo esc_url( get_permalink() ); ?>">
										<?php
										if ( $external_image == 'yes' ) {
											$image_url = ( $item['post_image']['id'] != '' ) ? wp_get_attachment_image_url( $item['post_image']['id'], 'full' ) : $item['post_image']['url'];
											?>
								<img src="<?php echo esc_url( $image_url ); ?>" alt="<?php esc_attr_e( 'Awesome Image', 'visarzo-core' ); ?>">
											<?php
										} elseif ( isset( $image ) && $image != '' ) {
											 $ad_im = wp_get_attachment_image_url( $image, 'full' );
											?>
								<img src="<?php echo esc_url( $ad_im ); ?>" alt="<?php esc_attr_e( 'Awesome Image', 'visarzo-core' ); ?>">
											<?php
										} else {
											  the_post_thumbnail();
										}
										?>
									</a>
								</figure>
								<div class="lower-content">
									<div class="post-date"><h2><?php the_date( 'd' ); ?></h2><span><?php echo get_the_date( 'M' ); ?></span></div>
									<h3><a href="<?php echo esc_url( get_permalink() ); ?>">
									<?php
									if ( $show_external_name == 'yes' ) {
										echo $item['external_name'];
									} else {
										the_title();
									}
									?>
									</a></h3>
									<ul class="post-info clearfix">
										<li><a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php esc_attr_e( 'By', 'visarzo-core' ); ?> <?php echo get_the_author(); ?></a></li>
										<li>
										<?php
										foreach ( $tags as $tag ) {
											$cats     = get_the_category_by_ID( $tag );
											$cat_link = get_category_link( $tag );
											?>
													<a href="<?php echo esc_url( $cat_link ); ?>"><?php echo $cats; ?></a>
												<?php
										}
										?>
										</li>
									</ul>
									<div class="link"><a href="<?php echo esc_url( get_permalink() ); ?>"><?php esc_html_e( 'Learn More', 'visarzo-core' ); ?><i class="flaticon-send"></i></a></div>
								</div>
							</div>
						</div>
					</div>
							<?php
						}
					}
						wp_reset_postdata();

				}
				?>

				</div>
			</div>
		</section>
			<?php

	}

	protected function content_template() {

	}
}
