<?php
namespace Visarzo\Helper\Elementor\Widgets;

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use \Elementor\Repeater;
use Elementor\Core\Schemes;
class Download_Widget extends Widget_Base {



	public function get_name() {
		return 'download_widget';
	}

	public function get_title() {
		return esc_html__( 'Download Widget', 'visarzo-core' );
	}

	public function get_icon() {
		return 'fa fa-object-ungroup';
	}

	public function get_categories() {
		return array( 'visarzo' );
	}

	protected function register_controls() {

		$this->start_controls_section(
			'general',
			array(
				'label' => esc_html__( 'General', 'visarzo-core' ),
			)
		);

		$this->add_control(
			'download_title',
			array(
				'label'       => esc_html__( 'Download Title', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'Related Downloads', 'visarzo-core' ),
			)
		);
		$this->add_control(
			'html_tag',
			array(
				'label'   => esc_html__( 'Html Tag', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'h1'   => esc_html__( 'H1', 'visarzo-core' ),
					'h2'   => esc_html__( 'H2', 'visarzo-core' ),
					'h3'   => esc_html__( 'H3', 'visarzo-core' ),
					'h4'   => esc_html__( 'H4', 'visarzo-core' ),
					'h5'   => esc_html__( 'H5', 'visarzo-core' ),
					'h6'   => esc_html__( 'H6', 'visarzo-core' ),
					'div'  => esc_html__( 'div', 'visarzo-core' ),
					'span' => esc_html__( 'span', 'visarzo-core' ),
					'p'    => esc_html__( 'p', 'visarzo-core' ),
				),
				'default' => 'h3',

			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'item',
			array(
				'label' => esc_html__( 'ITEM', 'visarzo-core' ),
			)
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'item_title',
			array(
				'label'       => esc_html__( 'Title', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
			)
		);

		$repeater->add_control(
			'item_date_title',
			array(
				'label'       => esc_html__( 'Date Title', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'Last Update: 23 May 2020', 'visarzo-core' ),
			)
		);

		$repeater->add_control(
			'item_download_link',
			array(
				'label'         => esc_html__( 'Download Link', 'visarzo-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => esc_html__( 'https://your-link.com', 'visarzo-core' ),
				'show_external' => true,
				'default'       => array(
					'url'         => '',
					'is_external' => true,
					'nofollow'    => true,
				),

			)
		);

		$this->add_control(
			'items',
			array(
				'label'   => esc_html__( 'Repeater List', 'visarzo-core' ),
				'type'    => Controls_Manager::REPEATER,
				'fields'  => $repeater->get_controls(),
				'default' => array(
					array(
						'list_title'   => esc_html__( 'Title #1', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
					array(
						'list_title'   => esc_html__( 'Title #2', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
				),
			)
		);

		$this->end_controls_section();
		$this->start_controls_section(
			'text_style_section',
			array(
				'label' => __( 'Text Style', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'content_typography',
				'label'    => __( 'Typography', 'visarzo-core' ),
				'scheme'   => Schemes\Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .download',
			)
		);
		$this->end_controls_section();
	}
	protected function render() {
		$settings       = $this->get_settings_for_display();
		$download_title = $settings['download_title'];
		$html_tag       = $settings['html_tag'];
		?> <div class="sidebar-widget sidebar-download">
			<div class="widget-title">
			<<?php echo $html_tag; ?> class="download"><?php echo $download_title; ?></<?php echo $html_tag; ?>>
				<div class="dotted-box">
					<span class="dotted"></span>
					<span class="dotted"></span>
					<span class="dotted"></span>
				</div>
			</div>
			<div class="widget-content">
				<ul class="download-list clearfix">
		<?php
		$i = 1;
		foreach ( $settings['items'] as $item ) {
			$item_title         = $item['item_title'];
			$item_date_title    = $item['item_date_title'];
			$item_download_link = $item['item_download_link']['url'];

			$item_page_link          = $item['item_download_link'];
			$item_page_link_target   = $item['item_download_link']['is_external'] ? ' target="_blank"' : '';
			$item_page_link_nofollow = $item['item_download_link']['nofollow'] ? ' rel="nofollow"' : '';
			?>
					 <li>
							<i class="flaticon-files"></i>
							<h4><a href="<?php echo esc_url( $item_page_link['url'] ); ?>" <?php echo $item_page_link_target . ' ' . $item_page_link_nofollow; ?>><?php echo $item_title; ?></a></h4>
							<span><?php echo $item_date_title; ?></span>
</li> <?php } ?>


				</ul>
			</div>
		</div> 
		<?php
	}

	protected function content_templates() {
	}
}
