<?php
namespace Visarzo\Helper\Elementor\Widgets;

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use \Elementor\Repeater;
use Elementor\Core\Schemes;
use Visarzo\Helper\Elementor\Settings\Header;

class Footer_Newsletter extends Widget_Base {








	public function get_name() {
		return 'visarzo_footer_newsletter';
	}

	public function get_title() {
		return esc_html__( 'Footer Newsletter', 'visarzo-core' );
	}

	public function get_icon() {
		return 'fa fa-object-ungroup';
	}

	public function get_categories() {
		return array( 'visarzo' );
	}

	protected function register_controls() {

		$this->start_controls_section(
			'general',
			array(
				'label' => esc_html__( 'General', 'visarzo-core' ),
			)
		);

		$this->add_control(
			'title',
			array(
				'label'       => esc_html__( 'Title', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'Newsletter Signup', 'visarzo-core' ),
			)
		);
		$this->add_control(
			'html_tag',
			array(
				'label'   => esc_html__( 'Html Tag', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'h1'   => esc_html__( 'H1', 'visarzo-core' ),
					'h2'   => esc_html__( 'H2', 'visarzo-core' ),
					'h3'   => esc_html__( 'H3', 'visarzo-core' ),
					'h4'   => esc_html__( 'H4', 'visarzo-core' ),
					'h5'   => esc_html__( 'H5', 'visarzo-core' ),
					'h6'   => esc_html__( 'H6', 'visarzo-core' ),
					'div'  => esc_html__( 'div', 'visarzo-core' ),
					'span' => esc_html__( 'span', 'visarzo-core' ),
					'p'    => esc_html__( 'p', 'visarzo-core' ),
				),
				'default' => 'h3',
			)
		);

		$this->add_control(
			'content',
			array(
				'label'       => esc_html__( 'Content', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'     => __( 'Enter your email address to get latest updates and offers from us. Also some Discount coupons.', 'visarzo-core' ),
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),

			)
		);
		$this->add_control(
			'newsletter_contact_cf7',
			array(
				'label'       => esc_html__( 'Select Contact Form', 'visarzo-core' ),
				'description' => esc_html__( 'Contact form 7 - plugin must be installed and there must be some contact forms made with the contact form 7', 'visarzo-core' ),
				'type'        => Controls_Manager::SELECT2,
				'multiple'    => false,
				'label_block' => 1,
				'options'     => Header::getContactForm7Posts(),
			)
		);

		$this->end_controls_section();
		$this->start_controls_section(
			'text_style_section',
			array(
				'label' => __( 'Text Style', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'content_typography',
				'label'    => __( 'Typography', 'visarzo-core' ),
				'scheme'   => Schemes\Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .newsletter',
			)
		);
		$this->end_controls_section();
	}
	protected function render() {
		$settings = $this->get_settings_for_display();
		$title    = $settings['title'];
		$content  = $settings['content'];
		$html_tag = $settings['html_tag'];
		?>
		<div class="main-footer bg-color-2">
			<div class="footer-top">
				<div class="footer-column">
					<div class="footer-widget newsletter-widget">
						<div class="widget-title">
							<<?php echo $html_tag; ?> class="newsletter"><?php echo $title; ?></<?php echo $html_tag; ?>>
						</div>
						<div class="widget-content">
							<p><?php echo $content; ?></p>
		<?php

		static $v_veriable = 0;

		$settings = $this->get_settings();
		if ( ! empty( $settings['newsletter_contact_cf7'] ) ) {
			echo '<div class="elementor-shortcode visarzocore-newsletter_contact_cf7-' . $v_veriable . '">';
			echo do_shortcode( '[contact-form-7 id="' . $settings['newsletter_contact_cf7'] . '"]' );
			echo '</div>';
		}

		if ( ! empty( $settings['newsletter_contact_cf7_redirect_page'] ) || ! empty( $settings['newsletter_contact_cf7_redirect_external'] ) ) {
			?>
								<script>
									var theform = document.querySelector('.visarzocore-newsletter_contact_cf7-<?php echo $v_veriable; ?>');
									theform.addEventListener('wpnewsletter_contact_cf7mailsent', function(event) {
										location = ' 
			<?php
			if ( ! empty( $settings['cnewsletter_contact_cf7_redirect_external'] ) ) {
				echo $settings['newsletter_contact_cf7_redirect_external'];
			} else {
				echo get_permalink( $settings['newsletter_contact_cf7_redirect_page'] );
			}
			?>
											';
									}, false);
								</script>

			<?php
			$v_veriable++;
		}

		?>
						</div>
					</div>
				</div>
			</div>
		</div>
		<?php
	}

	protected function content_templates() {
	}
}
