<?php
namespace Visarzo\Helper\Elementor\Widgets;

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Core\Schemes;
use Visarzo\Helper\Elementor\Settings\Header;

class Inquire_Contact extends Widget_Base {


	public function get_name() {
		return 'visarzo_inquiry';
	}

	public function get_title() {
		return esc_html__( 'Visarzo Inquiry', 'visarzo-core' );
	}

	public function get_icon() {
		return 'fa fa-object-ungroup';
	}

	public function get_categories() {
		return array( 'visarzo' );
	}

	protected function register_controls() {

		$this->start_controls_section(
			'general',
			array(
				'label' => esc_html__( 'General', 'visarzo-core' ),
			)
		);

		$this->add_control(
			'tagline',
			array(
				'label'   => esc_html__( 'Tagline', 'visarzo-core' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __( 'Get Free Assessment Today!', 'visarzo-core' ),
			)
		);

		$this->add_control(
			'title',
			array(
				'label'       => esc_html__( 'Title', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),

			)
		);

		$this->add_control(
			'html_tag',
			array(
				'label'   => esc_html__( 'Html Tag', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'h1'   => esc_html__( 'H1', 'visarzo-core' ),
					'h2'   => esc_html__( 'H2', 'visarzo-core' ),
					'h3'   => esc_html__( 'H3', 'visarzo-core' ),
					'h4'   => esc_html__( 'H4', 'visarzo-core' ),
					'h5'   => esc_html__( 'H5', 'visarzo-core' ),
					'h6'   => esc_html__( 'H6', 'visarzo-core' ),
					'div'  => esc_html__( 'div', 'visarzo-core' ),
					'span' => esc_html__( 'span', 'visarzo-core' ),
					'p'    => esc_html__( 'p', 'visarzo-core' ),
				),
				'default' => 'h2',

			)
		);

		$this->add_control(
			'rating_title',
			array(
				'label'   => esc_html__( 'Rating Title', 'visarzo-core' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __( 'Customer Ratings', 'visarzo-core' ),
			)
		);
		$this->add_control(
			'rating',
			array(
				'label' => esc_html__( 'Rating', 'visarzo-core' ),
				'type'  => Controls_Manager::TEXTAREA,
			)
		);

		$this->add_control(
			'total_rating',
			array(
				'label'       => esc_html__( 'Total Rating', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
			)
		);

		$this->add_control(
			'out_of',
			array(
				'label'       => esc_html__( 'Out Of', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
			)
		);

		$this->add_control(
			'rating_text',
			array(
				'label'       => esc_html__( 'Rating Text', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),

			)
		);

		$this->add_control(
			'background_image',
			array(
				'label'   => esc_html__( 'Background Image', 'visarzo-core' ),
				'type'    => Controls_Manager::MEDIA,
				'default' => array(
					'url' => Utils::get_placeholder_image_src(),
				),

			)
		);
		$this->add_control(
			'inquire_contact_cf7',
			array(
				'label'       => esc_html__( 'Select Contact Form', 'visarzo-core' ),
				'description' => esc_html__( 'Contact form 7 - plugin must be installed and there must be some contact forms made with the contact form 7', 'visarzo-core' ),
				'type'        => Controls_Manager::SELECT2,
				'multiple'    => false,
				'label_block' => 1,
				'options'     => Header::getContactForm7Posts(),
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'item',
			array(
				'label' => esc_html__( 'ITEM', 'visarzo-core' ),
			)
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'item_title',
			array(
				'label'       => esc_html__( 'Title', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
			)
		);

		$repeater->add_control(
			'item_icon',
			array(
				'label'       => esc_html__( 'Icon', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::ICONS,
			)
		);

		$repeater->add_control(
			'item_tagline',
			array(
				'label'       => esc_html__( 'Tagline', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,

			)
		);

		$repeater->add_control(
			'item_contact_title',
			array(
				'label'       => esc_html__( 'Contact Title', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),

			)
		);

		$repeater->add_control(
			'item_contact_link',
			array(
				'label'         => esc_html__( 'Contact Link', 'visarzo-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => esc_html__( 'https://your-link.com', 'visarzo-core' ),
				'show_external' => true,
				'default'       => array(
					'url'         => '#',
					'is_external' => true,
					'nofollow'    => true,
				),

			)
		);

		$this->add_control(
			'items',
			array(
				'label'   => esc_html__( 'Repeater List', 'visarzo-core' ),
				'type'    => Controls_Manager::REPEATER,
				'fields'  => $repeater->get_controls(),
				'default' => array(
					array(
						'list_title'   => esc_html__( 'Title #1', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
					array(
						'list_title'   => esc_html__( 'Title #2', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
				),
			)
		);

		$this->end_controls_section();
		$this->start_controls_section(
			'style_section',
			array(
				'label' => __( 'Color', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->start_controls_tabs( 'tabs_button_style' );
		$this->start_controls_tab(
			'tab_button_normal',
			array(
				'label' => __( 'Normal', 'elementor' ),
			)
		);
		$this->add_control(
			'underline_color',
			array(
				'label'     => __( 'Underline Color', 'bisarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .sec-title:before' => 'background: {{VALUE}} !important',
					'{{WRAPPER}} .sec-title .dotted-box .dotted' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tab_button_hover',
			array(
				'label' => __( 'Hover', 'elementor' ),
			)
		);
		$this->add_control(
			'icon_hover_color',
			array(
				'label'     => __( 'Icon Color', 'bisarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} #content_block_2 .content-box .inner-box .single-item:hover .icon-box' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		$this->start_controls_section(
			'text_style_section',
			array(
				'label' => __( 'Text Style', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'content_typography',
				'label'    => __( 'Typography', 'visarzo-core' ),
				'scheme'   => Schemes\Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .inquire',
			)
		);
		$this->end_controls_section();
	}
	protected function render() {
		$settings         = $this->get_settings_for_display();
		$tagline          = $settings['tagline'];
		$title            = $settings['title'];
		$html_tag         = $settings['html_tag'];
		$rating_title     = $settings['rating_title'];
		$total_rating     = $settings['total_rating'];
		$out_of           = $settings['out_of'];
		$rating_text      = $settings['rating_text'];
		$rating           = $settings['rating'];
		$background_image = ( $settings['background_image']['id'] != '' ) ? wp_get_attachment_image_url( $settings['background_image']['id'], 'full' ) : $settings['background_image']['url'];

		?>
		<!-- inquiry-section -->
		<section class="inquiry-section bg-color-1">
			<div class="pattern-layer" style="background-image: url(<?php echo esc_url( $background_image ); ?>);"></div>
			<div class="auto-container">
				<div class="row align-items-center clearfix">
					<div class="col-lg-6 col-md-12 col-sm-12 inner-column">
						<div class="inner-box">
							<h4><?php echo $tagline; ?></h4>
							<<?php echo $html_tag; ?> class="inquire"><?php echo $title; ?></<?php echo $html_tag; ?>>
							<?php

							static $v_veriable = 0;

							$settings = $this->get_settings();
							if ( ! empty( $settings['inquire_contact_cf7'] ) ) {
								echo '<div class="elementor-shortcode visarzocore-inquire_contact_cf7-' . $v_veriable . '">';
								echo do_shortcode( '[contact-form-7 id="' . $settings['inquire_contact_cf7'] . '"]' );
								echo '</div>';
							}

							if ( ! empty( $settings['inquire_contact_cf7_redirect_page'] ) || ! empty( $settings['inquire_contact_cf7_redirect_external'] ) ) {
								?>
								<script>
									var theform = document.querySelector('.visarzocore-inquire_contact_cf7-<?php echo $v_veriable; ?>');
									theform.addEventListener('wpinquire_contact_cf7mailsent', function(event) {
										location = ' 
										<?php
										if ( ! empty( $settings['cinquire_contact_cf7_redirect_external'] ) ) {
											echo $settings['inquire_contact_cf7_redirect_external'];
										} else {
											echo get_permalink( $settings['inquire_contact_cf7_redirect_page'] );
										}
										?>
										';
									}, false);
								</script>

								<?php
								$v_veriable++;
							}

							?>

						</div>
					</div>
					<div class="col-lg-6 col-md-12 col-sm-12 content-column">
						<div class="content-box">
							<h3><?php echo $rating_title; ?></h3>
							<ul class="rating clearfix">
								<?php echo $rating; ?>
							</ul>
							
							<h2><?php echo $total_rating; ?><?php if($total_rating != '' && $out_of != ''){ ?> / <?php } ?><?php echo $out_of; ?></h2>
							
							<span><?php echo $rating_text; ?></span>
							<ul class="info-box clearfix">
								<?php
								$i = 1;
								foreach ( $settings['items'] as $item ) {
									$item_title            = $item['item_title'];
									$item_icon             = $item['item_icon'];
									$item_tagline          = $item['item_tagline'];
									$item_contact_title    = $item['item_contact_title'];
									$item_contact_link     = $item['item_contact_link'];
									$item_contact_target   = $item['item_contact_link']['is_external'] ? ' target="_blank"' : '';
									$item_contact_nofollow = $item['item_contact_link']['nofollow'] ? ' rel="nofollow"' : '';
									?>
								 <li>
										<?php \Elementor\Icons_Manager::render_icon( ( $item_icon ), array( 'aria-hidden' => 'true' ) ); ?>
										<p><?php echo $item_tagline; ?></p>
										<h3><a href="<?php echo esc_url( $item_contact_link['url'] ); ?>" <?php echo $item_contact_target . ' ' . $item_contact_nofollow; ?>><?php echo $item_contact_title; ?></a></h3>
									</li> <?php } ?>

							</ul>
						</div>
					</div>
				</div>
			</div>
		</section>
		<!-- inquiry-section end --> 
		<?php
	}

	protected function content_templates() {
	}
}
