<?php
namespace Visarzo\Helper\Elementor\Widgets;

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use \Elementor\Repeater;
use Visarzo\Helper\Elementor\Settings\Header;
use Elementor\Core\Schemes;

class Sidebar_Recent_Post extends Widget_Base {




	public function get_name() {
		return 'visarzo_recent_blog';
	}

	public function get_title() {
		return esc_html__( 'Visarzo Recent Blog', 'visarzo-core' );
	}

	public function get_icon() {
		return 'eicon-post';
	}

	public function get_categories() {
		return array( 'visarzo' );
	}
	private function get_posts_custom_two() {
		$options = array();

		$args = array(
			'post_type'   => array( 'post' ),
			'post_status' => 'publish',
			'showposts'   => -1,
		);

		$query = new \WP_Query( $args );

		// The Loop
		if ( $query->have_posts() ) {

			while ( $query->have_posts() ) {
				$query->the_post();
				$options[ get_the_ID() ] = get_the_title();
			}
		}

		wp_reset_postdata();

		return $options;
	}

	protected function register_controls() {
		$this->start_controls_section(
			'general',
			array(
				'label' => esc_html__( 'General', 'visarzo-core' ),
			)
		);

		$this->add_control(
			'title',
			array(
				'label'       => esc_html__( 'Title', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'What’s Happening', 'visarzo-core' ),
			)
		);

		$this->add_control(
			'html_tag',
			array(
				'label'   => esc_html__( 'Html Tag', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'h1'   => esc_html__( 'H1', 'visarzo-core' ),
					'h2'   => esc_html__( 'H2', 'visarzo-core' ),
					'h3'   => esc_html__( 'H3', 'visarzo-core' ),
					'h4'   => esc_html__( 'H4', 'visarzo-core' ),
					'h5'   => esc_html__( 'H5', 'visarzo-core' ),
					'h6'   => esc_html__( 'H6', 'visarzo-core' ),
					'div'  => esc_html__( 'div', 'visarzo-core' ),
					'span' => esc_html__( 'span', 'visarzo-core' ),
					'p'    => esc_html__( 'p', 'visarzo-core' ),
				),
				'default' => 'h2',

			)
		);
		$this->end_controls_section();
		$this->start_controls_section(
			'blog_item',
			array(
				'label' => esc_html__( 'ITEM', 'visarzo-core' ),
			)
		);
		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'post_name',
			array(
				'label'   => esc_html__( 'Select Posts', 'visarzo-core' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => $this->get_posts_custom_two(),
			)
		);

		$repeater->add_control(
			'show_external_name',
			array(
				'label'   => esc_html__( 'Show external name for this post', 'visarzo-core' ),
				'type'    => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'false',
			)
		);

		$repeater->add_control(
			'external_name',
			array(
				'label'       => esc_html__( 'Name of the post', 'visarzo-core' ),
				'type'        => \Elementor\Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'External name of the post', 'visarzo-core' ),
				'condition'   => array(
					'show_external_name' => 'yes',
				),
			)
		);

		$repeater->add_control(
			'external_image',
			array(
				'label'   => esc_html__( 'Show external image for this post', 'visarzo-core' ),
				'type'    => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'false',
			)
		);

		$repeater->add_control(
			'post_image',
			array(
				'label'     => esc_html__( 'Post image', 'visarzo-core' ),
				'type'      => \Elementor\Controls_Manager::MEDIA,
				'default'   => array(
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				),
				'condition' => array(
					'external_image' => 'yes',
				),
			)
		);

		$this->add_control(
			'items1',
			array(
				'label'   => esc_html__( 'Repeater List', 'visarzo-core' ),
				'type'    => \Elementor\Controls_Manager::REPEATER,
				'fields'  => $repeater->get_controls(),
				'default' => array(
					array(
						'list_title'   => esc_html__( 'Title #1', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
					array(
						'list_title'   => esc_html__( 'Title #2', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
				),
			)
		);

		$this->end_controls_section();
		$this->start_controls_section(
			'text_style_section',
			array(
				'label' => __( 'Text Style', 'visarzo-core-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'content_typography',
				'label'    => __( 'Typography', 'visarzo-core-core' ),
				'scheme'   => Schemes\Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .recent_heading',
			)
		);
		$this->end_controls_section();
	}
	protected function render() {
		$settings = $this->get_settings_for_display();
		$title    = $settings['title'];
		$html_tag = $settings['html_tag'];

		?>
			<div class="sidebar-widget sidebar-post">
				<div class="widget-title">
				<<?php echo $html_tag; ?> class="recent_heading"><?php echo $title; ?></<?php echo $html_tag; ?>>
					<div class="dotted-box">
						<span class="dotted"></span>
						<span class="dotted"></span>
						<span class="dotted"></span>
					</div>
				</div>
				<div class="post-inner">
				<?php
				foreach ( $settings['items1'] as $item ) {

					$external_image     = $item['external_image'];
					$show_external_name = $item['show_external_name'];

					$args  = array(
						'p'         => $item['post_name'],
						'post_type' => 'post',
					);
					$query = new \WP_Query( $args );
					$count = 1;
					if ( $query->have_posts() ) {
						while ( $query->have_posts() ) {
							$query->the_post();
							?>
					<div class="post">
							<?php
							if ( $external_image == 'yes' ) :
								$image_url = ( $item['post_image']['id'] != '' ) ? wp_get_attachment_image_url( $item['post_image']['id'], 'full' ) : $item['post_image']['url'];
								?>
								<figure class="post-thumb"><a href="<?php echo esc_url( get_permalink() ); ?>"><img src="<?php echo esc_url( $image_url ); ?>" alt="<?php esc_attr_e( 'recent Image', 'visarzo-core' ); ?>"></a></figure>
								<?php elseif ( has_post_thumbnail() ) : ?>
						<figure class="post-thumb"><a href="<?php echo esc_url( get_permalink() ); ?>"><?php the_post_thumbnail( 'visarzo-recent-post-size' ); ?></a></figure>
								<?php endif; ?>
						<h5><a href="<?php echo esc_url( get_permalink() ); ?>">
							<?php
							if ( $show_external_name == 'yes' ) {
								echo $item['external_name'];
							} else {
								the_title();
							}
							?>
						</a></h5>
						<span class="post-date"><?php visarzo_posted_on(); ?></span>
					</div>
							<?php
						}
					}
						wp_reset_postdata();

				}
				?>
				</div>
			</div>
			<!-- news-style-three end -->
		<?php
	}

	protected function content_templates() {
	}
}
