<?php
namespace Visarzo\Helper\Elementor\Widgets;

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use \Elementor\Repeater;

class Sidebar_Support_Widget extends Widget_Base {


	public function get_name() {
		return 'visarzo_support_widget';
	}

	public function get_title() {
		return esc_html__( 'Visarzo Sidebar Support', 'visarzo-core' );
	}

	public function get_icon() {
		return 'fa fa-object-ungroup';
	}

	public function get_categories() {
		return array( 'visarzo' );
	}

	protected function register_controls() {

		$this->start_controls_section(
			'item',
			array(
				'label' => esc_html__( 'ITEM', 'visarzo-core' ),
			)
		);
		$this->add_control(
			'image',
			array(
				'label'   => esc_html__( 'Image', 'visarzo-core' ),
				'type'    => Controls_Manager::MEDIA,
				'default' => array(
					'url' => Utils::get_placeholder_image_src(),
				),

			)
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'title',
			array(
				'label'       => esc_html__( 'Title', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
			)
		);

		$repeater->add_control(
			'contact',
			array(
				'label'       => esc_html__( 'Contact', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
			)
		);
		$repeater->add_control(
			'item_icon',
			array(
				'label'       => esc_html__( 'Icon', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::ICONS,
			)
		);
		$repeater->add_control(
			'item_contact_link',
			array(
				'label'         => esc_html__( 'Contact Link', 'visarzo-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => esc_html__( 'https://your-link.com', 'visarzo-core' ),
				'show_external' => true,
				'default'       => array(
					'url'         => '#',
					'is_external' => true,
					'nofollow'    => true,
				),

			)
		);

		$this->add_control(
			'items',
			array(
				'label'   => esc_html__( 'Repeater List', 'visarzo-core' ),
				'type'    => Controls_Manager::REPEATER,
				'fields'  => $repeater->get_controls(),
				'default' => array(
					array(
						'list_title'   => esc_html__( 'Title #1', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
					array(
						'list_title'   => esc_html__( 'Title #2', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
				),
			)
		);

		$this->end_controls_section();
	}
	protected function render() {
		$settings = $this->get_settings_for_display();

		$image = ( $settings['image']['id'] != '' ) ? wp_get_attachment_image_url( $settings['image']['id'], 'full' ) : $settings['image']['url'];
		if ( ! empty( $image ) ) {
			$this->add_render_attribute( 'image', 'src', $image );
			$this->add_render_attribute( 'image', 'alt', \Elementor\Control_Media::get_image_alt( $settings['image'] ) );
			$this->add_render_attribute( 'image', 'title', \Elementor\Control_Media::get_image_title( $settings['image'] ) );
			$item_photo_html = \Elementor\Group_Control_Image_Size::get_attachment_image_html( $settings, 'full', 'image' );
		}
		?>
		<div class="sidebar-widget sidebar-support">
			<div class="widget-content">
				<figure class="image-box"><?php echo $item_photo_html; ?></figure>
				<ul class="content-box clearfix">
				<?php
					$i = 1;
				foreach ( $settings['items'] as $item ) {
					$title     = $item['title'];
					$item_icon = $item['item_icon'];
					$contact   = $item['contact'];

					$item_contact_link     = $item['item_contact_link'];
					$item_contact_target   = $item['item_contact_link']['is_external'] ? ' target="_blank"' : '';
					$item_contact_nofollow = $item['item_contact_link']['nofollow'] ? ' rel="nofollow"' : '';
					?>
					<li>
					<?php \Elementor\Icons_Manager::render_icon( ( $item_icon ), array( 'aria-hidden' => 'true' ) ); ?>
						<p><?php echo $title; ?></p>
						<h3><a href="<?php echo esc_url( $item_contact_link['url'] ); ?>" <?php echo $item_contact_target . ' ' . $item_contact_nofollow; ?>><?php echo $contact; ?></a></h3>
					</li>
				<?php } ?>
				</ul>
			</div>
		</div>

		
			
		<?php
	}

	protected function content_templates() {
	}
}
