<?php
namespace Visarzo\Helper\Elementor\Widgets;

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Core\Schemes;

class Slider_Banner extends Widget_Base {


	public function get_name() {
		return 'visarzo_banner';
	}

	public function get_title() {
		return esc_html__( 'Visarzo Banner', 'visarzo-core' );
	}

	public function get_icon() {
		return 'fa fa-object-ungroup';
	}

	public function get_categories() {
		return array( 'visarzo' );
	}

	protected function register_controls() {

		$this->start_controls_section(
			'slider_settings',
			array(
				'label' => esc_html__( 'Slider Settings', 'driving_school' ),
			)
		);
		$this->add_control(
			'loop',
			array(
				'label'        => esc_html__( 'Enable Loop', 'driving_school' ),
				'type'         => Controls_Manager::SWITCHER,
				'return_value' => 'yes',
				'default'      => 'yes',
			)
		);
		$this->add_control(
			'mouseDrag',
			array(
				'label'        => esc_html__( 'Enable mouseDrag', 'driving_school' ),
				'type'         => Controls_Manager::SWITCHER,
				'return_value' => 'yes',
				'default'      => 'yes',
			)
		);
		$this->add_control(
			'autoplay',
			array(
				'label'        => esc_html__( 'Enable Autoplay', 'driving_school' ),
				'type'         => Controls_Manager::SWITCHER,
				'return_value' => 'yes',
				'default'      => 'yes',

			)
		);
		$this->add_control(
			'autoplay_speed',
			array(
				'label'   => esc_html__( 'Autoplay Speed', 'driving_school' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => __( '8000', 'driving_school' ),
			)
		);
		$this->add_control(
			'arrows',
			array(
				'label'        => esc_html__( 'Enable Arrows', 'driving_school' ),
				'type'         => Controls_Manager::SWITCHER,
				'return_value' => 'yes',
				'default'      => 'yes',

			)
		);
		$this->end_controls_section();


		$this->start_controls_section(
			'item',
			array(
				'label' => esc_html__( 'ITEM', 'visarzo-core' ),
			)
		);
		$this->add_control(
			'slider_style',
			array(
				'label'   => esc_html__( 'Banner Slider Designs', 'visarzo-core' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'default' => 'style_1',
				'options' => array(
					'style_1' => esc_html__( 'Style 1', 'visarzo-core' ),
					'style_2' => esc_html__( 'Style 2', 'visarzo-core' ),
				),
			)
		);

		$repeater = new Repeater();
		$repeater->add_control(
			'item_slider_image',
			array(
				'label'   => esc_html__( 'Slider Image', 'fionca' ),
				'type'    => Controls_Manager::MEDIA,
				'default' => array(
					'url' => Utils::get_placeholder_image_src(),
				),

			)
		);

		$repeater->add_control(
			'item_tagline',
			array(
				'label'       => esc_html__( 'Tagline', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'Effective Immigration Solution', 'visarzo-core' ),
			)
		);

		$repeater->add_control(
			'item_title',
			array(
				'label'       => esc_html__( 'Title', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXTAREA,
				'default'     => __( 'Our Simple Approach To Immigration Process', 'visarzo-core' ),
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),

			)
		);
		$repeater->add_control(
			'section_style',
			array(
				'label'   => esc_html__( 'Banner Style', 'visarzo-core' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'default' => 'style_1',
				'options' => array(
					'style_1' => esc_html__( 'One', 'visarzo-core' ),
					'style_2' => esc_html__( 'Two', 'visarzo-core' ),
				),
			)
		);

		$repeater->add_control(
			'item_html_tag',
			array(
				'label'   => esc_html__( 'Html Tag', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'h1'   => esc_html__( 'H1', 'visarzo-core' ),
					'h2'   => esc_html__( 'H2', 'visarzo-core' ),
					'h3'   => esc_html__( 'H3', 'visarzo-core' ),
					'h4'   => esc_html__( 'H4', 'visarzo-core' ),
					'h5'   => esc_html__( 'H5', 'visarzo-core' ),
					'h6'   => esc_html__( 'H6', 'visarzo-core' ),
					'div'  => esc_html__( 'div', 'visarzo-core' ),
					'span' => esc_html__( 'span', 'visarzo-core' ),
					'p'    => esc_html__( 'p', 'visarzo-core' ),
				),
				'default' => 'h1',

			)
		);

		$repeater->add_control(
			'item_content',
			array(
				'label'       => esc_html__( 'Content', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),

			)
		);
		$repeater->add_control(
			'content_on_off',
			array(
				'label'        => __( 'Content Enable?', 'visarzo-core' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => __( 'Show', 'visarzo-core' ),
				'label_off'    => __( 'Hide', 'visarzo-core' ),
				'return_value' => 'yes',
				'default'      => 'yes',
			)
		);

		$repeater->add_control(
			'item_button_name',
			array(
				'label'       => esc_html__( 'Button Name', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'Discover Solutions', 'visarzo-core' ),
			)
		);
		$repeater->add_control(
			'top_text_style',
			array(
				'label'        => __( 'Top Text Enable?', 'visarzo-core' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => __( 'Show', 'visarzo-core' ),
				'label_off'    => __( 'Hide', 'visarzo-core' ),
				'return_value' => 'yes',
				'default'      => 'yes',
			)
		);

		$repeater->add_control(
			'item_button_link',
			array(
				'label'         => esc_html__( 'Button Link', 'visarzo-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => esc_html__( 'https://your-link.com', 'visarzo-core' ),
				'show_external' => true,
				'default'       => array(
					'url'         => '',
					'is_external' => true,
					'nofollow'    => true,
				),

			)
		);
		$repeater->add_control(
			'item_alighment',
			array(
				'label'   => __( 'Alignment', 'visarzo-core' ),
				'type'    => \Elementor\Controls_Manager::CHOOSE,
				'options' => array(
					'left'    => array(
						'title' => __( 'Left', 'visarzo-core' ),
						'icon'  => 'fa fa-align-left',
					),
					'centred' => array(
						'title' => __( 'Center', 'visarzo-core' ),
						'icon'  => 'fa fa-align-center',
					),
				),
				'default' => 'centred',
				'toggle'  => true,
			)
		);

		$this->add_control(
			'items',
			array(
				'label'   => esc_html__( 'Repeater List', 'visarzo-core' ),
				'type'    => Controls_Manager::REPEATER,
				'fields'  => $repeater->get_controls(),
				'default' => array(
					array(
						'list_title'   => esc_html__( 'Title #1', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
					array(
						'list_title'   => esc_html__( 'Title #2', 'visarzo' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
				),
			)
		);

		$this->end_controls_section();
		$this->start_controls_section(
			'style_section',
			array(
				'label' => __( 'Color', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->start_controls_tabs( 'tabs_button_style' );
		$this->start_controls_tab(
			'tab_button_normal',
			array(
				'label' => __( 'Normal', 'elementor' ),
			)
		);
		$this->add_control(
			'bg_color',
			array(
				'label'     => __( 'Background Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .theme-btn-one' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'text_color',
			array(
				'label'     => __( 'Text Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .theme-btn-one' => 'color: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'border_color',
			array(
				'label'     => __( 'Border Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .banner-section .banner-carousel .content-box a.theme-btn-one' => 'border:2px solid {{VALUE}} !important',

				),
			)
		);

		$this->add_control(
			'icon_color',
			array(
				'label'     => __( 'Icon Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .theme-btn-one i' => 'color: {{VALUE}} !important',

				),
			)
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tab_button_hover',
			array(
				'label' => __( 'Hover', 'elementor' ),
			)
		);
		$this->add_control(
			'hover_bg_color',
			array(
				'label'     => __( 'Hover Bg Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .theme-btn-one:after' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'hover_border_color',
			array(
				'label'     => __( 'Hover Border Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .banner-section .banner-carousel .content-box a.theme-btn-one:hover' => 'border:2px solid {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'hover_icon_color',
			array(
				'label'     => __( 'Hover Icon Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .theme-btn-one:hover i' => 'color: {{VALUE}} !important',

				),
			)
		);

		$this->add_control(
			'hover_text_color',
			array(
				'label'     => __( 'Hover Text Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .theme-btn-one:hover' => 'color: {{VALUE}} !important',

				),
			)
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		$this->start_controls_section(
			'text_style_section',
			array(
				'label' => __( 'Text Style', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'content_typography',
				'label'    => __( 'Typography', 'visarzo-core' ),
				'scheme'   => Schemes\Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .slider',
			)
		);
		$this->end_controls_section();
	}
	protected function render() {
		$settings     = $this->get_settings_for_display();
		$slider_style = $settings['slider_style'];

		$loop     = $settings['loop'];
		if ( $loop == 'yes' ) {
			$loop = 'true';
		} else {
			$loop = 'false';
		}

		$mouseDrag     = $settings['mouseDrag'];
		if ( $mouseDrag == 'yes' ) {
			$mouseDrag = 'true';
		} else {
			$mouseDrag = 'false';
		}


		$autoplay = $settings['autoplay'];
		if ( $autoplay == 'yes' ) {
			$autoplay = 'true';
		} else {
			$autoplay = 'false';
		}
		$autoplay_speed = $settings['autoplay_speed'];

		$arrows = $settings['arrows'];
		if ( $arrows == 'yes' ) {
			$arrows = 'true';
		} else {
			$arrows = 'false';
		}

		$sl_set = array(
			'loop'           => $loop,
			'autoplay'       => $autoplay,
			'autoplayTimeout' => ! empty( $autoplay_speed ) ? $autoplay_speed : '8000',
			'nav'         => $arrows,
			'mouseDrag'         => $mouseDrag,
		);

		?>
		<!-- banner-section -->
		<?php if ( $slider_style == 'style_1' ) : ?>
		<section class="banner-section style-one">
			<div class="banner-carousel owl-theme owl-carousel owl-dots-none" data-slider='<?php echo wp_json_encode( $sl_set ); ?>'>
				<?php
				$i = 1;
				foreach ( $settings['items'] as $item ) {
					$item_tagline           = $item['item_tagline'];
					$item_slider_image      = ( $item['item_slider_image']['id'] != '' ) ? wp_get_attachment_image_url( $item['item_slider_image']['id'], 'full' ) : $item['item_slider_image']['url'];
					$item_title             = $item['item_title'];
					$item_html_tag          = $item['item_html_tag'];
					$item_content           = $item['item_content'];
					$top_text_style         = $item['top_text_style'];
					$item_button_name       = $item['item_button_name'];
					$item_first_button_link = $item['item_button_link'];
					$item_page_target       = $item['item_button_link']['is_external'] ? ' target="_blank"' : '';
					$item_page_nofollow     = $item['item_button_link']['nofollow'] ? ' rel="nofollow"' : '';
					$item_alighment         = $item['item_alighment'];
					$content_on_off         = $item['content_on_off'];
					$section_style          = $item['section_style'];
					?>
				 <div class="slide-item">
						<div class="image-layer" style="background-image:url(<?php echo esc_url( $item_slider_image ); ?>)"></div>
						<div class="auto-container">
							<div class="row clearfix">
								<?php if ( $section_style == 'style_1' ) : ?>
								<div class="col-xl-7 col-lg-12 col-md-12 content-column">
								<?php elseif ( $section_style == 'style_2' ) : ?>
								<div class="col-xl-6 col-lg-12 col-md-12 content-column">
								<?php endif; ?>
									<div class="content-box">
									<?php if ( $top_text_style == 'yes' ) : ?>
										<span class="top-text"><?php echo $item_tagline; ?></span>
									<?php endif; ?>
										<div class="title-text">
											<<?php echo $item_html_tag; ?> class="slider"><?php echo $item_title; ?></<?php echo $item_html_tag; ?>>
											<div class="dotted-box">
												<span class="dotted"></span>
												<span class="dotted"></span>
												<span class="dotted"></span>
											</div>
										</div>
										<?php if ( $content_on_off == 'yes' ) : ?>
										<p><?php echo $item_content; ?></p>
										<?php endif; ?>
										<div class="btn-box">
											<a href="<?php echo esc_url( $item_first_button_link['url'] ); ?>" <?php echo $item_page_target . ' ' . $item_page_nofollow; ?> class="theme-btn-one"><i class="flaticon-send"></i><?php echo $item_button_name; ?></a>
										</div>
									</div>
								</div>
							</div>
						</div>
					</div> <?php } ?>

			</div>
		</section>
		<!-- banner-section end -->
					<?php elseif ( $slider_style == 'style_2' ) : ?>
		<!-- banner-section -->
		<section class="banner-section style-two">
			<div class="banner-carousel owl-theme owl-carousel owl-dots-none"  data-slider='<?php echo wp_json_encode( $sl_set ); ?>'>
						<?php
						$i = 1;
						foreach ( $settings['items'] as $item ) {
							$item_tagline           = $item['item_tagline'];
							$item_slider_image      = ( $item['item_slider_image']['id'] != '' ) ? wp_get_attachment_image_url( $item['item_slider_image']['id'], 'full' ) : $item['item_slider_image']['url'];
							$item_title             = $item['item_title'];
							$item_html_tag          = $item['item_html_tag'];
							$item_content           = $item['item_content'];
							$top_text_style         = $item['top_text_style'];
							$item_button_name       = $item['item_button_name'];
							$item_button_link       = $item['item_button_link']['url'];
							$item_first_button_link = $item['item_button_link'];
							$item_page_target       = $item['item_button_link']['is_external'] ? ' target="_blank"' : '';
							$item_page_nofollow     = $item['item_button_link']['nofollow'] ? ' rel="nofollow"' : '';
							$item_alighment         = $item['item_alighment'];
							$content_on_off         = $item['content_on_off'];
							$section_style          = $item['section_style'];
							?>
				<div class="slide-item">
					<div class="image-layer" style="background-image:url(<?php echo esc_url( $item_slider_image ); ?>)"></div>
					<div class="auto-container">
						<div class="row clearfix">
							<?php if ( $section_style == 'style_2' ) : ?>
								<div class="col-xl-7 col-lg-12 col-md-12 content-column">
								<?php elseif ( $section_style == 'style_1' ) : ?>
							<div class="col-xl-8 col-lg-12 col-md-12 offset-xl-2 content-column">
							<?php endif; ?>
								<div class="content-box <?php echo $item_alighment; ?>">
								<?php if ( $top_text_style == 'yes' ) : ?>
									<span class="top-text"><?php echo $item_tagline; ?></span>
									<?php endif; ?>
									<div class="title-text">
									<<?php echo $item_html_tag; ?> class="slider"><?php echo $item_title; ?></<?php echo $item_html_tag; ?>>
										<div class="dotted-box">
											<span class="dotted"></span>
											<span class="dotted"></span>
											<span class="dotted"></span>
										</div>
									</div>
									<?php if ( $content_on_off == 'yes' ) : ?>
									<p><?php echo $item_content; ?></p>
									<?php endif; ?>
									<div class="btn-box">
										<a href="<?php echo esc_url( $item_first_button_link['url'] ); ?>" <?php echo $item_page_target . ' ' . $item_page_nofollow; ?> class="theme-btn-one"><i class="flaticon-send"></i><?php echo $item_button_name; ?></a>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
						<?php } ?>
			</div>
		</section>
		<?php endif; ?>
		<!-- banner-section end --> 
					<?php
	}

	protected function content_templates() {
	}
}
