<?php
namespace Visarzo\Helper\Elementor\Widgets;

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use \Elementor\Repeater;
use Visarzo\Helper\Elementor\Settings\Header;
use Elementor\Core\Schemes;

class VisarzoBlog extends Widget_Base {



	public function get_name() {
		return 'visarzo_blog';
	}

	public function get_title() {
		return esc_html__( 'Visarzo Blog', 'visarzo-core' );
	}

	public function get_icon() {
		return 'eicon-post';
	}

	public function get_categories() {
		return array( 'visarzo' );
	}
	public function get_script_depends() {
		return array( 'training' );
	}

	private function get_blog_categories() {
		$options  = array();
		$taxonomy = 'category';
		if ( ! empty( $taxonomy ) ) {
			$terms = get_terms(
				array(
					'parent'     => 0,
					'taxonomy'   => $taxonomy,
					'hide_empty' => false,
				)
			);
			if ( ! empty( $terms ) ) {
				foreach ( $terms as $term ) {
					if ( isset( $term ) ) {
						$options[''] = 'Select';
						if ( isset( $term->slug ) && isset( $term->name ) ) {
							$options[ $term->slug ] = $term->name;
						}
					}
				}
			}
		}
		return $options;
	}

	protected function register_controls() {
		$this->start_controls_section(
			'general',
			array(
				'label' => esc_html__( 'General', 'visarzo-core' ),
			)
		);

		$this->add_control(
			'layout_style',
			array(
				'label'   => esc_html__( 'Layout Style', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'style_1' => esc_html__( 'Style One', 'visarzo-core' ),
					'style_2' => esc_html__( 'Style Two', 'visarzo-core' ),
					'style_3' => esc_html__( 'Style Three', 'visarzo-core' ),

				),
				'default' => 'style_1',

			)
		);
		Header::visarzo_coloumn_control( $this, 6, 2 );
		$this->add_control(
			'tagline',
			array(
				'label'       => esc_html__( 'Tagline', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'read latest articles', 'visarzo-core' ),
				'condition'   => array( 'layout_style' => 'style_1' ),
			)
		);

		$this->add_control(
			'title',
			array(
				'label'       => esc_html__( 'Title', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'What’s Happening', 'visarzo-core' ),
				'condition'   => array( 'layout_style' => 'style_1' ),
			)
		);

		$this->add_control(
			'html_tag',
			array(
				'label'     => esc_html__( 'Html Tag', 'visarzo-core' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => array(
					'h1'   => esc_html__( 'H1', 'visarzo-core' ),
					'h2'   => esc_html__( 'H2', 'visarzo-core' ),
					'h3'   => esc_html__( 'H3', 'visarzo-core' ),
					'h4'   => esc_html__( 'H4', 'visarzo-core' ),
					'h5'   => esc_html__( 'H5', 'visarzo-core' ),
					'h6'   => esc_html__( 'H6', 'visarzo-core' ),
					'div'  => esc_html__( 'div', 'visarzo-core' ),
					'span' => esc_html__( 'span', 'visarzo-core' ),
					'p'    => esc_html__( 'p', 'visarzo-core' ),
				),
				'default'   => 'h2',
				'condition' => array( 'layout_style' => 'style_1' ),

			)
		);

		$this->add_control(
			'content',
			array(
				'label'       => esc_html__( 'Content', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),
				'condition'   => array( 'layout_style' => 'style_1' ),

			)
		);

		$this->add_control(
			'category_id',
			array(
				'type'        => \Elementor\Controls_Manager::SELECT2,
				'label'       => esc_html__( 'Category', 'visarzo-core-core' ),
				'options'     => $this->get_blog_categories(),
				'multiple'    => true,
				'label_block' => true,
			)
		);

		$this->add_control(
			'posts_per_page',
			array(
				'label'   => esc_html__( 'Number of Post', 'visarzo-core-core' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 3,
			)
		);

		$this->add_control(
			'order_by',
			array(
				'label'   => esc_html__( 'Order By', 'visarzo-core-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => array(
					'date'          => esc_html__( 'Date', 'visarzo-core-core' ),
					'ID'            => esc_html__( 'ID', 'visarzo-core-core' ),
					'author'        => esc_html__( 'Author', 'visarzo-core-core' ),
					'title'         => esc_html__( 'Title', 'visarzo-core-core' ),
					'modified'      => esc_html__( 'Modified', 'visarzo-core-core' ),
					'rand'          => esc_html__( 'Random', 'visarzo-core-core' ),
					'comment_count' => esc_html__( 'Comment count', 'visarzo-core-core' ),
					'menu_order'    => esc_html__( 'Menu order', 'visarzo-core-core' ),
				),
			)
		);

		$this->add_control(
			'order',
			array(
				'label'   => esc_html__( 'Order', 'visarzo-core-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'desc',
				'options' => array(
					'desc' => esc_html__( 'DESC', 'visarzo-core-core' ),
					'asc'  => esc_html__( 'ASC', 'visarzo-core-core' ),
				),
			)
		);

		$this->end_controls_section();
		$this->start_controls_section(
			'style_section',
			array(
				'label' => __( 'Color', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->start_controls_tabs( 'tabs_button_style' );
		$this->start_controls_tab(
			'tab_button_normal',
			array(
				'label' => __( 'Normal', 'elementor' ),
			)
		);
		$this->add_control(
			'title_underline',
			array(
				'label'     => __( 'Title Underline Color', 'bisarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .sec-title:before' => 'background: {{VALUE}} !important',
					'{{WRAPPER}} .sec-title .dotted-box .dotted' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'date_color',
			array(
				'label'     => __( 'Date Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .news-block-one .inner-box .lower-content .post-date' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'author_underline_color',
			array(
				'label'     => __( 'author Underline Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .news-block-one .inner-box .lower-content .post-info:before' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'icon_color',
			array(
				'label'     => __( 'Icon Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .news-block-one .inner-box .lower-content .link a i' => 'color: {{VALUE}} !important',

				),
			)
		);

		$this->end_controls_tab();
		$this->start_controls_tab(
			'tab_button_hover',
			array(
				'label' => __( 'Hover', 'elementor' ),
			)
		);
		$this->add_control(
			'title_hover_color',
			array(
				'label'     => __( 'Title  Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} h3 a:hover' => 'color: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'author_hover_color',
			array(
				'label'     => __( 'Author  Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .news-block-one .inner-box .lower-content .post-info li a:hover' => 'color: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'readmore_color',
			array(
				'label'     => __( 'Read More Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .news-block-one .inner-box .lower-content .link a:hover' => 'color: {{VALUE}} !important',

				),
			)
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();

		$this->start_controls_section(
			'text_style_section',
			array(
				'label' => __( 'Text Style', 'visarzo-core-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'content_typography',
				'label'    => __( 'Typography', 'visarzo-core-core' ),
				'scheme'   => Schemes\Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .blog_heading',
			)
		);
		$this->end_controls_section();
	}
	protected function render() {
		$settings     = $this->get_settings_for_display();
		$layout_style = $settings['layout_style'];
		if ( $layout_style == 'style_1' ) :
			$tagline  = $settings['tagline'];
			$title    = $settings['title'];
			$html_tag = $settings['html_tag'];
			$content  = $settings['content'];
		endif;

		if ( $settings['category_id'] ) {
			$category_arr = implode( ', ', $settings['category_id'] );
		} else {
			$category_arr = array();
		}

		$posts_per_page = $settings['posts_per_page'];
		$order_by       = $settings['order_by'];
		$order          = $settings['order'];
		$pg_num         = get_query_var( 'paged' ) ? get_query_var( 'paged' ) : 1;
		$args           = array(
			'post_type'      => array( 'post' ),
			'post_status'    => array( 'publish' ),
			'nopaging'       => false,
			'paged'          => $pg_num,
			'posts_per_page' => $posts_per_page,
			'category_name'  => $category_arr,
			'orderby'        => $order_by,
			'order'          => $order,
		);
		$query          = new \WP_Query( $args );
		$section_class  = ( $layout_style == 'style_3' ) ? 'sec-pad-2' : '';

		?>
		<?php if ( $layout_style == 'style_1' || $layout_style == 'style_3' ) : ?>
			<section class="news-section <?php echo $section_class; ?>">
			<div class="auto-container">
			<?php if ( $layout_style == 'style_1' ) : ?>
				<div class="top-inner">
					<div class="row clearfix">
						<div class="col-lg-5 col-md-12 col-sm-12 title-column">
							<div class="sec-title">
							<p><?php echo $tagline; ?></p>
								<<?php echo $html_tag; ?> class="blog_heading"><?php echo $title; ?></<?php echo $html_tag; ?>>
								<div class="dotted-box">
									<span class="dotted"></span>
									<span class="dotted"></span>
									<span class="dotted"></span>
								</div>
							</div>
						</div>
						<div class="col-lg-7 col-md-12 col-sm-12 text-column">
							<div class="text">
							<p><?php echo $content; ?></p>
							</div>
						</div>
					</div>
				</div>
			<?php endif; ?>
				<div class="row clearfix">
			<?php
			$i     = 0;
			$delay = 00;

			if ( $query->have_posts() ) {
				while ( $query->have_posts() ) {
					$i++;
					$query->the_post();
					global $post;
					$tags  = wp_get_post_categories( get_the_ID() );
					$image = get_post_meta( get_the_ID(), 'visarzo_metabox_content_image', true );
					?>
							
					<div class="col-lg-4 col-md-6 col-sm-12 news-block">
						<div class="news-block-one wow fadeInUp animated animated" data-wow-delay="<?php echo $delay; ?>ms" data-wow-duration="1500ms">
							<div class="inner-box">
								<figure class="image-box"><a href="<?php echo esc_url( get_permalink() ); ?>">
					<?php
					if ( isset( $image ) && $image != '' ) {
							$ad_im = wp_get_attachment_image_url( $image, 'full' );
						?>
										<img src="<?php echo esc_url( $ad_im ); ?>" alt="<?php esc_attr_e( 'Awesome Image', 'visarzo-core' ); ?>">
							<?php
					} else {
						the_post_thumbnail( 'visarzo-blog-grid' );
					}
					?>
										 </a>
								</figure>
								<div class="lower-content">
									<div class="post-date"><h2><?php echo get_the_date( 'd' ); ?></h2><span><?php echo get_the_date( 'M' ); ?></span></div>
									<h3><a href="<?php echo esc_url( get_permalink() ); ?>"><?php the_title(); ?></a></h3>
									<ul class="post-info clearfix">
								
									<li><a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php esc_html_e( 'By', 'visarzo-core' ); ?> <?php echo get_the_author(); ?></a></li>
									<li>
					<?php
					foreach ( $tags as $tag ) {
						  $cats     = get_the_category_by_ID( $tag );
						  $cat_link = get_category_link( $tag );
						?>
											<a href="<?php echo esc_url( $cat_link ); ?>"><?php echo $cats; ?></a>
						  <?php
					}
					?>
									</li>
									</ul>
									<div class="link"><a href="<?php echo esc_url( get_permalink() ); ?>"><?php esc_html_e( 'Read More', 'visarzo-core' ); ?><i class="flaticon-send"></i></a></div>
								</div>
							</div>
						</div>
					</div>
					<?php
					$delay += 300;
				}
									wp_reset_postdata();
			}
			?>

				</div>
			</div>
		</section>
					<?php elseif ( $layout_style == 'style_2' ) : ?>
		<section class="news-section sec-pad-2">
			<div class="auto-container">
				<div class="three-item-carousel owl-carousel owl-theme owl-dots-none owl-nav-none">
						<?php
						$i = 0;
						if ( $query->have_posts() ) {
							while ( $query->have_posts() ) {
								$i++;
								$query->the_post();
								global $post;
								$tags  = wp_get_post_categories( get_the_ID() );
								$image = get_post_meta( get_the_ID(), 'visarzo_metabox_content_image', true );
								?>

					<div class="news-block-one mb-30">
						<div class="inner-box">
							<figure class="image-box">
								<a href="<?php echo esc_url( get_permalink() ); ?>">
								<?php
								if ( isset( $image ) && $image != '' ) {
									$ad_im = wp_get_attachment_image_url( $image, 'full' );
									?>
										<img src="<?php echo esc_url( $ad_im ); ?>" alt="<?php esc_attr_e( 'Awesome Image', 'visarzo-core' ); ?>">
									 <?php
								} else {
										  the_post_thumbnail( 'visarzo-blog-grid' );
								}
								?>
								</a>
							</figure>
							<div class="lower-content">
								<div class="post-date"><h2><?php echo get_the_date( 'd' ); ?></h2><span><?php the_date( 'M' ); ?></span></div>
								<h3><a href="<?php echo esc_url( get_permalink() ); ?>"><?php the_title(); ?></a></h3>
								<ul class="post-info clearfix">
									<li><a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php esc_html_e( 'By', 'visarzo-core' ); ?> <?php echo get_the_author(); ?></a></li>
									<li>
								<?php
								foreach ( $tags as $tag ) {
												 $cats     = get_the_category_by_ID( $tag );
												 $cat_link = get_category_link( $tag );
									?>
											<a href="<?php echo esc_url( $cat_link ); ?>"><?php echo $cats; ?></a>
															   <?php
								}
								?>
									</li>
								</ul>
								<div class="link"><a href="<?php echo esc_url( get_permalink() ); ?>"><?php esc_html_e( 'Read More', 'visarzo-core' ); ?><i class="flaticon-send"></i></a></div>
							</div>
						</div>
					</div>
					
								<?php
							}
							wp_reset_postdata();
						}
						?>
				</div>
			</div>
		</section>
					<?php endif; ?>
			<!-- news-style-three end -->
		 <?php
	}

	protected function content_templates() {
	}
}
