<?php
namespace Visarzo\Helper\Elementor\Widgets;

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Core\Schemes;
class Visarzo_About extends Widget_Base {



	public function get_name() {
		return 'visarzo_about';
	}

	public function get_title() {
		return esc_html__( 'Visarzo About', 'visarzo-core' );
	}

	public function get_icon() {
		return 'fa fa-object-ungroup';
	}

	public function get_categories() {
		return array( 'visarzo' );
	}

	protected function register_controls() {
		$this->start_controls_section(
			'left_content',
			array(
				'label' => esc_html__( 'General', 'visarzo-core' ),
			)
		);
		$this->add_control(
			'layout_style',
			array(
				'label'   => esc_html__( 'Layout Style', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'style_1' => esc_html__( 'Style One', 'visarzo-core' ),
					'style_2' => esc_html__( 'Style Two', 'visarzo-core' ),

				),
				'default' => 'style_1',

			)
		);

		$this->add_control(
			'tagline',
			array(
				'label'   => esc_html__( 'Tagline', 'visarzo-core' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __( 'who are visarzo', 'visarzo-core' ),
			)
		);

		$this->add_control(
			'title',
			array(
				'label'       => esc_html__( 'Title', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'     => __( 'Not Just Traditional Visa & Immigration Firm', 'visarzo-core' ),
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),

			)
		);
		$this->add_control(
			'extra_class',
			array(
				'label'   => esc_html__( 'Extra Class', 'visarzo-core' ),
				'type'    => Controls_Manager::TEXTAREA,
				'default' => __( 'sec-pad-2', 'visarzo-core' ),

			)
		);

		$this->add_control(
			'html_tag',
			array(
				'label'   => esc_html__( 'Html Tag', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'h1'   => esc_html__( 'H1', 'visarzo-core' ),
					'h2'   => esc_html__( 'H2', 'visarzo-core' ),
					'h3'   => esc_html__( 'H3', 'visarzo-core' ),
					'h4'   => esc_html__( 'H4', 'visarzo-core' ),
					'h5'   => esc_html__( 'H5', 'visarzo-core' ),
					'h6'   => esc_html__( 'H6', 'visarzo-core' ),
					'div'  => esc_html__( 'div', 'visarzo-core' ),
					'span' => esc_html__( 'span', 'visarzo-core' ),
					'p'    => esc_html__( 'p', 'visarzo-core' ),
				),
				'default' => 'h2',

			)
		);

		$this->add_control(
			'bolt_text',
			array(
				'label'     => esc_html__( 'Bolt Text', 'visarzo-core' ),
				'type'      => Controls_Manager::TEXTAREA,
				'default'   => __( 'Sponsoring and managing work visas parts now becoming results in the experience.', 'visarzo-core' ),
				'condition' => array( 'layout_style' => 'style_1' ),

			)
		);

		$this->add_control(
			'content',
			array(
				'label'       => esc_html__( 'Content', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),

			)
		);

		$this->add_control(
			'button_name',
			array(
				'label'   => esc_html__( 'Button Name', 'visarzo-core' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __( 'Learn More', 'visarzo-core' ),
			)
		);

		$this->add_control(
			'button_link',
			array(
				'label'         => esc_html__( 'Button Link', 'visarzo-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => esc_html__( 'https://your-link.com', 'visarzo-core' ),
				'show_external' => true,
				'default'       => array(
					'url'         => '#',
					'is_external' => true,
					'nofollow'    => true,
				),

			)
		);

		$this->add_control(
			'experience_tagline',
			array(
				'label'       => esc_html__( 'Experience Tagline', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'     => __( 'America’s Leading Visa & Immigration lawyers with', 'visarzo-core' ),
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),
				'condition'   => array( 'layout_style' => 'style_1' ),

			)
		);

		$this->add_control(
			'experience_year',
			array(
				'label'     => esc_html__( 'Experience Year', 'visarzo-core' ),
				'type'      => Controls_Manager::TEXT,
				'default'   => __( '24', 'visarzo' ),
				'condition' => array( 'layout_style' => 'style_1' ),
			)
		);

		$this->add_control(
			'experience_title',
			array(
				'label'     => esc_html__( 'Experience Title', 'visarzo-core' ),
				'type'      => Controls_Manager::TEXT,
				'default'   => __( 'Years Of Experience', 'visarzo-core' ),
				'condition' => array( 'layout_style' => 'style_1' ),
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'right_content',
			array(
				'label' => esc_html__( 'Thumbnail', 'visarzo-core' ),
			)
		);

		$this->add_control(
			'shape_image',
			array(
				'label'     => esc_html__( 'Shape Image', 'visarzo-core' ),
				'type'      => Controls_Manager::MEDIA,
				'default'   => array(
					'url' => Utils::get_placeholder_image_src(),
				),
				'condition' => array( 'layout_style' => 'style_1' ),

			)
		);
		$this->add_control(
			'image',
			array(
				'label'   => esc_html__( 'Image', 'visarzo-core' ),
				'type'    => Controls_Manager::MEDIA,
				'default' => array(
					'url' => Utils::get_placeholder_image_src(),
				),

			)
		);
		$this->add_control(
			'upper_left_image',
			array(
				'label'     => esc_html__( 'Upper Left Image', 'visarzo-core' ),
				'type'      => Controls_Manager::MEDIA,
				'default'   => array(
					'url' => Utils::get_placeholder_image_src(),
				),
				'condition' => array( 'layout_style' => 'style_2' ),

			)
		);
		$this->add_control(
			'lower_right_image',
			array(
				'label'     => esc_html__( 'Lower Right Image', 'visarzo-core' ),
				'type'      => Controls_Manager::MEDIA,
				'default'   => array(
					'url' => Utils::get_placeholder_image_src(),
				),
				'condition' => array( 'layout_style' => 'style_2' ),

			)
		);
		$this->end_controls_section();
		$this->start_controls_section(
			'style_section',
			array(
				'label' => __( 'Color', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->start_controls_tabs( 'tabs_button_style' );
		$this->start_controls_tab(
			'tab_button_normal',
			array(
				'label' => __( 'Normal', 'elementor' ),
			)
		);
		$this->add_control(
			'title_underline',
			array(
				'label'     => __( 'Title Underline Color', 'bisarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .sec-title:before' => 'background: {{VALUE}} !important',
					'{{WRAPPER}} .sec-title .dotted-box .dotted' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'background_color',
			array(
				'label'     => __( 'Button Color', 'bisarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .theme-btn-two' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'text_color',
			array(
				'label'     => __( 'Button Text Color', 'bisarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .theme-btn-two' => 'color: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'year_color',
			array(
				'label'     => __( 'Year Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} #image_block_1 .image-box .box .inner h1' => 'color: {{VALUE}} !important',

				),
			)
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tab_button_hover',
			array(
				'label' => __( 'Hover', 'elementor' ),
			)
		);
		$this->add_control(
			'hover_bg_color',
			array(
				'label'     => __( 'Button Color', 'bisarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .theme-btn-two:after' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'hover_text_color',
			array(
				'label'     => __( 'Text Color', 'bisarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .theme-btn-two:hover' => 'color: {{VALUE}} !important',

				),
			)
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		$this->start_controls_section(
			'text_style_section',
			array(
				'label' => __( 'Text Style', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'content_typography',
				'label'    => __( 'Typography', 'visarzo-core' ),
				'scheme'   => Schemes\Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .about_section',
			)
		);
		$this->end_controls_section();

	}
	protected function render() {
		$settings     = $this->get_settings_for_display();
		$layout_style = $settings['layout_style'];
		$tagline      = $settings['tagline'];
		$title        = $settings['title'];
		$extra_class  = $settings['extra_class'];
		$image        = ( $settings['image']['id'] != '' ) ? wp_get_attachment_image_url( $settings['image']['id'], 'full' ) : $settings['image']['url'];
		if ( ! empty( $image ) ) {
			$this->add_render_attribute( 'image', 'src', $image );
			$this->add_render_attribute( 'image', 'alt', \Elementor\Control_Media::get_image_alt( $settings['image'] ) );
			$this->add_render_attribute( 'image', 'title', \Elementor\Control_Media::get_image_title( $settings['image'] ) );
			$image_html = \Elementor\Group_Control_Image_Size::get_attachment_image_html( $settings, 'full', 'image' );
		}
		if ( $layout_style == 'style_2' ) :
			$upper_left_image = ( $settings['upper_left_image']['id'] != '' ) ? wp_get_attachment_image_url( $settings['upper_left_image']['id'], 'full' ) : $settings['upper_left_image']['url'];
			if ( ! empty( $upper_left_image ) ) {
				$this->add_render_attribute( 'upper_left_image', 'src', $upper_left_image );
				$this->add_render_attribute( 'upper_left_image', 'alt', \Elementor\Control_Media::get_image_alt( $settings['upper_left_image'] ) );
				$this->add_render_attribute( 'upper_left_image', 'title', \Elementor\Control_Media::get_image_title( $settings['upper_left_image'] ) );
				$upper_left_image_html = \Elementor\Group_Control_Image_Size::get_attachment_image_html( $settings, 'full', 'upper_left_image' );
			}
			$lower_right_image = ( $settings['lower_right_image']['id'] != '' ) ? wp_get_attachment_image_url( $settings['lower_right_image']['id'], 'full' ) : $settings['lower_right_image']['url'];
			if ( ! empty( $lower_right_image ) ) {
				$this->add_render_attribute( 'lower_right_image', 'src', $lower_right_image );
				$this->add_render_attribute( 'lower_right_image', 'alt', \Elementor\Control_Media::get_image_alt( $settings['lower_right_image'] ) );
				$this->add_render_attribute( 'lower_right_image', 'title', \Elementor\Control_Media::get_image_title( $settings['lower_right_image'] ) );
				$lower_right_image_html = \Elementor\Group_Control_Image_Size::get_attachment_image_html( $settings, 'full', 'lower_right_image' );
			}
		endif;
		$html_tag    = $settings['html_tag'];
		$content     = $settings['content'];
		$button_name = $settings['button_name'];
		$button_link = $settings['button_link']['url'];
		if ( ! empty( $button_link ) ) {
			$this->add_render_attribute( 'button_link', 'href', $button_link );
			if ( ! empty( $settings['button_link']['is_external'] ) ) {
				$this->add_render_attribute( 'button_link', 'target', '_blank' );
			}

			if ( ! empty( $settings['button_link']['nofollow'] ) ) {
				$this->add_render_attribute( 'button_link', 'rel', 'nofollow' );
			}
		}

		?>
		<!-- about-section -->
		<?php
		if ( $layout_style == 'style_1' ) :
			$bolt_text          = $settings['bolt_text'];
			$experience_tagline = $settings['experience_tagline'];
			$experience_year    = $settings['experience_year'];
			$experience_title   = $settings['experience_title'];
			$shape_image        = ( $settings['shape_image']['id'] != '' ) ? wp_get_attachment_image_url( $settings['shape_image']['id'], 'full' ) : $settings['shape_image']['url'];
			?>
		<section class="about-section">
			<div class="pattern-layer" style="background-image: url(<?php echo esc_url( $shape_image ); ?>);"></div>
			<div class="auto-container">
				<div class="row align-items-center clearfix">
					<div class="col-lg-6 col-md-12 col-sm-12 image-column">
						<div id="image_block_1">
							<div class="image-box">
								<figure class="image"><?php echo $image_html; ?></figure>
								<div class="box">
									<div class="inner">
										<div class="icon-box">
											<div class="icon icon-1"></div>
											<div class="icon icon-2"></div>
										</div>
										<span><?php echo $experience_tagline; ?></span>
										<h1><?php echo $experience_year; ?></h1>
										<p><?php echo $experience_title; ?></p>
									</div>
								</div>
							</div>
						</div>
					</div>
					<div class="col-lg-6 col-md-12 col-sm-12 content-column">
						<div id="content_block_1">
							<div class="content-box">
								<div class="sec-title">
									<p><?php echo $tagline; ?></p>
									<<?php echo $html_tag; ?> class="about_section"><?php echo $title; ?></<?php echo $html_tag; ?>>
									<div class="dotted-box">
										<span class="dotted"></span>
										<span class="dotted"></span>
										<span class="dotted"></span>
									</div>
								</div>
								<div class="bold-text">
									<p><?php echo $bolt_text; ?></p>
								</div>
								<div class="text">
									<p><?php echo $content; ?></p>
								</div>
								<div class="btn-box">
									<a <?php echo $this->get_render_attribute_string( 'button_link' ); ?> class="theme-btn-two"><?php echo $button_name; ?><i class="flaticon-send"></i></a>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</section>
		<!-- about-section end -->
		<?php elseif ( $layout_style == 'style_2' ) : ?>

		<!-- about-style-two -->
		<section class="about-style-two <?php echo $extra_class; ?>">
			<div class="auto-container">
				<div class="row clearfix">
					<div class="col-lg-6 col-md-12 col-sm-12 content-column">
						<div id="content_block_3">
							<div class="content-box">
								<div class="sec-title">
									<p><?php echo $tagline; ?></p>
									<<?php echo $html_tag; ?> class="about_section"><?php echo $title; ?></<?php echo $html_tag; ?>>
									<div class="dotted-box">
										<span class="dotted"></span>
										<span class="dotted"></span>
										<span class="dotted"></span>
									</div>
								</div>
								<div class="text">
									<p><?php echo $content; ?></p>
								</div>
								<div class="btn-box"><a <?php echo $this->get_render_attribute_string( 'button_link' ); ?> class="theme-btn-two"><?php echo $button_name; ?><i class="flaticon-send"></i></a></div>
							</div>
						</div>
					</div>
					<div class="col-lg-6 col-md-12 col-sm-12 image-column">
						<div id="image_block_2">
							<div class="image-box">
								<figure class="image-1"><?php echo $image_html; ?></figure>
								<figure class="image-2"><?php echo $upper_left_image_html; ?></figure>
								<figure class="image-3"><?php echo $lower_right_image_html; ?></figure>
							</div>
						</div>
					</div>
				</div>
			</div>
		</section>
		<?php endif; ?>
		<!-- about-style-two end -->
		<?php
	}

	protected function content_templates() {
	}
}
