<?php
namespace Visarzo\Helper\Elementor\Widgets;

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use \Elementor\Repeater;

class Visarzo_Brand extends Widget_Base {



	public function get_name() {
		return 'visarzo_client';
	}

	public function get_title() {
		return esc_html__( 'Visarzo Client', 'visarzo-core' );
	}

	public function get_icon() {
		return 'fa fa-object-ungroup';
	}

	public function get_categories() {
		return array( 'visarzo' );
	}
	public function get_script_depends() {
		return array( 'training' );
	}


	protected function register_controls() {

		$this->start_controls_section(
			'item',
			array(
				'label' => esc_html__( 'ITEM', 'visarzo-core' ),
			)
		);
		$this->add_control(
			'extra_class',
			array(
				'label'       => esc_html__( 'Extra Class', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'about-page', 'visarzo-core' ),
			)
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'item_client_logo_image',
			array(
				'label'   => esc_html__( 'Client Logo Image', 'visarzo-core' ),
				'type'    => Controls_Manager::MEDIA,
				'default' => array(
					'url' => Utils::get_placeholder_image_src(),
				),

			)
		);

		$repeater->add_control(
			'item_client_page_link',
			array(
				'label'         => esc_html__( 'Client Page Link', 'visarzo-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => esc_html__( 'https://your-link.com', 'visarzo-core' ),
				'show_external' => true,
				'default'       => array(
					'url'         => '',
					'is_external' => true,
					'nofollow'    => true,
				),

			)
		);

		$this->add_control(
			'items',
			array(
				'label'   => esc_html__( 'Repeater List', 'visarzo-core' ),
				'type'    => Controls_Manager::REPEATER,
				'fields'  => $repeater->get_controls(),
				'default' => array(
					array(
						'list_title'   => esc_html__( 'Title #1', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
					array(
						'list_title'   => esc_html__( 'Title #2', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
				),
			)
		);

		$this->end_controls_section();
	}
	protected function render() {
		$settings    = $this->get_settings_for_display();
		$extra_class = $settings['extra_class'];

		?>
		<!-- clients-section -->
		<section class="clients-section <?php echo $extra_class; ?>">
			<div class="auto-container">
				<div class="four-item-carousel owl-carousel owl-theme owl-dots-none owl-nav-none">
		<?php
		$i = 1;
		foreach ( $settings['items'] as $item ) {
			$item_client_logo_image = ( $item['item_client_logo_image']['id'] != '' ) ? wp_get_attachment_image_url( $item['item_client_logo_image']['id'], 'full' ) : $item['item_client_logo_image']['url'];
			if ( ! empty( $item_client_logo_image ) ) {
				$this->add_render_attribute( 'item_client_logo_image', 'src', $item_client_logo_image );
				$this->add_render_attribute( 'item_client_logo_image', 'alt', \Elementor\Control_Media::get_image_alt( $item['item_client_logo_image'] ) );
				$this->add_render_attribute( 'item_client_logo_image', 'title', \Elementor\Control_Media::get_image_title( $item['item_client_logo_image'] ) );
				$item['item_client_logo_image_size'] = 'full';
				$item_client_logo_image_html = \Elementor\Group_Control_Image_Size::get_attachment_image_html( $item, 'item_client_logo_image' );
			}

			$item_client_page_link     = $item['item_client_page_link'];
			$item_client_page_target   = $item['item_client_page_link']['is_external'] ? ' target="_blank"' : '';
			$item_client_page_nofollow = $item['item_client_page_link']['nofollow'] ? ' rel="nofollow"' : '';

			?>
					 <figure class="logo-image"><a href="<?php echo esc_url( $item_client_page_link['url'] ); ?>" <?php echo $item_client_page_target . ' ' . $item_client_page_nofollow; ?>><?php echo $item_client_logo_image_html; ?></a></figure> 
																	<?php
		}
		?>

				</div>
			</div>
		</section>
		<!-- clients-section end --> 
		<?php
	}

	protected function content_templates() {
	}
}
