<?php
namespace Visarzo\Helper\Elementor\Widgets;

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use \Elementor\Repeater;
use Elementor\Core\Schemes;

class Visarzo_CTA extends Widget_Base {

	public function get_name() {
		return 'visarzo_cta';
	}

	public function get_title() {
		return esc_html__( 'Visarzo CTA', 'visarzo-core' );
	}

	public function get_icon() {
		return 'fa fa-object-ungroup';
	}

	public function get_categories() {
		return array( 'visarzo' );
	}

	protected function register_controls() {

		$this->start_controls_section(
			'general',
			array(
				'label' => esc_html__( 'General', 'visarzo-core' ),
			)
		);

		$this->add_control(
			'title',
			array(
				'label'       => esc_html__( 'Title', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'rows'        => 0,
				'default'     => __( 'Unparalleled Consultancy from Experienced Lawyers', 'visarzo-core' ),
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),

			)
		);

		$this->add_control(
			'html_tag',
			array(
				'label'   => esc_html__( 'Html Tag', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'h1'   => esc_html__( 'H1', 'visarzo-core' ),
					'h2'   => esc_html__( 'H2', 'visarzo-core' ),
					'h3'   => esc_html__( 'H3', 'visarzo-core' ),
					'h4'   => esc_html__( 'H4', 'visarzo-core' ),
					'h5'   => esc_html__( 'H5', 'visarzo-core' ),
					'h6'   => esc_html__( 'H6', 'visarzo-core' ),
					'div'  => esc_html__( 'div', 'visarzo-core' ),
					'span' => esc_html__( 'span', 'visarzo-core' ),
					'p'    => esc_html__( 'p', 'visarzo-core' ),
				),
				'default' => 'h2',

			)
		);

		$this->add_control(
			'content',
			array(
				'label'       => esc_html__( 'Content', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'     => __( 'Dolor emque laudantium totam rem aperiam eaque ipsa quae ventore', 'visarzo-core' ),
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),

			)
		);

		$this->end_controls_section();
		$this->start_controls_section(
			'style_section',
			array(
				'label' => __( 'Color', 'visarzo-core-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_control(
			'background_color',
			array(
				'label'     => __( 'Background Color', 'bisarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .bg-color-1' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'line_color',
			array(
				'label'     => __( 'Line Color', 'bisarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .cta-section .inner-box .text:before' => 'background: {{VALUE}} !important',
					'{{WRAPPER}} .cta-section .inner-box .text .dotted-box .dotted' => 'background: {{VALUE}} !important',
					'{{WRAPPER}} .cta-section .inner-box .text:after' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->end_controls_section();
		$this->start_controls_section(
			'text_style_section',
			array(
				'label' => __( 'Text Style', 'visarzo-core-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'content_typography',
				'label'    => __( 'Typography', 'visarzo-core-core' ),
				'scheme'   => Schemes\Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .cta_section',
			)
		);
		$this->end_controls_section();

	}
	protected function render() {
		$settings = $this->get_settings_for_display();
		$title    = $settings['title'];
		$html_tag = $settings['html_tag'];
		$content  = $settings['content'];
		?> <!-- cta-section -->
		<section class="cta-section bg-color-1 centred">
			<div class="auto-container">
				<div class="inner-box">
				<<?php echo $html_tag; ?> class="cta_section"><?php echo $title; ?></<?php echo $html_tag; ?>>
					<div class="text">
						<p><?php echo $content; ?></p>
						<div class="dotted-box">
							<div class="dotted"></div>
							<div class="dotted"></div>
							<div class="dotted"></div>
							<div class="dotted"></div>
							<div class="dotted"></div>
							<div class="dotted"></div>
						</div>
					</div>
				</div>
			</div>
		</section>
		<!-- cta-section end --> 
		<?php
	}

	protected function content_templates() {
	}
}


