<?php
namespace Visarzo\Helper\Elementor\Widgets;

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use \Elementor\Repeater;
use Elementor\Core\Schemes;
use Visarzo\Helper\Elementor\Settings\Header;

class Visarzo_Contact_Form extends Widget_Base {

	public function get_name() {
		return 'visarzo_contact_form';
	}

	public function get_title() {
		return esc_html__( 'Visarzo Contact Form', 'visarzo-core' );
	}

	public function get_icon() {
		return 'fa fa-object-ungroup';
	}

	public function get_categories() {
		return array( 'visarzo' );
	}

	protected function register_controls() {

		$this->start_controls_section(
			'general',
			array(
				'label' => esc_html__( 'General', 'visarzo-core' ),
			)
		);
		$this->add_control(
			'layout_style',
			array(
				'label'   => esc_html__( 'Layout Style', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'style_1' => esc_html__( 'Style One', 'visarzo-core' ),
					'style_2' => esc_html__( 'Style Two', 'visarzo-core' ),

				),
				'default' => 'style_1',

			)
		);

		$this->add_control(
			'title',
			array(
				'label'       => esc_html__( 'Title', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),

			)
		);

		$this->add_control(
			'html_tag',
			array(
				'label'   => esc_html__( 'Html Tag', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'h1'   => esc_html__( 'H1', 'visarzo-core' ),
					'h2'   => esc_html__( 'H2', 'visarzo-core' ),
					'h3'   => esc_html__( 'H3', 'visarzo-core' ),
					'h4'   => esc_html__( 'H4', 'visarzo-core' ),
					'h5'   => esc_html__( 'H5', 'visarzo-core' ),
					'h6'   => esc_html__( 'H6', 'visarzo-core' ),
					'div'  => esc_html__( 'div', 'visarzo-core' ),
					'span' => esc_html__( 'span', 'visarzo-core' ),
					'p'    => esc_html__( 'p', 'visarzo-core' ),
				),
				'default' => 'h2',

			)
		);
		$this->add_control(
			'contact_cf7',
			array(
				'label'   => esc_html__( 'Select Contact Form', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => Header::getContactForm7Posts(),
			)
		);

		$this->end_controls_section();
		$this->start_controls_section(
			'style_section',
			array(
				'label' => __( 'Color', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->start_controls_tabs( 'tabs_button_style' );
		$this->start_controls_tab(
			'tab_button_normal',
			array(
				'label' => __( 'Normal', 'elementor' ),
			)
		);
		$this->add_control(
			'underline_color',
			array(
				'label'     => __( 'Underline Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .sec-title:before' => 'background: {{VALUE}} !important',
					'{{WRAPPER}} .sec-title .dotted-box .dotted' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'button_bg_color',
			array(
				'label'     => __( 'Button Background Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .theme-btn-two' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'button_text_color',
			array(
				'label'     => __( 'Button Text Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .theme-btn-two' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tab_button_hover',
			array(
				'label' => __( 'Hover', 'elementor' ),
			)
		);
		$this->add_control(
			'button_hover_color',
			array(
				'label'     => __( 'Button Background Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .theme-btn-two:after' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'button_text_hover_color',
			array(
				'label'     => __( 'Button Text Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .theme-btn-two:hover' => 'color: {{VALUE}} !important',

				),
			)
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		$this->start_controls_section(
			'text_style_section',
			array(
				'label' => __( 'Text Style', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'content_typography',
				'label'    => __( 'Typography', 'visarzo-core' ),
				'scheme'   => Schemes\Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .contact_page',
			)
		);
		$this->end_controls_section();

	}
	protected function render() {
		$settings     = $this->get_settings_for_display();
		$title        = $settings['title'];
		$html_tag     = $settings['html_tag'];
		$layout_style = $settings['layout_style'];
		?> <!-- contact-section -->
		<?php if ( $layout_style == 'style_1' ) : ?>
		<section class="contact-page-section">
			<div class="auto-container">
				

				<div class="contact-form-inner">
					<div class="sec-title centred">
					<<?php echo $html_tag; ?> class="contact_page"><?php echo $title; ?></<?php echo $html_tag; ?>>
						<div class="dotted-box">
							<span class="dotted"></span>
							<span class="dotted"></span>
							<span class="dotted"></span>
						</div>
					</div>
					<div class="form-inner">
					<?php

						static $v_veriable = 0;

						$settings = $this->get_settings();
					if ( ! empty( $settings['contact_cf7'] ) ) {
						echo '<div class="elementor-shortcode yachercore-contact_cf7-' . $v_veriable . '">';
						echo do_shortcode( '[contact-form-7 id="' . $settings['contact_cf7'] . '"]' );
						echo '</div>';
					}

					if ( ! empty( $settings['cf7_redirect_page'] ) || ! empty( $settings['contact_cf7_redirect_external'] ) ) {
						?>
							<script>
								var theform = document.querySelector('.visarzocore-contact_cf7-<?php echo $v_veriable; ?>');
								theform.addEventListener('wpcontact_cf7mailsent', function(event) {
									location = ' 
									<?php
									if ( ! empty( $settings['contact_cf7_redirect_external'] ) ) {
										echo $settings['contact_cf7_redirect_external'];
									} else {
										echo get_permalink( $settings['contact_cf7_redirect_page'] );
									}
									?>
									';
								}, false);
							</script>

							<?php
							$v_veriable++;
					}

					?>
					</div>
				</div>

			</div>
		</section>
		<?php elseif ( $layout_style == 'style_2' ) : ?>
			<section class="contact-page-section">
			<div class="auto-container">
				<div class="contact-form-inner">
					<div class="sec-title centred">
					<<?php echo $html_tag; ?> class="contact_page"><?php echo $title; ?></<?php echo $html_tag; ?>>
						<div class="dotted-box">
							<span class="dotted"></span>
							<span class="dotted"></span>
							<span class="dotted"></span>
						</div>
					</div>
					<div class="form-inner">
					<?php

						static $v_veriable = 0;

						$settings = $this->get_settings();
					if ( ! empty( $settings['contact_cf7'] ) ) {
						echo '<div class="elementor-shortcode yachercore-contact_cf7-' . $v_veriable . '">';
						echo do_shortcode( '[contact-form-7 id="' . $settings['contact_cf7'] . '"]' );
						echo '</div>';
					}

					if ( ! empty( $settings['cf7_redirect_page'] ) || ! empty( $settings['contact_cf7_redirect_external'] ) ) {
						?>
							<script>
								var theform = document.querySelector('.visarzocore-contact_cf7-<?php echo $v_veriable; ?>');
								theform.addEventListener('wpcontact_cf7mailsent', function(event) {
									location = ' 
									<?php
									if ( ! empty( $settings['contact_cf7_redirect_external'] ) ) {
										echo $settings['contact_cf7_redirect_external'];
									} else {
										echo get_permalink( $settings['contact_cf7_redirect_page'] );
									}
									?>
									';
								}, false);
							</script>

							<?php
							$v_veriable++;
					}

					?>
					</div>
				</div>
			</div>
		</section>

			<?php
		endif;
	}

	protected function content_templates() {

	}
}
