<?php
namespace Visarzo\Helper\Elementor\Widgets;

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use \Elementor\Repeater;
use Elementor\Core\Schemes;
use Visarzo\Helper\Elementor\Settings\Header;

class Visarzo_FAQ extends Widget_Base {




	public function get_name() {
		return 'visarzo_faq';
	}

	public function get_title() {
		return esc_html__( 'Visarzo FAQ', 'visarzo-core' );
	}

	public function get_icon() {
		return 'fa fa-object-ungroup';
	}

	public function get_categories() {
		return array( 'visarzo' );
	}

	protected function register_controls() {

		$this->start_controls_section(
			'general',
			array(
				'label' => esc_html__( 'General', 'visarzo-core' ),
			)
		);

		$this->add_control(
			'layout_style',
			array(
				'label'   => esc_html__( 'Layout Style', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'style_1' => esc_html__( 'Style One', 'visarzo-core' ),
					'style_2' => esc_html__( 'Style Two', 'visarzo-core' ),
					'style_3' => esc_html__( 'Style Three', 'visarzo-core' ),
					'style_4' => esc_html__( 'Style Four', 'visarzo-core' ),

				),
				'default' => 'style_1',

			)
		);

		$this->add_control(
			'tagline',
			array(
				'label'       => esc_html__( 'Tagline', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'HOW WE HELP CLIENTS', 'visarzo-core' ),
				'condition'   => array( 'layout_style' => 'style_1' ),
			)
		);

		$this->add_control(
			'title',
			array(
				'label'       => esc_html__( 'Title', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXTAREA,
				'conditions'  => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_1',
						),
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_2',
						),
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_4',
						),
					),
				),

			)
		);

		$this->add_control(
			'html_tag',
			array(
				'label'      => esc_html__( 'Html Tag', 'visarzo-core' ),
				'type'       => Controls_Manager::SELECT,
				'options'    => array(
					'h1'   => esc_html__( 'H1', 'visarzo-core' ),
					'h2'   => esc_html__( 'H2', 'visarzo-core' ),
					'h3'   => esc_html__( 'H3', 'visarzo-core' ),
					'h4'   => esc_html__( 'H4', 'visarzo-core' ),
					'h5'   => esc_html__( 'H5', 'visarzo-core' ),
					'h6'   => esc_html__( 'H6', 'visarzo-core' ),
					'div'  => esc_html__( 'div', 'visarzo-core' ),
					'span' => esc_html__( 'span', 'visarzo-core' ),
					'p'    => esc_html__( 'p', 'visarzo-core' ),
				),
				'default'    => 'h2',
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_1',
						),
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_2',
						),
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_4',
						),
					),
				),
			)
		);

		$this->add_control(
			'content',
			array(
				'label'       => esc_html__( 'Content', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),
				'condition'   => array( 'layout_style' => 'style_1' ),

			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'item',
			array(
				'label' => esc_html__( 'ITEM', 'visarzo-core' ),
			)
		);
		$this->add_control(
			'total_item',
			array(
				'label'       => esc_html__( 'Total Item', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
			)
		);

		$repeater = new Repeater();
		$repeater->add_control(
			'item_question',
			array(
				'label'       => esc_html__( 'Question', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),

			)
		);

		$repeater->add_control(
			'item_answer',
			array(
				'label'       => esc_html__( 'Answer', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),

			)
		);

		$this->add_control(
			'items',
			array(
				'label'   => esc_html__( 'Repeater List', 'visarzo-core' ),
				'type'    => Controls_Manager::REPEATER,
				'fields'  => $repeater->get_controls(),
				'default' => array(
					array(
						'list_title'   => esc_html__( 'Title #1', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
					array(
						'list_title'   => esc_html__( 'Title #2', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
				),
			)
		);

		$this->end_controls_section();
		$this->start_controls_section(
			'style_section',
			array(
				'label' => __( 'Color', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_control(
			'underline_color',
			array(
				'label'     => __( 'Underline Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .sec-title:before' => 'background: {{VALUE}} !important',
					'{{WRAPPER}} .sec-title .dotted-box .dotted' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'active_color',
			array(
				'label'     => __( 'Border Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .accordion-box .block .acc-btn.active h5' => 'color:{{VALUE}} !important',

				),
			)
		);
		$this->end_controls_section();
		$this->start_controls_section(
			'text_style_section',
			array(
				'label' => __( 'Text Style', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'content_typography',
				'label'    => __( 'Typography', 'visarzo-core' ),
				'scheme'   => Schemes\Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .faq',
			)
		);
		$this->end_controls_section();
	}
	protected function render() {
		$settings     = $this->get_settings_for_display();
		$layout_style = $settings['layout_style'];
		if ( $layout_style == 'style_1' || $layout_style == 'style_2' || $layout_style == 'style_4' ) :
			$title    = $settings['title'];
			$html_tag = $settings['html_tag'];

		endif;
		$total_item = $settings['total_item'];
		?>
		<!-- faq-section -->
		<?php if ( $layout_style == 'style_1' || $layout_style == 'style_3' ) : ?>
		<section class="faq-section">
			<div class="auto-container">
			<?php
			if ( $layout_style == 'style_1' ) :
				$tagline = $settings['tagline'];
				$content = $settings['content'];
				?>
				<div class="top-inner">
					<div class="row clearfix">
						<div class="col-lg-5 col-md-12 col-sm-12 title-column">
							<div class="sec-title">
								<p><?php echo $tagline; ?></p>
								<<?php echo $html_tag; ?> class="faq"><?php echo $title; ?></<?php echo $html_tag; ?>>
								<div class="dotted-box">
									<span class="dotted"></span>
									<span class="dotted"></span>
									<span class="dotted"></span>
								</div>
							</div>
						</div>
						<div class="col-lg-7 col-md-12 col-sm-12 text-column">
							<div class="text">
								<p><?php echo $content; ?></p>
							</div>
						</div>
					</div>
				</div>
			<?php endif; ?>
				<div class="row clearfix">
			<?php
			$count = 1;
			$i     = 0;
			foreach ( $settings['items'] as $item ) {
				$item_question = $item['item_question'];
				$item_answer   = $item['item_answer'];
				$activeblock   = '';
				$active        = '';
				$current       = '';
				if ( $i == 0 ) :
					$activeblock = 'active-block';
					$active      = 'active';
					$current     = 'current';
				endif;
				?>
				<?php if ( $count == 1 ) { ?>
					<div class="col-lg-6 col-md-12 col-sm-12 faq-column">
						<ul class="accordion-box">
				<?php } ?>

							<li class="accordion block <?php echo $activeblock; ?>">
								<div class="acc-btn <?php echo $active; ?>">
									<div class="icon-outer"><i class="fas fa-angle-down"></i></div>
									<h5><?php echo $item_question; ?></h5>
								</div>
								<div class="acc-content <?php echo $current; ?>">
									<p><?php echo $item_answer; ?></p>
								</div>
							</li>
				<?php if ( $count == $total_item ) { ?>    
						</ul>
					</div>
					<?php
					$count = 0;
				}
				$count++;
				$i++;
			}
			?>
				</div>
			</div>
		</section>
		<?php elseif ( $layout_style == 'style_2' ) : ?>  
		<!-- faq-style-two -->
		<section class="faq-section style-two">
			<div class="auto-container">
				<div class="inner-box">
				<<?php echo $html_tag; ?> class="faq"><?php echo $title; ?></<?php echo $html_tag; ?>>
					<ul class="accordion-box">
						<?php
						$i = 0;
						foreach ( $settings['items'] as $item ) {
							$item_question = $item['item_question'];
							$item_answer   = $item['item_answer'];
							$activeblock   = '';
							$active        = '';
							$current       = '';
							if ( $i == 0 ) :
								$activeblock = 'active-block';
								$active      = 'active';
								$current     = 'current';
							endif;
							?>
							<li class="accordion block <?php echo $activeblock; ?>">
								<div class="acc-btn <?php echo $active; ?>">
									<div class="icon-outer"><i class="fas fa-angle-down"></i></div>
									<h5><?php echo $item_question; ?></h5>
								</div>
								<div class="acc-content <?php echo $current; ?>">
									<p><?php echo $item_answer; ?></p>
								</div>
							</li> 
							<?php
							$i++;
						}
						?>

					</ul>
				</div>
			</div>
		</section>
		<?php elseif ( $layout_style == 'style_4' ) : ?>  
		<div class="accordion-content">
		<<?php echo $html_tag; ?> class="faq"><?php echo $title; ?></<?php echo $html_tag; ?>>
			<ul class="accordion-box">
			<?php
			$count = 0;
			foreach ( $settings['items'] as $item ) {
				$item_question = $item['item_question'];
				$item_answer   = $item['item_answer'];
				$activeblock   = '';
				$active        = '';
				$current       = '';
				if ( $count == 0 ) :
					$activeblock = 'active-block';
					$active      = 'active';
					$current     = 'current';
				endif;
				?>
				<li class="accordion block <?php echo $activeblock; ?>">
					<div class="acc-btn <?php echo $active; ?>">
						<div class="icon-outer"><i class="fas fa-angle-down"></i></div>
						<h5><?php echo $item_question; ?></h5>
					</div>
					<div class="acc-content <?php echo $current; ?>">
						<p><?php echo $item_answer; ?></p>
					</div>
				</li>
				<?php
				$count++;
			}
			?>
			</ul>
		</div>
		<?php endif; ?>
		<!-- faq-style-two end -->
		<?php
	}

	protected function content_templates() {
	}
}
