<?php
namespace Visarzo\Helper\Elementor\Widgets;

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use \Elementor\Repeater;
use Visarzo\Helper\Elementor\Settings\Header;
use Elementor\Core\Schemes;

class Visarzo_Feature extends Widget_Base {


	public function get_name() {
		return 'visarzo_feature';
	}

	public function get_title() {
		return esc_html__( 'Visarzo Feature', 'visarzo-core' );
	}

	public function get_icon() {
		return 'fa fa-object-ungroup';
	}

	public function get_categories() {
		return array( 'visarzo' );
	}
	public function get_script_depends() {
		return array( 'training' );
	}

	protected function register_controls() {

		$this->start_controls_section(
			'general',
			array(
				'label' => esc_html__( 'General', 'visarzo-core' ),
			)
		);

		$this->add_control(
			'layout_style',
			array(
				'label'   => esc_html__( 'Layout Style', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'style_1' => esc_html__( 'Style One', 'visarzo-core' ),
					'style_2' => esc_html__( 'Style Two', 'visarzo-core' ),
					'style_3' => esc_html__( 'Style Three', 'visarzo-core' ),
					'style_4' => esc_html__( 'Style Four', 'visarzo-core' ),

				),
				'default' => 'style_1',

			)
		);

		$this->add_control(
			'read_button_name',
			array(
				'label'       => esc_html__( 'Read Button Name', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'Read More', 'visarzo-core' ),
			)
		);
		$this->add_control(
			'extra_class',
			array(
				'label'       => esc_html__( 'Extra Class', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'sec-pad-2', 'visarzo-core' ),
			)
		);
		$this->end_controls_section();

		$this->start_controls_section(
			'item',
			array(
				'label' => esc_html__( 'ITEM', 'visarzo-core' ),
			)
		);
		Header::visarzo_coloumn_control( $this, 6, 2 );

		$repeater = new Repeater();

		$repeater->add_control(
			'item_title',
			array(
				'label'       => esc_html__( 'Title', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
			)
		);
		Header::visarzo_get_wow_animation_control( $repeater );

		$repeater->add_control(
			'item_html_tag',
			array(
				'label'   => esc_html__( 'Html Tag', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'h1'   => esc_html__( 'H1', 'visarzo-core' ),
					'h2'   => esc_html__( 'H2', 'visarzo-core' ),
					'h3'   => esc_html__( 'H3', 'visarzo-core' ),
					'h4'   => esc_html__( 'H4', 'visarzo-core' ),
					'h5'   => esc_html__( 'H5', 'visarzo-core' ),
					'h6'   => esc_html__( 'H6', 'visarzo-core' ),
					'div'  => esc_html__( 'div', 'visarzo-core' ),
					'span' => esc_html__( 'span', 'visarzo-core' ),
					'p'    => esc_html__( 'p', 'visarzo-core' ),
				),
				'default' => 'h3',

			)
		);

		$repeater->add_control(
			'item_image',
			array(
				'label'   => esc_html__( 'Image', 'visarzo-core' ),
				'type'    => Controls_Manager::MEDIA,
				'default' => array(
					'url' => Utils::get_placeholder_image_src(),
				),

			)
		);

		$repeater->add_control(
			'item_icon',
			array(
				'label' => esc_html__( 'Icon', 'visarzo-core' ),
				'type'  => Controls_Manager::ICONS,
			)
		);

		$repeater->add_control(
			'item_content',
			array(
				'label'       => esc_html__( 'Content', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),

			)
		);

		$repeater->add_control(
			'item_page_link',
			array(
				'label'         => esc_html__( 'Page Link', 'visarzo-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => esc_html__( 'https://your-link.com', 'visarzo-core' ),
				'show_external' => true,
				'default'       => array(
					'url'         => '#',
					'is_external' => true,
					'nofollow'    => true,
				),

			)
		);

		$repeater->add_control(
			'item_button_name',
			array(
				'label'       => esc_html__( 'Button Name', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'Read More', 'visarzo-core' ),
			)
		);

		$this->add_control(
			'items',
			array(
				'label'   => esc_html__( 'Repeater List', 'visarzo-core' ),
				'type'    => Controls_Manager::REPEATER,
				'fields'  => $repeater->get_controls(),
				'default' => array(
					array(
						'list_title'   => esc_html__( 'Title #1', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
					array(
						'list_title'   => esc_html__( 'Title #2', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
				),
			)
		);

		$this->end_controls_section();
		$this->start_controls_section(
			'style_section',
			array(
				'label' => __( 'Color', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->start_controls_tabs( 'tabs_button_style' );
		$this->start_controls_tab(
			'tab_button_normal',
			array(
				'label' => __( 'Normal', 'elementor' ),
			)
		);
		$this->add_control(
			'background_color',
			array(
				'label'     => __( 'Background Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .feature-block-two .inner-box' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'title_color',
			array(
				'label'     => __( 'Title Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} h3 a:hover' => 'color: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'text_color',
			array(
				'label'     => __( 'Text Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .feature-block-two .inner-box:hover .title-inner .icon-box, .feature-block-two .inner-box:hover .title-inner h3, .feature-block-two .inner-box .text p' => 'color: {{VALUE}} !important',

				),
			)
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tab_button_hover',
			array(
				'label' => __( 'Hover', 'elementor' ),
			)
		);
		$this->add_control(
			'hover_bg_color',
			array(
				'label'     => __( 'Background Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .feature-block-two .inner-box:before' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'hover_text_color',
			array(
				'label'     => __( 'Text Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .feature-block-two .inner-box:hover .title-inner .icon-box, .feature-block-two .inner-box:hover .title-inner h3, .feature-block-two .inner-box:hover .text p' => 'color: {{VALUE}} !important',

				),
			)
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		$this->start_controls_section(
			'text_style_section',
			array(
				'label' => __( 'Text Style', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'content_typography',
				'label'    => __( 'Typography', 'visarzo-core' ),
				'scheme'   => Schemes\Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .feature',
			)
		);
		$this->end_controls_section();
	}
	protected function render() {
		$settings         = $this->get_settings_for_display();
		$layout_style     = $settings['layout_style'];
		$read_button_name = $settings['read_button_name'];
		$extra_class      = $settings['extra_class'];
		?>
		<!-- feature-section -->
		<?php if ( $layout_style == 'style_1' ) : ?>
			<section class="feature-section <?php echo esc_attr( $extra_class ); ?>">
				<div class="auto-container">
					<div class="row clearfix">
					<?php
							$i = 1;
					foreach ( $settings['items'] as $item ) {
						$item_title    = $item['item_title'];
						$item_html_tag = $item['item_html_tag'];
						$item_image    = ( $item['item_image']['id'] != '' ) ? wp_get_attachment_image_url( $item['item_image']['id'], 'full' ) : $item['item_image']['url'];
						if ( ! empty( $item_image ) ) {
							$this->add_render_attribute( 'item_image', 'src', $item_image );
							$this->add_render_attribute( 'item_image', 'alt', \Elementor\Control_Media::get_image_alt( $item['item_image'] ) );
							$this->add_render_attribute( 'item_image', 'title', \Elementor\Control_Media::get_image_title( $item['item_image'] ) );
							$item_image_html = \Elementor\Group_Control_Image_Size::get_attachment_image_html( $item, 'full', 'item_image' );
						}
						$item_icon    = $item['item_icon'];
						$item_content = $item['item_content'];

						$item_page_link          = $item['item_page_link'];
						$item_page_link_target   = $item['item_page_link']['is_external'] ? ' target="_blank"' : '';
						$item_page_link_nofollow = $item['item_page_link']['nofollow'] ? ' rel="nofollow"' : '';

						$item_button_name = $item['item_button_name'];
						$animation_class  = $item['animation_class'];
						$duration_time    = $item['duration_time'];
						$delay_time       = $item['delay_time'];
						?>
						<div class="<?php echo Header::visarzo_coloumn( $this, $settings ); ?> col-md-6 col-sm-12 feature-block">
							<div class="feature-block-one wow <?php echo $animation_class; ?> animated animated" data-wow-delay="<?php echo $delay_time; ?>" data-wow-duration="<?php echo $duration_time; ?>">
								<div class="inner-box">
									<figure class="image-box"><?php echo $item_image_html; ?></figure>
									<div class="text">
										<h3><a href="<?php echo esc_url( $item_page_link['url'] ); ?>" <?php echo $item_page_link_target . ' ' . $item_page_link_nofollow; ?>><?php echo $item_title; ?></a></h3>
									</div>
								</div>
							</div>
						</div>
						<?php } ?>
					</div>
				</div>
			</section>
			<!-- feature-section end -->
		<?php elseif ( $layout_style == 'style_2' ) : ?>
			<!-- feature-style-two -->
			<section class="feature-style-two <?php echo esc_attr( $extra_class ); ?>">
				<div class="auto-container">
					<?php if ( empty( $extra_class ) ) : ?>
					<div class="inner-container">
					<?php endif; ?>
						<div class="row clearfix">
							<?php
							$i = 1;
							foreach ( $settings['items'] as $item ) {
								$item_title    = $item['item_title'];
								$item_html_tag = $item['item_html_tag'];
								$item_image    = ( $item['item_image']['id'] != '' ) ? wp_get_attachment_image_url( $item['item_image']['id'], 'full' ) : $item['item_image']['url'];
								if ( ! empty( $item_image ) ) {
									$this->add_render_attribute( 'item_image', 'src', $item_image );
									$this->add_render_attribute( 'item_image', 'alt', \Elementor\Control_Media::get_image_alt( $item['item_image'] ) );
									$this->add_render_attribute( 'item_image', 'title', \Elementor\Control_Media::get_image_title( $item['item_image'] ) );
									$item_image_html = \Elementor\Group_Control_Image_Size::get_attachment_image_html( $item, 'full', 'item_image' );
								}
								$item_icon               = $item['item_icon'];
								$item_content            = $item['item_content'];
								$item_page_link          = $item['item_page_link'];
								$item_page_link_target   = $item['item_page_link']['is_external'] ? ' target="_blank"' : '';
								$item_page_link_nofollow = $item['item_page_link']['nofollow'] ? ' rel="nofollow"' : '';
								$item_button_name        = $item['item_button_name'];
								?>
							 <div class="<?php echo Header::visarzo_coloumn( $this, $settings ); ?> col-md-6 col-sm-12 feature-block">
									<div class="feature-block-two">
										<div class="inner-box">
											<div class="title-inner">
												<div class="icon-box"><?php \Elementor\Icons_Manager::render_icon( ( $item_icon ), array( 'aria-hidden' => 'true' ) ); ?></div>
												<<?php echo $item_html_tag; ?> class="feature"><?php echo $item_title; ?></<?php echo $item_html_tag; ?>>
											</div>
											<div class="text">
												<p><?php echo $item_content; ?></p>
											</div>
											<div class="link"><a href="<?php echo esc_url( $item_page_link['url'] ); ?>" <?php echo $item_page_link_target . ' ' . $item_page_link_nofollow; ?>><span><?php echo $item_button_name; ?></span><i class="flaticon-send"></i></a></div>
										</div>
									</div>
								</div> <?php } ?>

						</div>
						<?php if ( empty( $extra_class ) ) : ?>
					</div>
					<?php endif; ?>
				</div>
			</section>
			<?php elseif ( $layout_style == 'style_3' ) : ?>
			<section class="feature-style-two sec-pad-2">
				<div class="auto-container">
					<div class="three-item-carousel owl-carousel owl-theme owl-dots-none owl-nav-none">
						<?php
							$i = 1;
						foreach ( $settings['items'] as $item ) {
							$item_title    = $item['item_title'];
							$item_html_tag = $item['item_html_tag'];
							$item_image    = ( $item['item_image']['id'] != '' ) ? wp_get_attachment_image_url( $item['item_image']['id'], 'full' ) : $item['item_image']['url'];
							if ( ! empty( $item_image ) ) {
								$this->add_render_attribute( 'item_image', 'src', $item_image );
								$this->add_render_attribute( 'item_image', 'alt', \Elementor\Control_Media::get_image_alt( $item['item_image'] ) );
								$this->add_render_attribute( 'item_image', 'title', \Elementor\Control_Media::get_image_title( $item['item_image'] ) );
								$item_image_html = \Elementor\Group_Control_Image_Size::get_attachment_image_html( $item, 'full', 'item_image' );
							}
							$item_icon               = $item['item_icon'];
							$item_content            = $item['item_content'];
							$item_page_link          = $item['item_page_link'];
							$item_page_link_target   = $item['item_page_link']['is_external'] ? ' target="_blank"' : '';
							$item_page_link_nofollow = $item['item_page_link']['nofollow'] ? ' rel="nofollow"' : '';
							$item_button_name        = $item['item_button_name'];
							?>
									
						<div class="feature-block-two">
							<div class="inner-box">
								<div class="title-inner">
									<div class="icon-box"><?php \Elementor\Icons_Manager::render_icon( ( $item_icon ), array( 'aria-hidden' => 'true' ) ); ?></div>
									<<?php echo $item_html_tag; ?> class="feature"><?php echo $item_title; ?></<?php echo $item_html_tag; ?>>
								</div>
								<div class="text">
									<p><?php echo $item_content; ?></p>
								</div>
								<div class="link"><a href="<?php echo esc_url( $item_page_link['url'] ); ?>" <?php echo $item_page_link_target . ' ' . $item_page_link_nofollow; ?>><span><?php echo $item_button_name; ?></span><i class="flaticon-send"></i></a></div>
							</div>
						</div>
					<?php } ?>	

					</div>
				</div>
			</section>
			<?php elseif ( $layout_style == 'style_4' ) : ?>
			<section class="feature-section sec-pad-2">
			<div class="auto-container">
				<div class="three-item-carousel owl-carousel owl-theme owl-dots-none owl-nav-none">
				<?php
							$i = 1;
				foreach ( $settings['items'] as $item ) {
					$item_title    = $item['item_title'];
					$item_html_tag = $item['item_html_tag'];
					$item_image    = ( $item['item_image']['id'] != '' ) ? wp_get_attachment_image_url( $item['item_image']['id'], 'full' ) : $item['item_image']['url'];
					if ( ! empty( $item_image ) ) {
						$this->add_render_attribute( 'item_image', 'src', $item_image );
						$this->add_render_attribute( 'item_image', 'alt', \Elementor\Control_Media::get_image_alt( $item['item_image'] ) );
						$this->add_render_attribute( 'item_image', 'title', \Elementor\Control_Media::get_image_title( $item['item_image'] ) );
						$item_image_html = \Elementor\Group_Control_Image_Size::get_attachment_image_html( $item, 'full', 'item_image' );
					}
					$item_icon               = $item['item_icon'];
					$item_content            = $item['item_content'];
					$item_page_link          = $item['item_page_link'];
					$item_page_link_target   = $item['item_page_link']['is_external'] ? ' target="_blank"' : '';
					$item_page_link_nofollow = $item['item_page_link']['nofollow'] ? ' rel="nofollow"' : '';
					$item_button_name        = $item['item_button_name'];
					?>
					<div class="feature-block-one mb-30">
						<div class="inner-box">
							<figure class="image-box"><?php echo $item_image_html; ?></figure>
							<div class="text">
								<h3><a href="<?php echo esc_url( $item_page_link['url'] ); ?>" <?php echo $item_page_link_target . ' ' . $item_page_link_nofollow; ?>><?php echo $item_title; ?></a></h3>
							</div>
						</div>
					</div>
				<?php } ?>
					
				</div>
			</div>
		</section>
		<?php endif; ?>
		<!-- feature-style-two end --> 
		<?php
	}

	protected function content_templates() {
	}
}
