<?php
namespace Visarzo\Helper\Elementor\Widgets;

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use \Elementor\Repeater;
use Visarzo\Helper\Elementor\Settings\Header;
use Elementor\Core\Schemes;

class Visarzo_Funfact extends Widget_Base {


	public function get_name() {
		return 'visarzo_funfact';
	}

	public function get_title() {
		return esc_html__( 'Visarzo Funfact', 'visarzo-core' );
	}

	public function get_icon() {
		return 'fa fa-object-ungroup';
	}

	public function get_categories() {
		return array( 'visarzo' );
	}
	public function get_script_depends() {
		return array( 'training' );
	}

	protected function register_controls() {

		$this->start_controls_section(
			'item',
			array(
				'label' => esc_html__( 'ITEM', 'visarzo-core' ),
			)
		);
		$this->add_control(
			'layout_style',
			array(
				'label'   => esc_html__( 'Layout Style', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'style_1' => esc_html__( 'Style One', 'visarzo-core' ),
					'style_2' => esc_html__( 'Style Two', 'visarzo-core' ),
					'style_3' => esc_html__( 'Style Three', 'visarzo-core' ),

				),
				'default' => 'style_1',

			)
		);
		Header::visarzo_coloumn_control( $this, 6, 2 );

		$repeater = new Repeater();
		Header::visarzo_get_wow_animation_control( $repeater );
		$repeater->add_control(
			'item_title',
			array(
				'label'       => esc_html__( 'Title', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'We Have Worked With Clients', 'visarzo-core' ),
			)
		);

		$repeater->add_control(
			'item_html_tag',
			array(
				'label'   => esc_html__( 'Heading Tag', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'h1'   => esc_html__( 'H1', 'visarzo-core' ),
					'h2'   => esc_html__( 'H2', 'visarzo-core' ),
					'h3'   => esc_html__( 'H3', 'visarzo-core' ),
					'h4'   => esc_html__( 'H4', 'visarzo-core' ),
					'h5'   => esc_html__( 'H5', 'visarzo-core' ),
					'h6'   => esc_html__( 'H6', 'visarzo-core' ),
					'div'  => esc_html__( 'div', 'visarzo-core' ),
					'span' => esc_html__( 'span', 'visarzo-core' ),
					'p'    => esc_html__( 'p', 'visarzo-core' ),
				),
				'default' => 'h3',

			)
		);

		$repeater->add_control(
			'item_icon',
			array(
				'label' => esc_html__( 'Icon', 'visarzo-core' ),
				'type'  => Controls_Manager::ICONS,
			)
		);

		$repeater->add_control(
			'item_amount',
			array(
				'label'       => esc_html__( 'Amount', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
			)
		);

		$repeater->add_control(
			'item_post_text',
			array(
				'label'       => esc_html__( 'Post Text', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
			)
		);

		$this->add_control(
			'items',
			array(
				'label'   => esc_html__( 'Repeater List', 'visarzo-core' ),
				'type'    => Controls_Manager::REPEATER,
				'fields'  => $repeater->get_controls(),
				'default' => array(
					array(
						'list_title'   => esc_html__( 'Title #1', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
					array(
						'list_title'   => esc_html__( 'Title #2', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
				),
			)
		);

		$this->end_controls_section();
		$this->start_controls_section(
			'style_section',
			array(
				'label' => __( 'Color', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_control(
			'background_color',
			array(
				'label'     => __( 'Background Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .funfact-style-two .inner-container' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'container_color',
			array(
				'label'     => __( 'Title/Icon/Counter Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .counter-block-two .inner-box h4' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .counter-block-two .inner-box .count-outer' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .counter-block-two .inner-box .icon-box' => 'color: {{VALUE}} !important',

				),
			)
		);
		$this->end_controls_section();
		$this->start_controls_section(
			'text_style_section',
			array(
				'label' => __( 'Text Style', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'content_typography',
				'label'    => __( 'Typography', 'visarzo-core' ),
				'scheme'   => Schemes\Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .headingtwo',
			)
		);
		$this->end_controls_section();
	}
	protected function render() {
		$settings     = $this->get_settings_for_display();
		$layout_style = $settings['layout_style'];
		?>
		<!-- funfact-section -->
		<?php if ( $layout_style == 'style_1' ) : ?>
		<section class="funfact-section centred">
			<div class="auto-container">
				<div class="row clearfix">
				<?php
						$i = 1;
				foreach ( $settings['items'] as $item ) {
					$item_title     = $item['item_title'];
					$item_html_tag  = $item['item_html_tag'];
					$item_icon      = $item['item_icon'];
					$item_amount    = $item['item_amount'];
					$item_post_text = $item['item_post_text'];

					$animation_class = $item['animation_class'];
					$duration_time   = $item['duration_time'];
					$delay_time      = $item['delay_time'];
					?>
					<div class="<?php echo Header::visarzo_coloumn( $this, $settings ); ?> col-md-6 col-sm-12 counter-block">
						<div class="counter-block-one wow <?php echo $animation_class; ?> animated animated" data-wow-delay="<?php echo $delay_time; ?>" data-wow-duration="<?php echo $duration_time; ?>">
							<div class="inner-box">
								<div class="count-outer count-box">
								<span class="count-text" data-speed="1500" data-stop="<?php echo $item_amount; ?>">0</span><span><?php echo $item_post_text; ?></span>
								</div>
								<<?php echo $item_html_tag; ?> class="headingtwo"><?php echo $item_title; ?></<?php echo $item_html_tag; ?>>
							</div>
						</div>
					</div>
					<?php } ?>
				</div>
			</div>
		</section>
		<!-- funfact-section end -->
		<?php elseif ( $layout_style == 'style_2' ) : ?>
		<!-- funfact-style-two -->
		<section class="funfact-style-two">
			<div class="auto-container">
				<div class="inner-container wow fadeInLeft animated animated" data-wow-delay="00ms" data-wow-duration="1500ms">
					<div class="row clearfix">
						<?php
						$i = 1;
						foreach ( $settings['items'] as $item ) {
							$item_title     = $item['item_title'];
							$item_html_tag  = $item['item_html_tag'];
							$item_icon      = $item['item_icon'];
							$item_amount    = $item['item_amount'];
							$item_post_text = $item['item_post_text'];
							?>
							<div class="<?php echo Header::visarzo_coloumn( $this, $settings ); ?> col-md-6 col-sm-12 counter-block">
								<div class="counter-block-two">
									<div class="inner-box">
										<div class="icon-box"><?php \Elementor\Icons_Manager::render_icon( ( $item_icon ), array( 'aria-hidden' => 'true' ) ); ?></div>
										<div class="count-outer count-box">
											<span class="count-text" data-speed="1500" data-stop="<?php echo $item_amount; ?>">0</span><span><?php echo $item_post_text; ?></span>
										</div>
										<<?php echo $item_html_tag; ?> class="headingtwo"><?php echo $item_title; ?></<?php echo $item_html_tag; ?>>
									</div>
								</div>
							</div> <?php } ?>

					</div>
				</div>
			</div>
		</section>
		<?php elseif ( $layout_style == 'style_3' ) : ?>
		<section class="funfact-section centred">
			<div class="auto-container">
				<div class="three-item-carousel owl-carousel owl-theme owl-dots-none owl-nav-none">
				<?php
						$i = 1;
				foreach ( $settings['items'] as $item ) {
					$item_title     = $item['item_title'];
					$item_html_tag  = $item['item_html_tag'];
					$item_icon      = $item['item_icon'];
					$item_amount    = $item['item_amount'];
					$item_post_text = $item['item_post_text'];
					?>
					<div class="counter-block-one">
						<div class="inner-box">
							<div class="count-outer count-box">
								<span class="count-text" data-speed="1500" data-stop="<?php echo $item_amount; ?>">0</span><span><?php echo $item_post_text; ?></span>
							</div>
							<<?php echo $item_html_tag; ?> class="headingtwo"><?php echo $item_title; ?></<?php echo $item_html_tag; ?>>
						</div>
					</div>
				<?php } ?>
				</div>
			</div>
		</section>
						<?php endif; ?>
		<!-- funfact-style-two end -->
		<?php
	}

	protected function content_templates() {
	}
}
