<?php
namespace Visarzo\Helper\Elementor\Widgets;

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use \Elementor\Repeater;
use Visarzo\Helper\Elementor\Settings\Header;
use Elementor\Core\Schemes;

class Visarzo_Immigration extends Widget_Base {


	public function get_name() {
		return 'visarzo_immigration';
	}

	public function get_title() {
		return esc_html__( 'Visarzo Immigration', 'visarzo-core' );
	}

	public function get_icon() {
		return 'fa fa-object-ungroup';
	}

	public function get_categories() {
		return array( 'visarzo' );
	}
	public function get_script_depends() {
		return array( 'immigration' );
	}

	protected function register_controls() {
		$this->start_controls_section(
			'general',
			array(
				'label' => esc_html__( 'General', 'visarzo-core' ),
			)
		);

		$this->add_control(
			'tagline',
			array(
				'label'       => esc_html__( 'Tagline', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'countries we offer support', 'visarzo-core' ),
			)
		);

		$this->add_control(
			'title',
			array(
				'label'       => esc_html__( 'Title', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'     => __( 'Immigration &amp; Visa Services <br>Following Countries', 'visarzo-core' ),
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),

			)
		);

		$this->add_control(
			'html_tag',
			array(
				'label'   => esc_html__( 'Html Tag', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'h1'   => esc_html__( 'H1', 'visarzo-core' ),
					'h2'   => esc_html__( 'H2', 'visarzo-core' ),
					'h3'   => esc_html__( 'H3', 'visarzo-core' ),
					'h4'   => esc_html__( 'H4', 'visarzo-core' ),
					'h5'   => esc_html__( 'H5', 'visarzo-core' ),
					'h6'   => esc_html__( 'H6', 'visarzo-core' ),
					'div'  => esc_html__( 'div', 'visarzo-core' ),
					'span' => esc_html__( 'span', 'visarzo-core' ),
					'p'    => esc_html__( 'p', 'visarzo-core' ),
				),
				'default' => 'h2',

			)
		);
		$this->end_controls_section();

		$this->start_controls_section(
			'item',
			array(
				'label' => esc_html__( 'ITEM', 'visarzo-core' ),
			)
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'item_image',
			array(
				'label'   => esc_html__( 'Image', 'visarzo-core' ),
				'type'    => Controls_Manager::MEDIA,
				'default' => array(
					'url' => Utils::get_placeholder_image_src(),
				),

			)
		);

		$repeater->add_control(
			'item_tagline',
			array(
				'label'       => esc_html__( 'Tagline', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'COUNTRIES WE OFFER SUPPORT', 'visarzo-core' ),
			)
		);

		$repeater->add_control(
			'item_title',
			array(
				'label'       => esc_html__( 'Title', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'     => __( 'Immigration &amp; Visa Services <br>Following Countries', 'visarzo-core' ),
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),

			)
		);

		$repeater->add_control(
			'item_html_tag',
			array(
				'label'   => esc_html__( 'Html Tag', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'h1'   => esc_html__( 'H1', 'visarzo-core' ),
					'h2'   => esc_html__( 'H2', 'visarzo-core' ),
					'h3'   => esc_html__( 'H3', 'visarzo-core' ),
					'h4'   => esc_html__( 'H4', 'visarzo-core' ),
					'h5'   => esc_html__( 'H5', 'visarzo-core' ),
					'h6'   => esc_html__( 'H6', 'visarzo-core' ),
					'div'  => esc_html__( 'div', 'visarzo-core' ),
					'span' => esc_html__( 'span', 'visarzo-core' ),
					'p'    => esc_html__( 'p', 'visarzo-core' ),
				),
				'default' => 'h2',

			)
		);

		$repeater->add_control(
			'item_button_name',
			array(
				'label'       => esc_html__( 'Button Name', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'Get Started', 'visarzo-core' ),
			)
		);

		$repeater->add_control(
			'item_button_link',
			array(
				'label'         => esc_html__( 'Button Link', 'visarzo-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => esc_html__( 'https://your-link.com', 'visarzo-core' ),
				'show_external' => true,
				'default'       => array(
					'url'         => '',
					'is_external' => true,
					'nofollow'    => true,
				),

			)
		);

		$this->add_control(
			'items',
			array(
				'label'   => esc_html__( 'Repeater List', 'visarzo-core' ),
				'type'    => Controls_Manager::REPEATER,
				'fields'  => $repeater->get_controls(),
				'default' => array(
					array(
						'list_title'   => esc_html__( 'Title #1', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
					array(
						'list_title'   => esc_html__( 'Title #2', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
				),
			)
		);

		$this->end_controls_section();
		$this->start_controls_section(
			'style_section',
			array(
				'label' => __( 'Color', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->start_controls_tabs( 'tabs_button_style' );
		$this->start_controls_tab(
			'tab_button_normal',
			array(
				'label' => __( 'Normal', 'elementor' ),
			)
		);
		$this->add_control(
			'underline_color',
			array(
				'label'     => __( 'Underline Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .sec-title:before' => 'background: {{VALUE}} !important',
					'{{WRAPPER}} .sec-title .dotted-box .dotted' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'border_color',
			array(
				'label'     => __( 'Border Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .immigration-section .more-text h3 a span' => 'border-bottom: 1px solid {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'border_icon_color',
			array(
				'label'     => __( 'Button Icon Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .theme-btn-one i' => 'color: {{VALUE}} !important',

				),
			)
		);

		$this->add_control(
			'btn_color',
			array(
				'label'     => __( 'Button Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .immigration-block-two .inner-box .content-box .theme-btn-one' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'btn_text_color',
			array(
				'label'     => __( 'Slider Button Text Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .theme-btn-one' => 'color: {{VALUE}} !important',

				),
			)
		);

		$this->add_control(
			'button_text_color',
			array(
				'label'     => __( 'Bottom Text Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .immigration-section .more-text h3 a span' => 'color: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'button_border_color',
			array(
				'label'     => __( 'Button Border Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .immigration-block-two .inner-box .content-box .theme-btn-one' => 'border:2px solid {{VALUE}} !important',

				),
			)
		);

		$this->end_controls_tab();
		$this->start_controls_tab(
			'tab_button_hover',
			array(
				'label' => __( 'Hover', 'elementor' ),
			)
		);
		$this->add_control(
			'hover_btn_color',
			array(
				'label'     => __( 'Button Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .theme-btn-one:after' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'hover_btn_text_color',
			array(
				'label'     => __( 'Button Text/Icon Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .theme-btn-one:hover'   => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .theme-btn-one:hover i' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .immigration-section .more-text h3 a:hover span' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .immigration-section .more-text h3 a i' => 'color: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'hover_button_border_color',
			array(
				'label'     => __( 'Button Border Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .immigration-block-two .inner-box .content-box .theme-btn-one:hover' => 'border:2px solid {{VALUE}} !important',
					'{{WRAPPER}} .immigration-section .more-text h3 a:hover span' => 'border-color: {{VALUE}} !important',

				),
			)
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		$this->start_controls_section(
			'text_style_section',
			array(
				'label' => __( 'Text Style', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'content_typography',
				'label'    => __( 'Typography', 'visarzo-core' ),
				'scheme'   => Schemes\Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .immigration',
			)
		);
		$this->end_controls_section();
	}
	protected function render() {
		$settings = $this->get_settings_for_display();
		$tagline  = $settings['tagline'];
		$title    = $settings['title'];
		$html_tag = $settings['html_tag'];

		?>
		<!-- immigration-style-two -->
		<section class="immigration-style-two">
			<div class="outer-container">
				<div class="three-item-carousel-2 owl-carousel owl-theme owl-nav-none owl-dots-none">
					<?php
					$i = 1;
					foreach ( $settings['items'] as $item ) {
						$item_image = ( $item['item_image']['id'] != '' ) ? wp_get_attachment_image_url( $item['item_image']['id'], 'full' ) : $item['item_image']['url'];
						if ( ! empty( $item_image ) ) {
							$this->add_render_attribute( 'item_image', 'src', $item_image );
							$this->add_render_attribute( 'item_image', 'alt', \Elementor\Control_Media::get_image_alt( $item['item_image'] ) );
							$this->add_render_attribute( 'item_image', 'title', \Elementor\Control_Media::get_image_title( $item['item_image'] ) );
							$item_image_html = \Elementor\Group_Control_Image_Size::get_attachment_image_html( $item, 'full', 'item_image' );
						}
						$item_tagline     = $item['item_tagline'];
						$item_title       = $item['item_title'];
						$item_html_tag    = $item['item_html_tag'];
						$item_button_name = $item['item_button_name'];
						$item_button_link = $item['item_button_link']['url'];

						$item_page_link          = $item['item_button_link'];
						$item_page_link_target   = $item['item_button_link']['is_external'] ? ' target="_blank"' : '';
						$item_page_link_nofollow = $item['item_button_link']['nofollow'] ? ' rel="nofollow"' : '';
						?>
					 <div class="immigration-block-two">
							<div class="inner-box">
								<figure class="image-box"><?php echo $item_image_html; ?></figure>
								<div class="content-box">
									<h4><a href="<?php echo esc_url( $item_page_link['url'] ); ?>" <?php echo $item_page_link_target . ' ' . $item_page_link_nofollow; ?>><?php echo $item_tagline; ?></a></h4>
									<<?php echo $item_html_tag; ?> class="immigration"><?php echo $item_title; ?></<?php echo $item_html_tag; ?>>
									<div class="btn-box"><a href="<?php echo esc_url( $item_page_link['url'] ); ?>" <?php echo $item_page_link_target . ' ' . $item_page_link_nofollow; ?> class="theme-btn-one"><?php echo $item_button_name; ?><i class="flaticon-send"></i></a></div>
								</div>
							</div>
						</div> <?php } ?>

				</div>
			</div>
		</section>
		<!-- immigration-style-two end --> 
		<?php
	}

	protected function content_templates() {
	}
}
