<?php
namespace Visarzo\Helper\Elementor\Widgets;

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use \Elementor\Repeater;
use Visarzo\Helper\Elementor\Settings\Header;
use Elementor\Core\Schemes;

class Visarzo_Offer extends Widget_Base {

	public function get_name() {
		return 'visarzo_offer';
	}

	public function get_title() {
		return esc_html__( 'Visarzo Offer', 'visarzo-core' );
	}

	public function get_icon() {
		return 'fa fa-object-ungroup';
	}

	public function get_categories() {
		return array( 'visarzo' );
	}
	public function get_script_depends() {
		return array( 'training' );
	}

	protected function register_controls() {

		$this->start_controls_section(
			'general',
			array(
				'label' => esc_html__( 'General', 'visarzo-core' ),
			)
		);

		$this->add_control(
			'layout_style',
			array(
				'label'   => esc_html__( 'Layout Style', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'style_1' => esc_html__( 'Style One', 'visarzo-core' ),
					'style_2' => esc_html__( 'Style Two', 'visarzo-core' ),

				),
				'default' => 'style_1',

			)
		);
		$this->add_control(
			'shape_image',
			array(
				'label'     => esc_html__( 'Shape Image', 'visarzo-core' ),
				'type'      => Controls_Manager::MEDIA,
				'default'   => array(
					'url' => Utils::get_placeholder_image_src(),
				),
				'condition' => array( 'layout_style' => 'style_2' ),

			)
		);

		$this->add_control(
			'tagline',
			array(
				'label'       => esc_html__( 'Tagline', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'COUNTRIES WE OFFER SUPPORT', 'visarzo-core' ),
			)
		);

		$this->add_control(
			'title',
			array(
				'label'       => esc_html__( 'Title', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'Apply For Quick Visa', 'visarzo-core' ),

			)
		);

		$this->add_control(
			'html_tag',
			array(
				'label'   => esc_html__( 'Html Tag', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'h1'   => esc_html__( 'H1', 'visarzo-core' ),
					'h2'   => esc_html__( 'H2', 'visarzo-core' ),
					'h3'   => esc_html__( 'H3', 'visarzo-core' ),
					'h4'   => esc_html__( 'H4', 'visarzo-core' ),
					'h5'   => esc_html__( 'H5', 'visarzo-core' ),
					'h6'   => esc_html__( 'H6', 'visarzo-core' ),
					'div'  => esc_html__( 'div', 'visarzo-core' ),
					'span' => esc_html__( 'span', 'visarzo-core' ),
					'p'    => esc_html__( 'p', 'visarzo-core' ),
				),
				'default' => 'h2',

			)
		);

		$this->add_control(
			'button_text',
			array(
				'label'       => esc_html__( 'Button Text', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'NewZealand', 'visarzo-core' ),

			)
		);

		$this->add_control(
			'bottom_button',
			array(
				'label'   => esc_html__( 'Bottom Button', 'visarzo-core' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __( 'Get In Touch', 'visarzo-core' ),
			)
		);

		$this->add_control(
			'button_link',
			array(
				'label'         => esc_html__( 'Button Link', 'visarzo-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => esc_html__( 'https://your-link.com', 'visarzo-core' ),
				'show_external' => true,
				'default'       => array(
					'url'         => '',
					'is_external' => true,
					'nofollow'    => true,
				),

			)
		);
		$this->end_controls_section();

		$this->start_controls_section(
			'item',
			array(
				'label' => esc_html__( 'ITEM', 'visarzo-core' ),
			)
		);
		Header::visarzo_coloumn_control( $this, 6, 2 );

		$repeater = new Repeater();

		$repeater->add_control(
			'item_country',
			array(
				'label' => esc_html__( 'Country', 'visarzo-core' ),
				'type'  => Controls_Manager::TEXT,
			)
		);
		Header::visarzo_get_wow_animation_control( $repeater );

		$repeater->add_control(
			'item_image',
			array(
				'label'   => esc_html__( 'Image', 'visarzo-core' ),
				'type'    => Controls_Manager::MEDIA,
				'default' => array(
					'url' => Utils::get_placeholder_image_src(),
				),

			)
		);

		$repeater->add_control(
			'item_page_link',
			array(
				'label'         => esc_html__( 'Page Link', 'visarzo-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => esc_html__( 'https://your-link.com', 'visarzo-core' ),
				'show_external' => true,
				'default'       => array(
					'url'         => '',
					'is_external' => true,
					'nofollow'    => true,
				),

			)
		);

		$this->add_control(
			'items',
			array(
				'label'   => esc_html__( 'Repeater List', 'visarzo-core' ),
				'type'    => Controls_Manager::REPEATER,
				'fields'  => $repeater->get_controls(),
				'default' => array(
					array(
						'list_title'   => esc_html__( 'Title #1', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
					array(
						'list_title'   => esc_html__( 'Title #2', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
				),
			)
		);

		$this->end_controls_section();
		$this->start_controls_section(
			'style_section',
			array(
				'label' => __( 'Color', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->start_controls_tabs( 'tabs_button_style' );
		$this->start_controls_tab(
			'tab_button_normal',
			array(
				'label' => __( 'Normal', 'elementor' ),
			)
		);
		$this->add_control(
			'underline_color',
			array(
				'label'     => __( 'Underline Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .sec-title:before' => 'background: {{VALUE}} !important',
					'{{WRAPPER}} .sec-title .dotted-box .dotted' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'border_color',
			array(
				'label'     => __( 'Border Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .immigration-section .more-text h3 a span' => 'border-bottom: 1px solid {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'border_icon_color',
			array(
				'label'     => __( 'Button Icon Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .theme-btn-one i' => 'color: {{VALUE}} !important',

				),
			)
		);

		$this->add_control(
			'button_text_color',
			array(
				'label'     => __( 'Bottom Text Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .immigration-section .more-text h3 a span' => 'color: {{VALUE}} !important',

				),
			)
		);

		$this->end_controls_tab();
		$this->start_controls_tab(
			'tab_button_hover',
			array(
				'label' => __( 'Hover', 'elementor' ),
			)
		);
		$this->add_control(
			'hover_btn_text_color',
			array(
				'label'     => __( 'Button Text/Icon Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .theme-btn-one:hover'   => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .theme-btn-one:hover i' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .immigration-section .more-text h3 a:hover span' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .immigration-section .more-text h3 a i' => 'color: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'hover_button_border_color',
			array(
				'label'     => __( 'Button Border Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .immigration-block-two .inner-box .content-box .theme-btn-one:hover' => 'border:2px solid {{VALUE}} !important',
					'{{WRAPPER}} .immigration-section .more-text h3 a:hover span' => 'border-color: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'hover_arrow_color',
			array(
				'label'     => __( 'Arrow Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .offer-section .owl-nav .owl-prev:hover, .offer-section .owl-nav .owl-next:hover' => 'border-color: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'hover_arrowborder_color',
			array(
				'label'     => __( 'Arrow Border Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .offer-section .owl-nav .owl-prev:hover, .offer-section .owl-nav .owl-next:hover' => 'background: {{VALUE}} !important',

				),
			)
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		$this->start_controls_section(
			'text_style_section',
			array(
				'label' => __( 'Text Style', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'content_typography',
				'label'    => __( 'Typography', 'visarzo-core' ),
				'scheme'   => Schemes\Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .immigration_section',
			)
		);
		$this->end_controls_section();

	}
	protected function render() {
		$settings      = $this->get_settings_for_display();
		$layout_style  = $settings['layout_style'];
		$tagline       = $settings['tagline'];
		$title         = $settings['title'];
		$html_tag      = $settings['html_tag'];
		$button_text   = $settings['button_text'];
		$bottom_button = $settings['bottom_button'];
		$button_link   = $settings['button_link']['url'];
		if ( ! empty( $button_link ) ) {
				$this->add_render_attribute( 'button_link', 'href', $button_link );
			if ( ! empty( $settings['button_link']['is_external'] ) ) {
				$this->add_render_attribute( 'button_link', 'target', '_blank' );
			}

			if ( ! empty( $settings['button_link']['nofollow'] ) ) {
							$this->add_render_attribute( 'button_link', 'rel', 'nofollow' );
			}
		}

		?> <!-- immigration-section -->
		<?php if ( $layout_style == 'style_1' ) : ?>
		<section class="immigration-section">
			<div class="auto-container">
				<div class="sec-title centred">
					<p><?php echo $tagline; ?></p>
					<<?php echo $html_tag; ?> class="immigration_section"><?php echo $title; ?></<?php echo $html_tag; ?>>
					<div class="dotted-box">
						<span class="dotted"></span>
						<span class="dotted"></span>
						<span class="dotted"></span>
					</div>
				</div>
				<div class="row clearfix">
				 <?php
					$i = 1;
					foreach ( $settings['items'] as $item ) {
						$item_country = $item['item_country'];
						$item_image   = ( $item['item_image']['id'] != '' ) ? wp_get_attachment_image_url( $item['item_image']['id'], 'full' ) : $item['item_image']['url'];
						if ( ! empty( $item_image ) ) {
							$this->add_render_attribute( 'item_image', 'src', $item_image );
							$this->add_render_attribute( 'item_image', 'alt', \Elementor\Control_Media::get_image_alt( $item['item_image'] ) );
							$this->add_render_attribute( 'item_image', 'title', \Elementor\Control_Media::get_image_title( $item['item_image'] ) );
							$item_image_html = \Elementor\Group_Control_Image_Size::get_attachment_image_html( $item, 'full', 'item_image' );

						}
						$item_page_link     = $item['item_page_link'];
						$item_page_target   = $item['item_page_link']['is_external'] ? ' target="_blank"' : '';
						$item_page_nofollow = $item['item_page_link']['nofollow'] ? ' rel="nofollow"' : '';

						$animation_class = $item['animation_class'];
						$duration_time   = $item['duration_time'];
						$delay_time      = $item['delay_time'];

						?>
					  <div class="<?php echo Header::visarzo_coloumn( $this, $settings ); ?> col-md-6 col-sm-12 immigration-block">
						<div class="immigration-block-one wow <?php $animation_class; ?> animated animated" data-wow-delay="<?php $delay_time; ?>" data-wow-duration="<?php $duration_time; ?>">
							<div class="inner-box">
								<figure class="image-box"><?php echo $item_image_html; ?></figure>
								<div class="text">
									<h3><a href="<?php echo esc_url( $item_page_link['url'] ); ?>" <?php echo $item_page_target . ' ' . $item_page_nofollow; ?>><?php echo $item_country; ?></a></h3>
								</div>
							</div>
						</div>
					</div> <?php } ?> 
									
				</div>
				<div class="more-text"><h3><?php echo $button_text; ?> <a <?php echo $this->get_render_attribute_string( 'button_link' ); ?>><span><?php echo $bottom_button; ?></span><i class="flaticon-send"></i></a></h3></div>
			</div>
		</section>
		<!-- immigration-section end -->
			<?php
		elseif ( $layout_style == 'style_2' ) :
			 $shape_image = ( $settings['shape_image']['id'] != '' ) ? wp_get_attachment_image_url( $settings['shape_image']['id'], 'full' ) : $settings['shape_image']['url'];
			?>
		<!-- offer-section -->
		<section class="offer-section">
			<div class="pattern-layer" style="background-image: url(<?php echo esc_url( $shape_image ); ?>);"></div>
			<div class="auto-container">
				<div class="sec-title light centred">
					<p><?php echo $tagline; ?></p>
					<<?php echo $html_tag; ?> class="immigration_section"><?php echo $title; ?></<?php echo $html_tag; ?>>
					<div class="dotted-box">
						<span class="dotted"></span>
						<span class="dotted"></span>
						<span class="dotted"></span>
					</div>
				</div>
				<div class="four-item-carousel owl-carousel owl-theme owl-dots-none">
				<?php
					$i = 1;
				foreach ( $settings['items'] as $item ) {
					$item_country = $item['item_country'];
					$item_image   = ( $item['item_image']['id'] != '' ) ? wp_get_attachment_image_url( $item['item_image']['id'], 'full' ) : $item['item_image']['url'];
					if ( ! empty( $item_image ) ) {
						$this->add_render_attribute( 'item_image', 'src', $item_image );
						$this->add_render_attribute( 'item_image', 'alt', \Elementor\Control_Media::get_image_alt( $item['item_image'] ) );
						$this->add_render_attribute( 'item_image', 'title', \Elementor\Control_Media::get_image_title( $item['item_image'] ) );
						$item_image_html = \Elementor\Group_Control_Image_Size::get_attachment_image_html( $item, 'full', 'item_image' );

					}
					$item_page_link     = $item['item_page_link'];
					$item_page_target   = $item['item_page_link']['is_external'] ? ' target="_blank"' : '';
					$item_page_nofollow = $item['item_page_link']['nofollow'] ? ' rel="nofollow"' : '';
					?>
					<div class="single-item">
						<div class="inner-box">
							<figure class="image-box"><?php echo $item_image_html; ?></figure>
							<div class="text"><h4><a href="<?php echo esc_url( $item_page_link['url'] ); ?>" <?php echo $item_page_target . ' ' . $item_page_nofollow; ?>><?php echo $item_country; ?></a></h4></div>
						</div>
					</div>
				<?php } ?> 

				</div>
			</div>
		</section>
					<?php endif; ?>
		<!-- offer-section end --> 
		<?php
	}

	protected function content_templates() {
	}
}


