<?php
namespace Visarzo\Helper\Elementor\Widgets;

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use \Elementor\Repeater;
use Elementor\Core\Schemes;

class Visarzo_Service_Icon extends Widget_Base {



	public function get_name() {
		return 'service_icon_box';
	}

	public function get_title() {
		return esc_html__( 'Service Icon Box', 'visarzo-core' );
	}

	public function get_icon() {
		return 'fa fa-object-ungroup';
	}

	public function get_categories() {
		return array( 'visarzo' );
	}

	protected function register_controls() {

		$this->start_controls_section(
			'general',
			array(
				'label' => esc_html__( 'General', 'visarzo-core' ),
			)
		);
		$this->add_control(
			'layout_style',
			array(
				'label'   => esc_html__( 'Layout Style', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'style_1' => esc_html__( 'Style One', 'visarzo-core' ),
					'style_2' => esc_html__( 'Style Two', 'visarzo-core' ),

				),
				'default' => 'style_1',

			)
		);

		$this->add_control(
			'title',
			array(
				'label'       => esc_html__( 'Title', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'Where and How to Apply for a Business Visa?', 'visarzo-core' ),
			)
		);

		$this->add_control(
			'content',
			array(
				'label'       => esc_html__( 'Content', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),

			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'item',
			array(
				'label' => esc_html__( 'ITEM', 'visarzo-core' ),
			)
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'item_icon',
			array(
				'label' => esc_html__( 'Icon', 'visarzo-core' ),
				'type'  => Controls_Manager::ICONS,
			)
		);

		$repeater->add_control(
			'item_title',
			array(
				'label'       => esc_html__( 'Title', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'Fill In The <br />Required Form', 'visarzo-core' ),
			)
		);
		$repeater->add_control(
			'html_tag',
			array(
				'label'   => esc_html__( 'Html Tag', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'h1'   => esc_html__( 'H1', 'visarzo-core' ),
					'h2'   => esc_html__( 'H2', 'visarzo-core' ),
					'h3'   => esc_html__( 'H3', 'visarzo-core' ),
					'h4'   => esc_html__( 'H4', 'visarzo-core' ),
					'h5'   => esc_html__( 'H5', 'visarzo-core' ),
					'h6'   => esc_html__( 'H6', 'visarzo-core' ),
					'div'  => esc_html__( 'div', 'visarzo-core' ),
					'span' => esc_html__( 'span', 'visarzo-core' ),
					'p'    => esc_html__( 'p', 'visarzo-core' ),
				),
				'default' => 'h4',

			)
		);

		$repeater->add_control(
			'item_content',
			array(
				'label'       => esc_html__( 'Content', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),

			)
		);

		$this->add_control(
			'items',
			array(
				'label'   => esc_html__( 'Repeater List', 'visarzo-core' ),
				'type'    => Controls_Manager::REPEATER,
				'fields'  => $repeater->get_controls(),
				'default' => array(
					array(
						'list_title'   => esc_html__( 'Title #1', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
					array(
						'list_title'   => esc_html__( 'Title #2', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
				),
			)
		);

		$this->end_controls_section();
		$this->start_controls_section(
			'text_style_section',
			array(
				'label' => __( 'Text Style', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'content_typography',
				'label'    => __( 'Typography', 'visarzo-core' ),
				'scheme'   => Schemes\Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .single_icon',
			)
		);
		$this->end_controls_section();
	}
	protected function render() {
		$settings     = $this->get_settings_for_display();
		$title        = $settings['title'];
		$content      = $settings['content'];
		$layout_style = $settings['layout_style'];
		?> 
		<?php if ( $layout_style == 'style_1' ) : ?>
		<div class="content-style-two">
			<div class="inner-box">
				<div class="row clearfix">

			<?php
			$i = 1;
			foreach ( $settings['items'] as $item ) {
				$item_icon    = $item['item_icon'];
				$item_title   = $item['item_title'];
				$item_content = $item['item_content'];
				$html_tag     = $item['html_tag'];

				?>
					 <div class="col-lg-4 col-md-6 col-sm-12 column">
						<div class="single-item">
							<div class="icon-box"><?php \Elementor\Icons_Manager::render_icon( ( $item_icon ), array( 'aria-hidden' => 'true' ) ); ?></div>
							<<?php echo $html_tag; ?> class="single_icon"><?php echo $item_title; ?></<?php echo $html_tag; ?>>
							<p><?php echo $item_content; ?></p>
						</div>
					</div> <?php } ?>

				</div>
			</div>
			<?php if ( ! empty( $title ) ) : ?>
				<h3><?php echo $title; ?></h3>
			<?php endif; ?>
			<?php if ( ! empty( $content ) ) : ?>
				<div class="text">
					<p><?php echo $content; ?></p>
				</div>
			<?php endif; ?>
			</div> 
			<?php elseif ( $layout_style == 'style_2' ) : ?>
				<div class="content-style-two">
				<?php if ( ! empty( $title ) ) : ?>
				<h3><?php echo $title; ?></h3>
			<?php endif; ?>
				<?php if ( ! empty( $content ) ) : ?>
				<div class="text">
					<p><?php echo $content; ?></p>
				</div>
			<?php endif; ?>
					<div class="inner-box">
						<div class="row clearfix">
						<?php
							$i = 1;
						foreach ( $settings['items'] as $item ) {
							$item_icon    = $item['item_icon'];
							$item_title   = $item['item_title'];
							$item_content = $item['item_content'];
							$html_tag     = $item['html_tag'];

							?>
							<div class="col-lg-4 col-md-6 col-sm-12 column">
								<div class="single-item">
									<div class="icon-box"><?php \Elementor\Icons_Manager::render_icon( ( $item_icon ), array( 'aria-hidden' => 'true' ) ); ?></div>
									<<?php echo $html_tag; ?> class="single_icon"><?php echo $item_title; ?></<?php echo $html_tag; ?>>
									<p><?php echo $item_content; ?></p>
								</div>
							</div>
						<?php } ?>

						</div>
					</div>
				</div>

				<?php
		endif;
	}

	protected function content_templates() {
	}
}
