<?php
namespace Visarzo\Helper\Elementor\Widgets;

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Core\Schemes;
use Visarzo\Helper\Elementor\Settings\Header;

class Visarzo_Service_Selector extends Widget_Base {


	public function get_name() {
		return 'visarzo_sevice';
	}

	public function get_title() {
		return esc_html__( 'Visarzo Visa Services', 'visarzo-core' );
	}

	public function get_icon() {
		return 'fa fa-object-ungroup';
	}

	public function get_categories() {
		return array( 'visarzo' );
	}
	public function get_script_depends() {
		return array( 'training' );
	}


	private function get_services() {
		$options  = array();
		$args     = array(
			'post_type' => array( 'service' ),
		);
		$services = new \WP_Query( $args );

		if ( $services->have_posts() ) {

			while ( $services->have_posts() ) {
				$services->the_post();
				$options[ get_the_ID() ] = get_the_title();
			}
		}
		wp_reset_postdata();
		return $options;
	}

	protected function register_controls() {
		$this->start_controls_section(
			'general',
			array(
				'label' => __( 'General', 'visarzo-core' ),
			)
		);
		$this->add_control(
			'layout_style',
			array(
				'label'   => esc_html__( 'Layout Style', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'style_1' => esc_html__( 'Style One', 'visarzo-core' ),
					'style_2' => esc_html__( 'Style Two', 'visarzo-core' ),
					'style_3' => esc_html__( 'Style Three', 'visarzo-core' ),
					'style_4' => esc_html__( 'Style Four', 'visarzo-core' ),
					'style_5' => esc_html__( 'Style Five', 'visarzo-core' ),
					'style_6' => esc_html__( 'Style Six', 'visarzo-core' ),

				),
				'default' => 'style_1',

			)
		);

		$this->add_control(
			'title',
			array(
				'label'       => __( 'Heading', 'visarzo-core' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => __( 'Level With Great Visa Serving Policies', 'visarzo-core' ),
				'conditions'  => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_1',
						),
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_2',
						),
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_3',
						),
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_4',
						),
					),
				),
			)
		);
		$this->add_control(
			'html_tag',
			array(
				'label'      => esc_html__( 'Heading Tag', 'visarzo-core' ),
				'type'       => Controls_Manager::SELECT,
				'options'    => array(
					'h1'   => esc_html__( 'H1', 'visarzo-core' ),
					'h2'   => esc_html__( 'H2', 'visarzo-core' ),
					'h3'   => esc_html__( 'H3', 'visarzo-core' ),
					'h4'   => esc_html__( 'H4', 'visarzo-core' ),
					'h5'   => esc_html__( 'H5', 'visarzo-core' ),
					'h6'   => esc_html__( 'H6', 'visarzo-core' ),
					'div'  => esc_html__( 'div', 'visarzo-core' ),
					'span' => esc_html__( 'span', 'visarzo-core' ),
					'p'    => esc_html__( 'p', 'visarzo-core' ),
				),
				'default'    => 'h2',
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_1',
						),
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_2',
						),
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_3',
						),
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_4',
						),
					),
				),

			)
		);
		$this->add_control(
			'tag_line',
			array(
				'label'       => __( 'Sub Heading', 'visarzo-core' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => __( 'HOW WE HELP CLIENTS', 'visarzo-core' ),
				'conditions'  => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_1',
						),
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_2',
						),
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_3',
						),
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_4',
						),
					),
				),

			)
		);
		$this->add_control(
			'bottom_title',
			array(
				'label'       => __( 'Bottom Title', 'visarzo-core' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => __( 'Visarzo is clearly your best partner at Immigration& Visa success', 'visarzo-core' ),
				'conditions'  => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_2',
						),
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_3',
						),
					),
				),

			)
		);
		$this->add_control(
			'link_title',
			array(
				'label'       => __( 'Bottom Link Title', 'visarzo-core' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => __( 'Get In Touch', 'visarzo-core' ),
				'conditions'  => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_2',
						),
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_3',
						),
					),
				),

			)
		);
		$this->add_control(
			'bottom_link',
			array(
				'label'         => esc_html__( 'Bottom Link', 'visarzo-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => esc_html__( 'https://your-link.com', 'visarzo-core' ),
				'show_external' => true,
				'default'       => array(
					'url'         => '#_',
					'is_external' => true,
					'nofollow'    => true,
				),
				'conditions'    => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_2',
						),
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_3',
						),
					),
				),

			)
		);
		$this->add_control(
			'description',
			array(
				'label'       => __( 'Description', 'visarzo-core' ),
				'type'        => \Elementor\Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Type your description here', 'visarzo-core' ),
				'conditions'  => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_1',
						),
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_2',
						),
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_3',
						),
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_4',
						),
					),
				),

			)
		);
		$this->end_controls_section();
		$this->start_controls_section(
			'item_section',
			array(
				'label' => __( 'ITEM', 'visarzo-core' ),
			)
		);
		Header::visarzo_coloumn_control( $this, 6, 2 );

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'service',
			array(
				'label'   => __( 'Select Service', 'visarzo-core' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => $this->get_services(),
				'default' => '',

			)
		);
		$repeater->add_control(
			'external_title',
			array(
				'label'       => __( 'External Title', 'visarzo-core' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::TEXT,
			)
		);
		$repeater->add_control(
			'service_link',
			array(
				'label'         => esc_html__( 'Service Link', 'visarzo-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => esc_html__( 'https://your-link.com', 'visarzo-core' ),
				'show_external' => true,
				'default'       => array(
					'url'         => '',
					'is_external' => true,
					'nofollow'    => true,
				),

			)
		);
		$repeater->add_control(
			'item_image',
			array(
				'label'   => esc_html__( 'Image', 'visarzo-core' ),
				'type'    => Controls_Manager::MEDIA,
				'default' => array(
					'url' => Utils::get_placeholder_image_src(),
				),

			)
		);
		$repeater->add_control(
			'item_description',
			array(
				'label'       => __( 'Description', 'visarzo-core' ),
				'type'        => \Elementor\Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Type your description here', 'visarzo-core' ),

			)
		);

		$repeater->add_control(
			'icon',
			array(
				'label'   => __( 'Icon', 'visarzo-core' ),
				'type'    => Controls_Manager::ICONS,
				'default' => array(
					'value'   => 'cameron-icon-lock-person',
					'library' => 'solid',
				),

			)
		);
		$repeater->add_control(
			'visa_type',
			array(
				'label'       => __( 'Visa Type Text', 'visarzo-core' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => __( 'visa types', 'visarzo-core' ),
			)
		);

		$this->add_control(
			'items',
			array(
				'label'   => __( 'Repeater List', 'visarzo-core' ),
				'type'    => \Elementor\Controls_Manager::REPEATER,
				'fields'  => $repeater->get_controls(),
				'default' => array(
					array(
						'list_title'   => __( 'Title #1', 'visarzo-core' ),
						'list_content' => __( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
					array(
						'list_title'   => __( 'Title #2', 'visarzo-core' ),
						'list_content' => __( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
				),
			)
		);

		$this->end_controls_section();
		$this->start_controls_section(
			'style_section',
			array(
				'label' => __( 'Color', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->start_controls_tabs( 'tabs_button_style' );
		$this->start_controls_tab(
			'tab_button_normal',
			array(
				'label' => __( 'Normal', 'elementor' ),
			)
		);
		$this->add_control(
			'title_underline',
			array(
				'label'     => __( 'Title Underline Color', 'bisarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .sec-title:before' => 'background: {{VALUE}} !important',
					'{{WRAPPER}} .sec-title .dotted-box .dotted' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'icon_color',
			array(
				'label'     => __( 'Icon Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .service-block-one .inner-box .icon-box' => 'color: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'icon_bgcolor',
			array(
				'label'     => __( 'Icon Background Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .service-block-two .inner-box .lower-content .box .icon-box' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'active_color',
			array(
				'label'     => __( 'Active Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .service-section .owl-theme .owl-dots .owl-dot.active span, .service-section .owl-theme .owl-dots .owl-dot span:hover' => 'background: {{VALUE}} !important',
					'{{WRAPPER}} .service-style-two .owl-theme .owl-dots .owl-dot.active span, .service-style-two .owl-theme .owl-dots .owl-dot span:hover' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'arrow_color',
			array(
				'label'     => __( 'Arrow Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .service-block-two .inner-box .lower-content .link a i' => 'color: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'border_bottm_color',
			array(
				'label'     => __( 'Border Bottom Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .service-block-one .inner-box' => 'border-bottom:1px solid {{VALUE}} !important',

				),
			)
		);

		$this->end_controls_tab();
		$this->start_controls_tab(
			'tab_button_hover',
			array(
				'label' => __( 'Hover', 'elementor' ),
			)
		);
		$this->add_control(
			'icon_hover_color',
			array(
				'label'     => __( 'Icon Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .service-block-one .inner-box .icon-box:hover' => 'color: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'bottom_border_color',
			array(
				'label'     => __( 'Bottom Border Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .service-block-one .inner-box:before' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'hover_arrow_color',
			array(
				'label'     => __( 'Arrow Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .service-block-one .inner-box .link a' => 'color: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'hover_readmore_color',
			array(
				'label'     => __( 'Read More BG Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .service-block-two .inner-box .lower-content .link:before' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		$this->start_controls_section(
			'content_sectionbgsection',
			array(
				'label' => __( 'Background', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'background',
				'label' => __( 'Background', 'visarzo-core' ),
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => '{{WRAPPER}} .immigration-section,{{WRAPPER}} .bg-color-3',
			]
		);

		$this->end_controls_section();
		$this->start_controls_section(
			'text_style_section',
			array(
				'label' => __( 'Text Style', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'content_typography',
				'label'    => __( 'Typography', 'visarzo-core' ),
				'scheme'   => Schemes\Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .service_heading',
			)
		);
		$this->end_controls_section();
	}

	protected function render() {
		$settings     = $this->get_settings_for_display();
		$layout_style = $settings['layout_style'];
		if ( $layout_style == 'style_1' || $layout_style == 'style_2' || $layout_style == 'style_3' || $layout_style == 'style_4' ) :
			$title       = $settings['title'];
			$tag_line    = $settings['tag_line'];
			$description = $settings['description'];
			$html_tag    = $settings['html_tag'];

		endif;

		if ( $layout_style == 'style_2' || $layout_style == 'style_3' ) :
			$bottom_title         = $settings['bottom_title'];
			$link_title           = $settings['link_title'];
			$bottom_link          = $settings['bottom_link'];
			$bottom_link_target   = $settings['bottom_link']['is_external'] ? ' target="_blank"' : '';
			$bottom_link_nofollow = $settings['bottom_link']['nofollow'] ? ' rel="nofollow"' : '';
		endif;
		if ( $layout_style == 'style_3' ) :
			$section_class = 'service-page-1';
		elseif ( $layout_style == 'style_5' || $layout_style == 'style_6' ) :
			$section_class = 'sec-pad-2';
			$dot_none      = 'owl-dots-none';
		elseif ( $layout_style == 'style_2' ) :
			$section_class = 'service-style-two';
		endif;

		?>
		<?php if ( $layout_style == 'style_1' ) : ?>
		<section class="service-section">
			<div class="auto-container">
				<div class="top-inner">
					<div class="row clearfix">
						<div class="col-lg-5 col-md-12 col-sm-12 title-column">
							<div class="sec-title">
								<p><?php echo $tag_line; ?></p>
								<<?php echo $html_tag; ?> class="service_heading"><?php echo $title; ?></<?php echo $html_tag; ?>>
								<div class="dotted-box">
									<span class="dotted"></span>
									<span class="dotted"></span>
									<span class="dotted"></span>
								</div>
							</div>
						</div>
						<div class="col-lg-7 col-md-12 col-sm-12 text-column">
							<div class="text">
								<p><?php echo $description; ?></p>
							</div>
						</div>
					</div>
				</div>
				<div class="four-item-carousel owl-carousel owl-theme owl-nav-none">
				<?php
				foreach ( $settings['items'] as $item ) {
					$service          = $item['service'];
					$icon             = $item['icon'];
					$visa_type        = $item['visa_type'];
					$item_description = $item['item_description'];

					$fav_service        = get_post( $service );
					$external_title     = $item['external_title'];
					$item_page_link     = $item['service_link'];
					$item_page_target   = $item['service_link']['is_external'] ? ' target="_blank"' : '';
					$item_page_nofollow = $item['service_link']['nofollow'] ? ' rel="nofollow"' : '';

					?>

					<div class="service-block-one">
						<div class="inner-box">
							<div class="icon-box">
						<?php
								\Elementor\Icons_Manager::render_icon(
									( $icon ),
									array(
										'aria-hidden' => 'true',
									)
								);
						?>
							</div>
							<span><?php echo $visa_type; ?></span>
							<?php if ( $external_title ) : ?>
							<h3><a href="<?php
							if($item_page_link['url']){
								echo esc_url( $item_page_link['url'] );
							}else{
								echo get_permalink($fav_service);
							}
								 ?>" <?php echo $item_page_target . ' ' . $item_page_nofollow; ?>><?php echo $external_title; ?></a></h3>
							<?php else : ?>
								<h3><a href="<?php echo get_permalink($fav_service); ?>"><?php echo $fav_service->post_title; ?></a></h3>
							<?php endif; ?>
							<p><?php echo $item_description; ?></p>
							<?php if ( $item_page_link ) : ?>
								<div class="link"><a href="<?php echo esc_url( $item_page_link['url'] ); ?>" <?php echo $item_page_target . ' ' . $item_page_nofollow; ?>><i class="flaticon-send"></i></a></div>
							<?php else : ?>
								<div class="link"><a href="<?php echo get_permalink($fav_service); ?>"><i class="flaticon-send"></i></a></div>
							<?php endif; ?>
						</div>
					</div>
					<?php
				}
					wp_reset_postdata();
				?>
					
				</div>
			</div>
		</section>
		<?php elseif ( $layout_style == 'style_2' || $layout_style == 'style_6' ) : ?>
		<section class="<?php echo $section_class; ?> bg-color-3">
			<div class="auto-container">
				<?php if ( $layout_style == 'style_2' ) : ?>
				<div class="sec-title centred">
					<p><?php echo $tag_line; ?></p>
					<<?php echo $html_tag; ?> class="service_heading"><?php echo $title; ?></<?php echo $html_tag; ?>>
					<span><?php echo $description; ?></span>
					<div class="dotted-box">
						<span class="dotted"></span>
						<span class="dotted"></span>
						<span class="dotted"></span>
					</div>
				</div>
				<?php endif; ?>
				<div class="three-item-carousel owl-carousel owl-theme owl-nav-none">
				<?php
				foreach ( $settings['items'] as $item ) {
					$service          = $item['service'];
					$icon             = $item['icon'];
					$visa_type        = $item['visa_type'];
					$item_description = $item['item_description'];
					$fav_service      = get_post( $service );
					$item_image       = ( $item['item_image']['id'] != '' ) ? wp_get_attachment_image_url( $item['item_image']['id'], 'full' ) : $item['item_image']['url'];
					if ( ! empty( $item_image ) ) {
						$this->add_render_attribute( 'item_image', 'src', $item_image );
						$this->add_render_attribute( 'item_image', 'alt', \Elementor\Control_Media::get_image_alt( $item['item_image'] ) );
						$this->add_render_attribute( 'item_image', 'title', \Elementor\Control_Media::get_image_title( $item['item_image'] ) );
						$item_image_html = \Elementor\Group_Control_Image_Size::get_attachment_image_html( $item, 'full', 'item_image' );
					}

					$external_title     = $item['external_title'];
					$item_page_link     = $item['service_link'];
					$item_page_target   = $item['service_link']['is_external'] ? ' target="_blank"' : '';
					$item_page_nofollow = $item['service_link']['nofollow'] ? ' rel="nofollow"' : '';

					?>
					<div class="service-block-two">
						<div class="inner-box">
							<figure class="image-box"><a href="<?php echo esc_url( $item_page_link['url'] ); ?>"><?php echo $item_image_html; ?></a></figure>
							<div class="lower-content">
								<div class="box">
									<div class="icon-box">
									<?php
									\Elementor\Icons_Manager::render_icon(
										( $icon ),
										array(
											'aria-hidden' => 'true',
										)
									);
									?>
									</div>
									<?php if ( $external_title ) : ?>
									<h3><a href="<?php if($item_page_link['url']){
										echo esc_url( $item_page_link['url'] );
									}else{
										echo get_permalink($fav_service);
									} ?>" <?php echo $item_page_target . ' ' . $item_page_nofollow; ?>><?php echo $external_title; ?></a></h3>
									<?php else : ?>
										<h3><a href="<?php echo get_permalink($fav_service); ?>"><?php echo $fav_service->post_title; ?></a></h3>
									<?php endif; ?>
									<p><?php echo $item_description; ?></p>
								</div>
								<?php if ( $item_page_link ) : ?>
									<div class="link"><a href="<?php echo esc_url( $item_page_link['url'] ); ?>" <?php echo $item_page_target . ' ' . $item_page_nofollow; ?>><?php esc_html_e( 'Read More', 'visarzo-core' ); ?><i class="flaticon-send"></i></a></div>
								<?php else : ?>
									<div class="link"><a href="<?php echo get_permalink($fav_service); ?>"><?php esc_html_e( 'Read More', 'visarzo-core' ); ?><i class="flaticon-send"></i></a></div>
								<?php endif; ?>
							</div>
						</div>
					</div>
					<?php
				}
					wp_reset_postdata();
				?>
					
				</div>
			</div>
			<?php if ( $layout_style == 'style_2' ) : ?>
			<div class="more-text centred">
				<div class="auto-container">
					<div class="inner">
						<h3><?php echo $bottom_title; ?> <a href="<?php echo esc_url( $bottom_link['url'] ); ?>" <?php echo $bottom_link_target . ' ' . $bottom_link_nofollow; ?>><span><?php echo $link_title; ?></span><i class="flaticon-send"></i></a></h3>
					</div>
				</div>
			</div>
			<?php endif; ?>
		</section>
		<?php elseif ( $layout_style == 'style_3' || $layout_style == 'style_5' ) : ?>
		<section class="service-style-two <?php echo $section_class; ?> bg-color-3">
			<div class="auto-container">
				<?php if ( $layout_style == 'style_3' ) : ?>
				<div class="sec-title centred">
					<p><?php echo $tag_line; ?></p>
					<<?php echo $html_tag; ?> class="service_heading"><?php echo $title; ?></<?php echo $html_tag; ?>>
					<span><?php echo $description; ?></span>
					<div class="dotted-box">
						<span class="dotted"></span>
						<span class="dotted"></span>
						<span class="dotted"></span>
					</div>
				</div>
				<?php endif; ?>
				<div class="row clearfix">
				<?php
				foreach ( $settings['items'] as $item ) {
					$service          = $item['service'];
					$icon             = $item['icon'];
					$visa_type        = $item['visa_type'];
					$item_description = $item['item_description'];
					$fav_service      = get_post( $service );
					$item_image       = ( $item['item_image']['id'] != '' ) ? wp_get_attachment_image_url( $item['item_image']['id'], 'full' ) : $item['item_image']['url'];
					if ( ! empty( $item_image ) ) {
						$this->add_render_attribute( 'item_image', 'src', $item_image );
						$this->add_render_attribute( 'item_image', 'alt', \Elementor\Control_Media::get_image_alt( $item['item_image'] ) );
						$this->add_render_attribute( 'item_image', 'title', \Elementor\Control_Media::get_image_title( $item['item_image'] ) );
						$item_image_html = \Elementor\Group_Control_Image_Size::get_attachment_image_html( $item, 'full', 'item_image' );
					}

					$external_title     = $item['external_title'];
					$item_page_link     = $item['service_link'];
					$item_page_target   = $item['service_link']['is_external'] ? ' target="_blank"' : '';
					$item_page_nofollow = $item['service_link']['nofollow'] ? ' rel="nofollow"' : '';

					?>
					<div class="<?php echo Header::visarzo_coloumn( $this, $settings ); ?> col-md-6 col-sm-12 service-block">
						<div class="service-block-two">
							<div class="inner-box">
								<figure class="image-box"><a href="<?php echo esc_url( $item_page_link['url'] ); ?>"><?php echo $item_image_html; ?></a></figure>
								<div class="lower-content">
									<div class="box">
										<div class="icon-box">
										<?php
										\Elementor\Icons_Manager::render_icon(
											( $icon ),
											array(
												'aria-hidden' => 'true',
											)
										);
										?>
										</div>
										<?php if ( $external_title ) : ?>
										<h3><a href="<?php echo esc_url( $item_page_link['url'] ); ?>" <?php echo $item_page_target . ' ' . $item_page_nofollow; ?>><?php echo $external_title; ?></a></h3>
										<?php else : ?>
											<h3><a href="<?php echo esc_url( $item_page_link['url'] ); ?>""><?php echo $fav_service->post_title; ?></a></h3>
										<?php endif; ?>
										<p><?php echo $item_description; ?></p>
									</div>
									<?php if ( $item_page_link ) : ?>
										<div class="link"><a href="<?php echo esc_url( $item_page_link['url'] ); ?>" <?php echo $item_page_target . ' ' . $item_page_nofollow; ?>><?php esc_html_e( 'Read More', 'visarzo-core' ); ?><i class="flaticon-send"></i></a></div>
									<?php else : ?>
										<div class="link"><a href="<?php echo esc_url( $item_page_link['url'] ); ?>""><?php esc_html_e( 'Read More', 'visarzo-core' ); ?><i class="flaticon-send"></i></a></div>
									<?php endif; ?>
								</div>
							</div>
						</div>
					</div>
					<?php
				}
					wp_reset_postdata();
				?>
					
				</div>
			</div>
			<?php if ( $layout_style == 'style_3' ) : ?>
			<div class="more-text centred">
				<div class="auto-container">
					<div class="inner">
						<h3><?php echo $bottom_title; ?> <a href="<?php echo esc_url( $bottom_link['url'] ); ?>" <?php echo $bottom_link_target . ' ' . $bottom_link_nofollow; ?>><span><?php echo $link_title; ?></span><i class="flaticon-send"></i></a></h3>
					</div>
				</div>
			</div>
			<?php endif; ?>
		</section>
		<?php elseif ( $layout_style == 'style_4' ) : ?>
		<section class="service-section service-page-2">
			<div class="auto-container">
				<div class="top-inner">
					<div class="row clearfix">
						<div class="col-lg-5 col-md-12 col-sm-12 title-column">
							<div class="sec-title">
								<p><?php echo $tag_line; ?></p>
								<<?php echo $html_tag; ?> class="service_heading"><?php echo $title; ?></<?php echo $html_tag; ?>>
								<div class="dotted-box">
									<span class="dotted"></span>
									<span class="dotted"></span>
									<span class="dotted"></span>
								</div>
							</div>
						</div>
						<div class="col-lg-7 col-md-12 col-sm-12 text-column">
							<div class="text">
								<p><?php echo $description; ?></p>
							</div>
						</div>
					</div>
				</div>
				<div class="row clearfix">
				<?php
				foreach ( $settings['items'] as $item ) {
					$service          = $item['service'];
					$icon             = $item['icon'];
					$visa_type        = $item['visa_type'];
					$item_description = $item['item_description'];
					$fav_service      = get_post( $service );

					$external_title     = $item['external_title'];
					$item_page_link     = $item['service_link'];
					$item_page_target   = $item['service_link']['is_external'] ? ' target="_blank"' : '';
					$item_page_nofollow = $item['service_link']['nofollow'] ? ' rel="nofollow"' : '';

					?>
					<div class="<?php echo Header::visarzo_coloumn( $this, $settings ); ?> col-md-6 col-sm-12 service-block">
						<div class="service-block-one">
							<div class="inner-box">
								<div class="icon-box">
								<?php
								\Elementor\Icons_Manager::render_icon(
									( $icon ),
									array(
										'aria-hidden' => 'true',
									)
								);
								?>
								</div>
								<span><?php echo $visa_type; ?></span>
								<?php if ( $external_title ) : ?>
								<h3><a href="<?php if($item_page_link['url']){
								echo esc_url( $item_page_link['url'] );
							}else{
								echo get_permalink($fav_service);
							} ?>" <?php echo $item_page_target . ' ' . $item_page_nofollow; ?>><?php echo $external_title; ?></a></h3>
								<?php else : ?>
									<h3><a href="<?php echo get_permalink($fav_service); ?>"><?php echo $fav_service->post_title; ?></a></h3>
								<?php endif; ?>
								<p><?php echo $item_description; ?></p>
								<?php if ( $item_page_link ) : ?>
									<div class="link"><a href="<?php echo esc_url( $item_page_link['url'] ); ?>" <?php echo $item_page_target . ' ' . $item_page_nofollow; ?>><i class="flaticon-send"></i></a></div>
								<?php else : ?>
									<div class="link"><a href="<?php echo get_permalink($fav_service); ?>"><i class="flaticon-send"></i></a></div>
								<?php endif; ?>
							</div>
						</div>
					</div>
					<?php
				}
					wp_reset_postdata();
				?>
					
				</div>
			</div>
		</section>
			<?php
		endif;
	}
	protected function content_templates() {
	}
}
