<?php
namespace Visarzo\Helper\Elementor\Widgets;

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use \Elementor\Repeater;
use Elementor\Core\Schemes;
class Visarzo_Single_Image extends Widget_Base {


	public function get_name() {
		return 'single_service_image';
	}

	public function get_title() {
		return esc_html__( 'Single Service Image', 'visarzo-core' );
	}

	public function get_icon() {
		return 'fa fa-object-ungroup';
	}

	public function get_categories() {
		return array( 'visarzo' );
	}

	protected function register_controls() {

		$this->start_controls_section(
			'general',
			array(
				'label' => esc_html__( 'General', 'visarzo-core' ),
			)
		);
		$this->add_control(
			'layout_style',
			array(
				'label'   => esc_html__( 'Layout Style', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'style_1' => esc_html__( 'Style One', 'visarzo-core' ),
					'style_2' => esc_html__( 'Style Two', 'visarzo-core' ),
					'style_3' => esc_html__( 'Style Three', 'visarzo-core' ),

				),
				'default' => 'style_1',

			)
		);

		$this->add_control(
			'image',
			array(
				'label'   => esc_html__( 'Image', 'visarzo-core' ),
				'type'    => Controls_Manager::MEDIA,
				'default' => array(
					'url' => Utils::get_placeholder_image_src(),
				),

			)
		);

		$this->add_control(
			'title',
			array(
				'label'       => esc_html__( 'Title', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'Business Visa Benefits', 'visarzo-core' ),
			)
		);

		$this->add_control(
			'bottom_title',
			array(
				'label'       => esc_html__( 'Bottom Title', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'How To Do Test Preparation', 'visarzo-core' ),
				'condition'   => array( 'layout_style' => 'style_1' ),
			)
		);
		$this->add_control(
			'lower_title',
			array(
				'label'       => esc_html__( 'Lower Title', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'Our Capabilities For Visa & Immigration', 'visarzo-core' ),
				'condition'   => array( 'layout_style' => 'style_3' ),
			)
		);
		$this->add_control(
			'lower_content',
			array(
				'label'       => esc_html__( 'Lower Content', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),
				'condition'   => array( 'layout_style' => 'style_3' ),

			)
		);
		$this->add_control(
			'html_tag',
			array(
				'label'   => esc_html__( 'Html Tag', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'h1'   => esc_html__( 'H1', 'visarzo-core' ),
					'h2'   => esc_html__( 'H2', 'visarzo-core' ),
					'h3'   => esc_html__( 'H3', 'visarzo-core' ),
					'h4'   => esc_html__( 'H4', 'visarzo-core' ),
					'h5'   => esc_html__( 'H5', 'visarzo-core' ),
					'h6'   => esc_html__( 'H6', 'visarzo-core' ),
					'div'  => esc_html__( 'div', 'visarzo-core' ),
					'span' => esc_html__( 'span', 'visarzo-core' ),
					'p'    => esc_html__( 'p', 'visarzo-core' ),
				),
				'default' => 'h2',

			)
		);

		$this->add_control(
			'content',
			array(
				'label'       => esc_html__( 'Content', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),
				'conditions'  => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_1',
						),
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_3',
						),
					),
				),

			)
		);

		$this->add_control(
			'list_content',
			array(
				'label'       => esc_html__( 'List Content', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),

			)
		);

		$this->end_controls_section();
		$this->start_controls_section(
			'text_style_section',
			array(
				'label' => __( 'Text Style', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'content_typography',
				'label'    => __( 'Typography', 'visarzo-core' ),
				'scheme'   => Schemes\Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .two_column',
			)
		);
		$this->end_controls_section();
	}
	protected function render() {
		$settings = $this->get_settings_for_display();
		$image    = ( $settings['image']['id'] != '' ) ? wp_get_attachment_image_url( $settings['image']['id'], 'full' ) : $settings['image']['url'];
		if ( ! empty( $image ) ) {
			$this->add_render_attribute( 'image', 'src', $image );
			$this->add_render_attribute( 'image', 'alt', \Elementor\Control_Media::get_image_alt( $settings['image'] ) );
			$this->add_render_attribute( 'image', 'title', \Elementor\Control_Media::get_image_title( $settings['image'] ) );
			$image_html = \Elementor\Group_Control_Image_Size::get_attachment_image_html( $settings, 'full', 'image' );
		}
		$title = $settings['title'];

		$list_content = $settings['list_content'];
		$html_tag     = $settings['html_tag'];
		$layout_style = $settings['layout_style'];

		?> 
		<?php
		if ( $layout_style == 'style_1' ) :
			$bottom_title = $settings['bottom_title'];
			$content      = $settings['content'];
			?>
		<div class="two-column">
			<div class="row align-items-center clearfix">
				<div class="col-lg-6 col-md-6 col-sm-12 image-column">
					<figure class="image-box"><?php echo $image_html; ?></figure>
				</div>
				<div class="col-lg-6 col-md-6 col-sm-12 content-column">
					<div class="content-box">
						<h3><?php echo $title; ?></h3>
						<ul class="list clearfix">
							<?php echo $list_content; ?>
						</ul>
					</div>
				</div>
			</div>
			<div class="text">
				<<?php echo $html_tag; ?> class="two_column"><?php echo $bottom_title; ?></<?php echo $html_tag; ?>>
				<p><?php echo $content; ?></p>
			</div>
		</div> 
		<?php elseif ( $layout_style == 'style_2' ) : ?>
			<div class="two-column">
				<div class="row align-items-center clearfix">
					<div class="col-lg-6 col-md-6 col-sm-12 image-column">
						<figure class="image-box"><?php echo $image_html; ?></figure>
					</div>
					<div class="col-lg-6 col-md-6 col-sm-12 content-column">
						<div class="content-box">
							<h3><?php echo $title; ?></h3>
							<?php echo $list_content; ?>
						</div>
					</div>
				</div>
			</div>
			<?php
			elseif ( $layout_style == 'style_3' ) :
				$lower_title   = $settings['lower_title'];
				$lower_content = $settings['lower_content'];
				$content       = $settings['content'];
				?>
				<div class="two-column">
					<div class="row align-items-center clearfix">
						<div class="col-lg-6 col-md-6 col-sm-12 column">
							<div class="text">
								<?php echo $title; ?>
								<p><?php echo $content; ?></p>
								<ul class="list clearfix">
									<?php echo $list_content; ?>
								</ul>
							</div>
						</div>
						<div class="col-lg-6 col-md-6 col-sm-12 column">
							<figure class="image-box"><?php echo $image_html; ?></figure>
						</div>
					</div>
					<div class="lower-box">
						<?php echo $lower_title; ?>
						<?php echo $lower_content; ?>
						
					</div>
				</div>
				<?php
		endif;
	}

	protected function content_templates() {
	}
}
