<?php
namespace Visarzo\Helper\Elementor\Widgets;

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use \Elementor\Repeater;
use Visarzo\Helper\Elementor\Settings\Header;
use Elementor\Core\Schemes;

class Visarzo_Team extends Widget_Base {


	public function get_name() {
		return 'visarzo_team';
	}

	public function get_title() {
		return esc_html__( 'Visarzo Team', 'visarzo-core' );
	}

	public function get_icon() {
		return 'fa fa-object-ungroup';
	}

	public function get_categories() {
		return array( 'visarzo' );
	}
	public function get_script_depends() {
		return array( 'training' );
	}

	protected function register_controls() {

		$this->start_controls_section(
			'general',
			array(
				'label' => esc_html__( 'General', 'visarzo-core' ),
			)
		);

		$this->add_control(
			'layout_style',
			array(
				'label'   => esc_html__( 'Layout Style', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'style_1' => esc_html__( 'Style One', 'visarzo-core' ),
					'style_2' => esc_html__( 'Style Two', 'visarzo-core' ),
					'style_3' => esc_html__( 'Style Three', 'visarzo-core' ),
					'style_4' => esc_html__( 'Style Four', 'visarzo-core' ),

				),
				'default' => 'style_1',

			)
		);

		$this->add_control(
			'tagline',
			array(
				'label'       => esc_html__( 'Tagline', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'HOW WE HELP CLIENTS', 'visarzo-core' ),
				'condition'   => array( 'layout_style' => 'style_1' ),
			)
		);

		$this->add_control(
			'title',
			array(
				'label'       => esc_html__( 'Title', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'condition'   => array( 'layout_style' => 'style_1' ),

			)
		);

		$this->add_control(
			'html_tag',
			array(
				'label'     => esc_html__( 'Html Tag', 'visarzo-core' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => array(
					'h1'   => esc_html__( 'H1', 'visarzo-core' ),
					'h2'   => esc_html__( 'H2', 'visarzo-core' ),
					'h3'   => esc_html__( 'H3', 'visarzo-core' ),
					'h4'   => esc_html__( 'H4', 'visarzo-core' ),
					'h5'   => esc_html__( 'H5', 'visarzo-core' ),
					'h6'   => esc_html__( 'H6', 'visarzo-core' ),
					'div'  => esc_html__( 'div', 'visarzo-core' ),
					'span' => esc_html__( 'span', 'visarzo-core' ),
					'p'    => esc_html__( 'p', 'visarzo-core' ),
				),
				'default'   => 'h2',
				'condition' => array( 'layout_style' => 'style_1' ),

			)
		);

		$this->add_control(
			'content',
			array(
				'label'       => esc_html__( 'Content', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),
				'condition'   => array( 'layout_style' => 'style_1' ),

			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'item',
			array(
				'label' => esc_html__( 'ITEM', 'visarzo-core' ),
			)
		);
		Header::visarzo_coloumn_control( $this, 6, 2 );

		$repeater = new Repeater();

		$repeater->add_control(
			'item_name',
			array(
				'label'       => esc_html__( 'Name', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
			)
		);
		Header::visarzo_get_wow_animation_control( $repeater );

		$repeater->add_control(
			'item_photo',
			array(
				'label'   => esc_html__( 'Photo', 'visarzo-core' ),
				'type'    => Controls_Manager::MEDIA,
				'default' => array(
					'url' => Utils::get_placeholder_image_src(),
				),

			)
		);
		$repeater->add_control(
			'item_designation',
			array(
				'label'       => esc_html__( 'Designation', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
			)
		);
		$repeater->add_control(
			'item_social',
			array(
				'label' => esc_html__( 'Social Content', 'visarzo-core' ),
				'type'  => Controls_Manager::TEXTAREA,
			)
		);

		$this->add_control(
			'items',
			array(
				'label'   => esc_html__( 'Repeater List', 'visarzo-core' ),
				'type'    => Controls_Manager::REPEATER,
				'fields'  => $repeater->get_controls(),
				'default' => array(
					array(
						'list_title'   => esc_html__( 'Title #1', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
					array(
						'list_title'   => esc_html__( 'Title #2', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
				),
			)
		);

		$this->end_controls_section();
		$this->start_controls_section(
			'style_section',
			array(
				'label' => __( 'Color', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->start_controls_tabs( 'tabs_button_style' );
		$this->start_controls_tab(
			'tab_button_normal',
			array(
				'label' => __( 'Normal', 'elementor' ),
			)
		);
		$this->add_control(
			'underline_color',
			array(
				'label'     => __( 'Underline Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .sec-title:before' => 'background: {{VALUE}} !important',
					'{{WRAPPER}} .sec-title .dotted-box .dotted' => 'background: {{VALUE}} !important',

				),
			)
		);

		$this->end_controls_tab();
		$this->start_controls_tab(
			'tab_button_hover',
			array(
				'label' => __( 'Hover', 'elementor' ),
			)
		);
		$this->add_control(
			'hover_title_color',
			array(
				'label'     => __( 'Title Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .team-block-one .inner-box .lower-content h4:hover' => 'color: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'hover_icon_color',
			array(
				'label'     => __( 'Social Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .team-block-one .inner-box .image-box .social-links li a:hover' => 'color: {{VALUE}} !important',

				),
			)
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		$this->start_controls_section(
			'text_style_section',
			array(
				'label' => __( 'Text Style', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'content_typography',
				'label'    => __( 'Typography', 'visarzo-core' ),
				'scheme'   => Schemes\Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .team',
			)
		);
		$this->end_controls_section();
	}
	protected function render() {
		$settings     = $this->get_settings_for_display();
		$layout_style = $settings['layout_style'];
		if ( $layout_style == 'style_1' ) :
			$tagline  = $settings['tagline'];
			$title    = $settings['title'];
			$html_tag = $settings['html_tag'];
			$content  = $settings['content'];
		endif;
		?>
		<!-- team-section -->
		<?php if ( $layout_style == 'style_1' || $layout_style == 'style_3' ) : ?>
		<section class="team-section">
			<div class="auto-container">
				<?php if ( $layout_style == 'style_1' ) : ?>
				<div class="top-inner">
					<div class="row clearfix">
						<div class="col-lg-5 col-md-12 col-sm-12 title-column">
							<div class="sec-title">
								<p><?php echo $tagline; ?></p>
								<<?php echo $html_tag; ?> class="team"><?php echo $title; ?></<?php echo $html_tag; ?>>
								<div class="dotted-box">
									<span class="dotted"></span>
									<span class="dotted"></span>
									<span class="dotted"></span>
								</div>
							</div>
						</div>
						<div class="col-lg-7 col-md-12 col-sm-12 text-column">
							<div class="text">
								<p><?php echo $content; ?></p>
							</div>
						</div>
					</div>
				</div>
				<?php endif; ?>
				<div class="row clearfix">
					<?php
					$i = 1;
					foreach ( $settings['items'] as $item ) {
						$item_name   = $item['item_name'];
						$item_social = $item['item_social'];
						$item_photo  = ( $item['item_photo']['id'] != '' ) ? wp_get_attachment_image_url( $item['item_photo']['id'], 'full' ) : $item['item_photo']['url'];
						if ( ! empty( $item_photo ) ) {
							$this->add_render_attribute( 'item_photo', 'src', $item_photo );
							$this->add_render_attribute( 'item_photo', 'alt', \Elementor\Control_Media::get_image_alt( $item['item_photo'] ) );
							$this->add_render_attribute( 'item_photo', 'title', \Elementor\Control_Media::get_image_title( $item['item_photo'] ) );
							$item_photo_html = \Elementor\Group_Control_Image_Size::get_attachment_image_html( $item, 'full', 'item_photo' );
						}
						$item_designation = $item['item_designation'];

						$animation_class = $item['animation_class'];
						$duration_time   = $item['duration_time'];
						$delay_time      = $item['delay_time'];

						?>
						<div class="<?php echo Header::visarzo_coloumn( $this, $settings ); ?> col-md-6 col-sm-12 team-block">
							<div class="team-block-one wow <?php echo $animation_class; ?> animated animated" data-wow-delay="<?php echo $delay_time; ?>" data-wow-duration="<?php echo $duration_time; ?>">
								<div class="inner-box">
									<figure class="image-box">
										<?php echo $item_photo_html; ?>
										<?php if ( ! empty( $item_social ) ) : ?>
										<ul class="social-links clearfix">
											<?php echo $item_social; ?>
										</ul>
										<?php endif; ?>
									</figure>
									<div class="lower-content">
										<h4><?php echo $item_name; ?></h4>
										<span class="designation"><?php echo $item_designation; ?></span>
									</div>
								</div>
							</div>
						</div> <?php } ?>

				</div>
			</div>
		</section>
		<!-- team-section end -->
		<?php elseif ( $layout_style == 'style_2' ) : ?>
		<!-- team-section -->
		<section class="team-page-section">
			<div class="auto-container">
				<div class="row clearfix">
				<?php
					$i = 1;
				foreach ( $settings['items'] as $item ) {
					$item_name   = $item['item_name'];
					$item_social = $item['item_social'];
					$item_photo  = ( $item['item_photo']['id'] != '' ) ? wp_get_attachment_image_url( $item['item_photo']['id'], 'full' ) : $item['item_photo']['url'];
					if ( ! empty( $item_photo ) ) {
						$this->add_render_attribute( 'item_photo', 'src', $item_photo );
						$this->add_render_attribute( 'item_photo', 'alt', \Elementor\Control_Media::get_image_alt( $item['item_photo'] ) );
						$this->add_render_attribute( 'item_photo', 'title', \Elementor\Control_Media::get_image_title( $item['item_photo'] ) );
						$item_photo_html = \Elementor\Group_Control_Image_Size::get_attachment_image_html( $item, 'full', 'item_photo' );
					}
					$item_designation = $item['item_designation'];

					$animation_class = $item['animation_class'];
					$duration_time   = $item['duration_time'];
					$delay_time      = $item['delay_time'];

					?>
					<div class="<?php echo Header::visarzo_coloumn( $this, $settings ); ?> col-md-6 col-sm-12 team-block">
						<div class="team-block-one wow <?php echo $animation_class; ?> animated animated" data-wow-delay="<?php echo $delay_time; ?>" data-wow-duration="<?php echo $duration_time; ?>">
							<div class="inner-box">
								<figure class="image-box">
							<?php echo $item_photo_html; ?>
							<?php if ( ! empty( $item_social ) ) : ?>
									<ul class="social-links clearfix">
										<?php echo $item_social; ?>
									</ul>
								<?php endif; ?>
								</figure>
								<div class="lower-content">
									<h4><?php echo $item_name; ?></h4>
									<span class="designation"><?php echo $item_designation; ?></span>
								</div>
							</div>
						</div>
					</div>
					<?php } ?>

				</div>
			</div>
		</section>
		<?php elseif ( $layout_style == 'style_4' ) : ?>
		<section class="team-section">
			<div class="auto-container">
				<div class="four-item-carousel owl-carousel owl-theme owl-dots-none owl-nav-none">
				<?php
					$i = 1;
				foreach ( $settings['items'] as $item ) {
					$item_name   = $item['item_name'];
					$item_social = $item['item_social'];
					$item_photo  = ( $item['item_photo']['id'] != '' ) ? wp_get_attachment_image_url( $item['item_photo']['id'], 'full' ) : $item['item_photo']['url'];
					if ( ! empty( $item_photo ) ) {
						$this->add_render_attribute( 'item_photo', 'src', $item_photo );
						$this->add_render_attribute( 'item_photo', 'alt', \Elementor\Control_Media::get_image_alt( $item['item_photo'] ) );
						$this->add_render_attribute( 'item_photo', 'title', \Elementor\Control_Media::get_image_title( $item['item_photo'] ) );
						$item_photo_html = \Elementor\Group_Control_Image_Size::get_attachment_image_html( $item, 'full', 'item_photo' );
					}
					$item_designation = $item['item_designation'];

					?>

					<div class="team-block-one">
						<div class="inner-box">
							<figure class="image-box">
								<?php echo $item_photo_html; ?>
								<?php if ( ! empty( $item_social ) ) : ?>
								<ul class="social-links clearfix">
									<?php echo $item_social; ?>
								</ul>
								<?php endif; ?>
							</figure>
							<div class="lower-content">
								<h4><?php echo $item_name; ?></h4>
								<span class="designation"><?php echo $item_designation; ?></span>
							</div>
						</div>
					</div>
				<?php } ?>
					
				</div>
			</div>
		</section>
		<?php endif; ?>
		<!-- team-section end -->
			<?php
	}

	protected function content_templates() {
	}
}
