<?php
namespace Visarzo\Helper\Elementor\Widgets;

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use \Elementor\Repeater;
use Visarzo\Helper\Elementor\Settings\Header;
use Elementor\Core\Schemes;

class Visarzo_Testimonial extends Widget_Base {


	public function get_name() {
		return 'visarzo_testimonial';
	}

	public function get_title() {
		return esc_html__( 'Visarzo Testimonial', 'visarzo-core' );
	}

	public function get_icon() {
		return 'fa fa-object-ungroup';
	}

	public function get_categories() {
		return array( 'visarzo' );
	}
	public function get_script_depends() {
		return array( 'testimonial' );
	}

	protected function register_controls() {

		$this->start_controls_section(
			'general',
			array(
				'label' => esc_html__( 'General', 'visarzo-core' ),
			)
		);

		$this->add_control(
			'layout_style',
			array(
				'label'   => esc_html__( 'Layout Style', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'style_1' => esc_html__( 'Style One', 'visarzo-core' ),
					'style_2' => esc_html__( 'Style Two', 'visarzo-core' ),
					'style_3' => esc_html__( 'Style Three', 'visarzo-core' ),

				),
				'default' => 'style_1',

			)
		);
		$this->add_control(
			'shape_image',
			array(
				'label'     => esc_html__( 'Shape Image', 'visarzo-core' ),
				'type'      => Controls_Manager::MEDIA,
				'default'   => array(
					'url' => Utils::get_placeholder_image_src(),
				),
				'condition' => array( 'layout_style' => 'style_2' ),

			)
		);

		$this->add_control(
			'tagline',
			array(
				'label'       => esc_html__( 'Tagline', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'CLIENTS TESTIMONIALS', 'visarzo-core' ),
				'conditions'  => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_1',
						),
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_2',
						),
					),
				),
			)
		);

		$this->add_control(
			'title',
			array(
				'label'       => esc_html__( 'Title', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'     => __( 'What Customers <br>Saying About Visarzo', 'visarzo-core' ),
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),
				'conditions'  => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_1',
						),
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_2',
						),
					),
				),

			)
		);
		$this->add_control(
			'extra_class',
			array(
				'label'       => esc_html__( 'Extra Class', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => 'testimonial-section',
			)
		);

		$this->add_control(
			'html_tag',
			array(
				'label'      => esc_html__( 'Html Tag', 'visarzo-core' ),
				'type'       => Controls_Manager::SELECT,
				'options'    => array(
					'h1'   => esc_html__( 'H1', 'visarzo-core' ),
					'h2'   => esc_html__( 'H2', 'visarzo-core' ),
					'h3'   => esc_html__( 'H3', 'visarzo-core' ),
					'h4'   => esc_html__( 'H4', 'visarzo-core' ),
					'h5'   => esc_html__( 'H5', 'visarzo-core' ),
					'h6'   => esc_html__( 'H6', 'visarzo-core' ),
					'div'  => esc_html__( 'div', 'visarzo-core' ),
					'span' => esc_html__( 'span', 'visarzo-core' ),
					'p'    => esc_html__( 'p', 'visarzo-core' ),
				),
				'default'    => 'h2',
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_1',
						),
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_2',
						),
					),
				),

			)
		);
		$this->end_controls_section();

		$this->start_controls_section(
			'item',
			array(
				'label' => esc_html__( 'ITEM', 'visarzo-core' ),
			)
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'item_photo',
			array(
				'label'   => esc_html__( 'Photo', 'visarzo-core' ),
				'type'    => Controls_Manager::MEDIA,
				'default' => array(
					'url' => Utils::get_placeholder_image_src(),
				),

			)
		);

		$repeater->add_control(
			'item_name',
			array(
				'label'       => esc_html__( 'Name', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
			)
		);

		$repeater->add_control(
			'item_designation',
			array(
				'label'       => esc_html__( 'Designation', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
			)
		);

		$repeater->add_control(
			'item_organization_name',
			array(
				'label'       => esc_html__( 'Organization Name', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
			)
		);

		$repeater->add_control(
			'item_rating',
			array(
				'label' => esc_html__( 'Rating', 'visarzo-core' ),
				'type'  => Controls_Manager::TEXTAREA,

			)
		);

		$repeater->add_control(
			'item_what_said',
			array(
				'label'       => esc_html__( 'What Said', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),

			)
		);

		$this->add_control(
			'items',
			array(
				'label'   => esc_html__( 'Repeater List', 'visarzo-core' ),
				'type'    => Controls_Manager::REPEATER,
				'fields'  => $repeater->get_controls(),
				'default' => array(
					array(
						'list_title'   => esc_html__( 'Title #1', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
					array(
						'list_title'   => esc_html__( 'Title #2', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
				),
			)
		);

		$this->end_controls_section();
		$this->start_controls_section(
			'style_section',
			array(
				'label' => __( 'Color', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_control(
			'underline_color',
			array(
				'label'     => __( 'Underline Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .sec-title:before' => 'background: {{VALUE}} !important',
					'{{WRAPPER}} .sec-title .dotted-box .dotted' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'rating_color',
			array(
				'label'     => __( 'Rating Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .testimonial-block-one .inner-box .content-inner .rating-box .rating li' => 'color: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'active_color',
			array(
				'label'     => __( 'Active Color', 'visarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .testimonial-section .owl-theme .owl-dots .owl-dot.active span, .testimonial-section .owl-theme .owl-dots .owl-dot span:hover' => 'background: {{VALUE}} !important',
					'{{WRAPPER}} .testimonial-style-two .owl-theme .owl-dots .owl-dot.active span, .testimonial-style-two .owl-theme .owl-dots .owl-dot span:hover' => 'background: {{VALUE}} !important',

				),
			)
		);

		$this->end_controls_section();
		$this->start_controls_section(
			'text_style_section',
			array(
				'label' => __( 'Text Style', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'content_typography',
				'label'    => __( 'Typography', 'visarzo-core' ),
				'scheme'   => Schemes\Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .testimonial',
			)
		);
		$this->end_controls_section();
	}
	protected function render() {
		$settings     = $this->get_settings_for_display();
		$layout_style = $settings['layout_style'];
		if ( $layout_style == 'style_1' || $layout_style == 'style_2' ) :
			$tagline  = $settings['tagline'];
			$title    = $settings['title'];
			$html_tag = $settings['html_tag'];
		endif;
		$extra_class = $settings['extra_class'];

		if ( $layout_style == 'style_1' ) :
			$section_class = 'testimonial-section';
			elseif ( $layout_style == 'style_2' ) :
				$section_class = 'testimonial-style-two bg-color-3';
				$shape_image   = ( $settings['shape_image']['id'] != '' ) ? wp_get_attachment_image_url( $settings['shape_image']['id'], 'full' ) : $settings['shape_image']['url'];
			endif;

			?>
		<!-- testimonial-section -->
			<?php if ( $layout_style == 'style_1' || $layout_style == 'style_2' ) : ?>
		<section class="<?php echo esc_attr( $section_class ); ?>">
				<?php
				if ( $layout_style == 'style_2' ) :
					?>
					<div class="pattern-layer" style="background-image: url(<?php echo esc_url( $shape_image ); ?>);"></div>
					<?php
					endif;
				?>

			<div class="auto-container">
				<div class="sec-title centred">
					<p><?php echo $tagline; ?></p>
					<<?php echo $html_tag; ?> class="testimonial"><?php echo $title; ?></<?php echo $html_tag; ?>>
					<div class="dotted-box">
						<span class="dotted"></span>
						<span class="dotted"></span>
						<span class="dotted"></span>
					</div>
				</div>
				<div class="two-column-carousel owl-carousel owl-theme owl-nav-none">
					<?php
					$i = 1;
					foreach ( $settings['items'] as $item ) {
						$item_photo = ( $item['item_photo']['id'] != '' ) ? wp_get_attachment_image_url( $item['item_photo']['id'], 'full' ) : $item['item_photo']['url'];
						if ( ! empty( $item_photo ) ) {
							$this->add_render_attribute( 'item_photo', 'src', $item_photo );
							$this->add_render_attribute( 'item_photo', 'alt', \Elementor\Control_Media::get_image_alt( $item['item_photo'] ) );
							$this->add_render_attribute( 'item_photo', 'title', \Elementor\Control_Media::get_image_title( $item['item_photo'] ) );
							$item_photo_html = \Elementor\Group_Control_Image_Size::get_attachment_image_html( $item, 'full', 'item_photo' );
						}
						$item_name              = $item['item_name'];
						$item_designation       = $item['item_designation'];
						$item_organization_name = $item['item_organization_name'];
						$item_rating            = $item['item_rating'];
						$item_what_said         = $item['item_what_said'];
						?>
					 <div class="testimonial-block-one">
							<div class="inner-box">
								<div class="author-inner">
									<figure class="image-box"><?php echo $item_photo_html; ?></figure>
									<h5><?php echo $item_name; ?></h5>
									<span class="designation"><?php echo $item_designation; ?></span>
								</div>
								<div class="content-inner">
									<div class="rating-box">
										<h6><?php echo $item_organization_name; ?></h6>
										<ul class="rating">
											<?php echo $item_rating; ?>
										</ul>
									</div>
									<div class="text">
										<p><?php echo $item_what_said; ?></p>
									</div>
								</div>
							</div>
						</div> <?php } ?>

				</div>
			</div>
		</section>
		<!-- testimonial-section end -->
		<?php elseif ( $layout_style == 'style_3' ) : ?>
		<section class="<?php echo esc_attr( $extra_class ); ?>">
			<div class="auto-container">
				<div class="two-column-carousel owl-carousel owl-theme owl-nav-none owl-dots-none">
				<?php
					$i = 1;
				foreach ( $settings['items'] as $item ) {
					$item_photo = ( $item['item_photo']['id'] != '' ) ? wp_get_attachment_image_url( $item['item_photo']['id'], 'full' ) : $item['item_photo']['url'];
					if ( ! empty( $item_photo ) ) {
						$this->add_render_attribute( 'item_photo', 'src', $item_photo );
						$this->add_render_attribute( 'item_photo', 'alt', \Elementor\Control_Media::get_image_alt( $item['item_photo'] ) );
						$this->add_render_attribute( 'item_photo', 'title', \Elementor\Control_Media::get_image_title( $item['item_photo'] ) );
						$item_photo_html = \Elementor\Group_Control_Image_Size::get_attachment_image_html( $item, 'full', 'item_photo' );
					}
					$item_name              = $item['item_name'];
					$item_designation       = $item['item_designation'];
					$item_organization_name = $item['item_organization_name'];
					$item_rating            = $item['item_rating'];
					$item_what_said         = $item['item_what_said'];
					?>
					<div class="testimonial-block-one">
						<div class="inner-box">
							<div class="author-inner">
								<figure class="image-box"><?php echo $item_photo_html; ?></figure>
								<h5><?php echo $item_name; ?></h5>
								<span class="designation"><?php echo $item_designation; ?></span>
							</div>
							<div class="content-inner">
								<div class="rating-box">
									<h6><?php echo $item_organization_name; ?></h6>
									<ul class="rating">
									<?php echo $item_rating; ?>
									</ul>
								</div>
								<div class="text">
									<p><?php echo $item_what_said; ?></p>
								</div>
							</div>
						</div>
					</div>
				<?php } ?>
					
				</div>
			</div>
		</section>
				<?php
			endif;
	}

	protected function content_templates() {
	}
}
