<?php
namespace Visarzo\Helper\Elementor\Widgets;

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use \Elementor\Repeater;
use Visarzo\Helper\Elementor\Settings\Header;
use Elementor\Core\Schemes;

class Visarzo_Training extends Widget_Base {


	public function get_name() {
		return 'visarzo_training';
	}

	public function get_title() {
		return esc_html__( 'Visarzo Training', 'visarzo-core' );
	}

	public function get_icon() {
		return 'fa fa-object-ungroup';
	}

	public function get_categories() {
		return array( 'visarzo' );
	}
	public function get_script_depends() {
		return array( 'training' );
	}


	protected function register_controls() {

		$this->start_controls_section(
			'general',
			array(
				'label' => esc_html__( 'General', 'visarzo-core' ),
			)
		);
		$this->add_control(
			'layout_style',
			array(
				'label'   => esc_html__( 'Layout Style', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'style_1' => esc_html__( 'Style One', 'visarzo-core' ),
					'style_2' => esc_html__( 'Style Two', 'visarzo-core' ),
					'style_3' => esc_html__( 'Style Three', 'visarzo-core' ),

				),
				'default' => 'style_1',

			)
		);

		$this->add_control(
			'tagline',
			array(
				'label'       => esc_html__( 'Tagline', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'HOW WE HELP CLIENTS', 'visarzo-core' ),
				'conditions'  => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_1',
						),
						array(
							'name'     => 'layout_style',
							'operator' => '==',
							'value'    => 'style_3',
						),

					),
				),
			)
		);

		$this->add_control(
			'title',
			array(
				'label'       => esc_html__( 'Title', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'Get The Immigration Training You Deserve', 'visarzo-core' ),
				array(
					'name'     => 'layout_style',
					'operator' => '==',
					'value'    => 'style_1',
				),
				array(
					'name'     => 'layout_style',
					'operator' => '==',
					'value'    => 'style_3',
				),
			)
		);

		$this->add_control(
			'html_tag',
			array(
				'label'   => esc_html__( 'Html Tag', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'h1'   => esc_html__( 'H1', 'visarzo-core' ),
					'h2'   => esc_html__( 'H2', 'visarzo-core' ),
					'h3'   => esc_html__( 'H3', 'visarzo-core' ),
					'h4'   => esc_html__( 'H4', 'visarzo-core' ),
					'h5'   => esc_html__( 'H5', 'visarzo-core' ),
					'h6'   => esc_html__( 'H6', 'visarzo-core' ),
					'div'  => esc_html__( 'div', 'visarzo-core' ),
					'span' => esc_html__( 'span', 'visarzo-core' ),
					'p'    => esc_html__( 'p', 'visarzo-core' ),
				),
				'default' => 'h2',
				array(
					'name'     => 'layout_style',
					'operator' => '==',
					'value'    => 'style_1',
				),
				array(
					'name'     => 'layout_style',
					'operator' => '==',
					'value'    => 'style_3',
				),

			)
		);

		$this->add_control(
			'content',
			array(
				'label'       => esc_html__( 'Content', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),
				array(
					'name'     => 'layout_style',
					'operator' => '==',
					'value'    => 'style_1',
				),
				array(
					'name'     => 'layout_style',
					'operator' => '==',
					'value'    => 'style_3',
				),

			)
		);

		$this->add_control(
			'background_image',
			array(
				'label'     => esc_html__( 'Background Image', 'visarzo-core' ),
				'type'      => Controls_Manager::MEDIA,
				'default'   => array(
					'url' => Utils::get_placeholder_image_src(),
				),
				'condition' => array( 'layout_style' => 'style_1' ),

			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'item',
			array(
				'label' => esc_html__( 'ITEM', 'visarzo-core' ),
			)
		);
		Header::visarzo_coloumn_control( $this, 6, 2 );

		$repeater = new Repeater();

		$repeater->add_control(
			'item_title',
			array(
				'label'       => esc_html__( 'Title', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
			)
		);
		$repeater->add_control(
			'item_image',
			array(
				'label'   => esc_html__( 'Image', 'visarzo-core' ),
				'type'    => Controls_Manager::MEDIA,
				'default' => array(
					'url' => Utils::get_placeholder_image_src(),
				),

			)
		);
		Header::visarzo_get_wow_animation_control( $repeater );

		$repeater->add_control(
			'item_content',
			array(
				'label'       => esc_html__( 'Content', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),

			)
		);

		$repeater->add_control(
			'item_read_button_name',
			array(
				'label'       => esc_html__( 'Read Button Name', 'visarzo-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'Read More', 'visarzo-core' ),
			)
		);

		$repeater->add_control(
			'item_page_link',
			array(
				'label'         => esc_html__( 'Page Link', 'visarzo-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => esc_html__( 'https://your-link.com', 'visarzo-core' ),
				'show_external' => true,
				'default'       => array(
					'url'         => '#',
					'is_external' => true,
					'nofollow'    => true,
				),

			)
		);

		$this->add_control(
			'items',
			array(
				'label'   => esc_html__( 'Repeater List', 'visarzo-core' ),
				'type'    => Controls_Manager::REPEATER,
				'fields'  => $repeater->get_controls(),
				'default' => array(
					array(
						'list_title'   => esc_html__( 'Title #1', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
					array(
						'list_title'   => esc_html__( 'Title #2', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
				),
			)
		);

		$this->end_controls_section();
		$this->start_controls_section(
			'style_section',
			array(
				'label' => __( 'Color', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->start_controls_tabs( 'tabs_button_style' );
		$this->start_controls_tab(
			'tab_button_normal',
			array(
				'label' => __( 'Normal', 'elementor' ),
			)
		);
		$this->add_control(
			'underline_color',
			array(
				'label'     => __( 'Underline Color', 'bisarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .sec-title:before' => 'background: {{VALUE}} !important',
					'{{WRAPPER}} .sec-title .dotted-box .dotted' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->add_control(
			'button_text_color',
			array(
				'label'     => __( 'Background Color', 'bisarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .bg-color-2' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tab_button_hover',
			array(
				'label' => __( 'Hover', 'elementor' ),
			)
		);
		$this->add_control(
			'hover_overlay_color',
			array(
				'label'     => __( 'Overlay Color', 'bisarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .training-block-one .inner-box .overlay-box:before' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		$this->start_controls_section(
			'text_style_section',
			array(
				'label' => __( 'Text Style', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'content_typography',
				'label'    => __( 'Typography', 'visarzo-core' ),
				'scheme'   => Schemes\Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .training',
			)
		);
		$this->end_controls_section();
	}
	protected function render() {
		$settings     = $this->get_settings_for_display();
		$layout_style = $settings['layout_style'];
		if ( $layout_style == 'style_1' || $layout_style == 'style_3' ) :
			$tagline  = $settings['tagline'];
			$title    = $settings['title'];
			$html_tag = $settings['html_tag'];
			$content  = $settings['content'];
		endif;
		?>
		<!-- training-section -->
		<?php
		if ( $layout_style == 'style_1' ) :
			$background_image = ( $settings['background_image']['id'] != '' ) ? wp_get_attachment_image_url( $settings['background_image']['id'], 'full' ) : $settings['background_image']['url'];
			?>
		<section class="training-section bg-color-2">
			<div class="pattern-layer" style="background-image: url(<?php echo esc_url( $background_image ); ?>);"></div>
			<div class="auto-container">
				<div class="top-inner">
					<div class="row clearfix">
						<div class="col-lg-5 col-md-12 col-sm-12 title-column">
							<div class="sec-title light">
								<p><?php echo $tagline; ?></p>
								<<?php echo $html_tag; ?> class="training"><?php echo $title; ?></<?php echo $html_tag; ?>>
								<div class="dotted-box">
									<span class="dotted"></span>
									<span class="dotted"></span>
									<span class="dotted"></span>
								</div>
							</div>
						</div>
						<div class="col-lg-7 col-md-12 col-sm-12 text-column">
							<div class="text">
								<p><?php echo $content; ?></p>
							</div>
						</div>
					</div>
				</div>
				<div class="four-item-carousel owl-carousel owl-theme owl-dots-none">
					<?php
					$i = 1;
					foreach ( $settings['items'] as $item ) {
						$item_title = $item['item_title'];
						$item_image = ( $item['item_image']['id'] != '' ) ? wp_get_attachment_image_url( $item['item_image']['id'], 'full' ) : $item['item_image']['url'];
						if ( ! empty( $item_image ) ) {
							$this->add_render_attribute( 'item_image', 'src', $item_image );
							$this->add_render_attribute( 'item_image', 'alt', \Elementor\Control_Media::get_image_alt( $item['item_image'] ) );
							$this->add_render_attribute( 'item_image', 'title', \Elementor\Control_Media::get_image_title( $item['item_image'] ) );
							$item_image_html = \Elementor\Group_Control_Image_Size::get_attachment_image_html( $item, 'full', 'item_image' );
						}
						$item_content          = $item['item_content'];
						$item_read_button_name = $item['item_read_button_name'];

						$item_page_link          = $item['item_page_link'];
						$item_page_link_target   = $item['item_page_link']['is_external'] ? ' target="_blank"' : '';
						$item_page_link_nofollow = $item['item_page_link']['nofollow'] ? ' rel="nofollow"' : '';
						?>
						<div class="training-block-one">
							<div class="inner-box">
								<div class="content-box">
									<figure class="image-box"><?php echo $item_image_html; ?></figure>
									<div class="text">
										<h4><?php echo $item_title; ?></h4>
									</div>
								</div>
								<div class="overlay-box">
									<div class="text">
										<h4><?php echo $item_title; ?></h4>
										<p><?php echo $item_content; ?></p>
										<a href="<?php echo esc_url( $item_page_link['url'] ); ?>" <?php echo $item_page_link_target . ' ' . $item_page_link_nofollow; ?>><span><?php echo $item_read_button_name; ?></span><i class="flaticon-send"></i></a>
									</div>
								</div>
							</div>
						</div> <?php } ?>

				</div>
			</div>
		</section>
		<?php elseif ( $layout_style == 'style_2' ) : ?>
			<section class="training-section sec-pad-2">
			<div class="auto-container">
				<div class="four-item-carousel owl-carousel owl-theme owl-dots-none owl-nav-none">
				<?php
					$i = 1;
				foreach ( $settings['items'] as $item ) {
					$item_title = $item['item_title'];
					$item_image = ( $item['item_image']['id'] != '' ) ? wp_get_attachment_image_url( $item['item_image']['id'], 'full' ) : $item['item_image']['url'];
					if ( ! empty( $item_image ) ) {
						$this->add_render_attribute( 'item_image', 'src', $item_image );
						$this->add_render_attribute( 'item_image', 'alt', \Elementor\Control_Media::get_image_alt( $item['item_image'] ) );
						$this->add_render_attribute( 'item_image', 'title', \Elementor\Control_Media::get_image_title( $item['item_image'] ) );
						$item_image_html = \Elementor\Group_Control_Image_Size::get_attachment_image_html( $item, 'full', 'item_image' );
					}
					$item_content          = $item['item_content'];
					$item_read_button_name = $item['item_read_button_name'];

					$item_page_link          = $item['item_page_link'];
					$item_page_link_target   = $item['item_page_link']['is_external'] ? ' target="_blank"' : '';
					$item_page_link_nofollow = $item['item_page_link']['nofollow'] ? ' rel="nofollow"' : '';
					?>
					<div class="training-block-one">
						<div class="inner-box">
							<div class="content-box">
								<figure class="image-box"><?php echo $item_image_html; ?></figure>
								<div class="text"><h4><?php echo $item_title; ?></h4></div>
							</div>
							<div class="overlay-box">
								<div class="text">
									<h4><?php echo $item_title; ?></h4>
									<p><?php echo $item_content; ?></p>
									<a href="<?php echo esc_url( $item_page_link['url'] ); ?>" <?php echo $item_page_link_target . ' ' . $item_page_link_nofollow; ?>><span><?php echo $item_read_button_name; ?></span><i class="flaticon-send"></i></a>
								</div>
							</div>
						</div>
					</div>
					<?php } ?>
					
				</div>
			</div>
		</section>
		<?php elseif ( $layout_style == 'style_3' ) : ?>
		<section class="coaching-page-section bg-color-3">
			<div class="auto-container">
				<div class="sec-title centred">
					<p><?php echo $tagline; ?></p>
					<<?php echo $html_tag; ?> class="training"><?php echo $title; ?></<?php echo $html_tag; ?>>
					<span><?php echo $content; ?></span>
					<div class="dotted-box">
						<span class="dotted"></span>
						<span class="dotted"></span>
						<span class="dotted"></span>
					</div>
				</div>
				<div class="row clearfix">
				<?php
					$i = 1;
				foreach ( $settings['items'] as $item ) {
					$item_title = $item['item_title'];
					$item_image = ( $item['item_image']['id'] != '' ) ? wp_get_attachment_image_url( $item['item_image']['id'], 'full' ) : $item['item_image']['url'];
					if ( ! empty( $item_image ) ) {
						$this->add_render_attribute( 'item_image', 'src', $item_image );
						$this->add_render_attribute( 'item_image', 'alt', \Elementor\Control_Media::get_image_alt( $item['item_image'] ) );
						$this->add_render_attribute( 'item_image', 'title', \Elementor\Control_Media::get_image_title( $item['item_image'] ) );
						$item_image_html = \Elementor\Group_Control_Image_Size::get_attachment_image_html( $item, 'full', 'item_image' );
					}
					$item_content          = $item['item_content'];
					$item_read_button_name = $item['item_read_button_name'];

					$item_page_link          = $item['item_page_link'];
					$item_page_link_target   = $item['item_page_link']['is_external'] ? ' target="_blank"' : '';
					$item_page_link_nofollow = $item['item_page_link']['nofollow'] ? ' rel="nofollow"' : '';

					$animation_class = $item['animation_class'];
					$duration_time   = $item['duration_time'];
					$delay_time      = $item['delay_time'];
					?>
					<div class="<?php echo Header::visarzo_coloumn( $this, $settings ); ?> col-md-6 col-sm-12">
						<div class="service-block-two wow <?php echo $animation_class; ?> animated animated" data-wow-delay="<?php echo $delay_time; ?>" data-wow-duration="<?php echo $duration_time; ?>">
							<div class="inner-box">
								<figure class="image-box"><a href="<?php echo esc_url( $item_page_link['url'] ); ?>" <?php echo $item_page_link_target . ' ' . $item_page_link_nofollow; ?>><?php echo $item_image_html; ?></a></figure>
								<div class="lower-content">
									<div class="box">
										<h3><a href="<?php echo esc_url( $item_page_link['url'] ); ?>" <?php echo $item_page_link_target . ' ' . $item_page_link_nofollow; ?>><?php echo $item_title; ?></a></h3>
										<p><?php echo $item_content; ?></p>
									</div>
									<div class="link"><a href="<?php echo esc_url( $item_page_link['url'] ); ?>" <?php echo $item_page_link_target . ' ' . $item_page_link_nofollow; ?>><?php echo $item_read_button_name; ?><i class="flaticon-send"></i></a></div>
								</div>
							</div>
						</div>
					</div>
				<?php } ?>
					
				</div>
			</div>
		</section>
		<?php endif; ?>
		
		<?php
	}

	protected function content_templates() {
	}
}
