<?php
namespace Visarzo\Helper\Elementor\Widgets;

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Core\Schemes;

class Visarzo_Why_Choose extends Widget_Base {


	public function get_name() {
		return 'visarzo_why_choose';
	}

	public function get_title() {
		return esc_html__( 'Visarzo Why Choose', 'visarzo-core' );
	}

	public function get_icon() {
		return 'fa fa-object-ungroup';
	}

	public function get_categories() {
		return array( 'visarzo' );
	}

	protected function register_controls() {
		$this->start_controls_section(
			'general',
			array(
				'label' => esc_html__( 'General', 'visarzo-core' ),
			)
		);

		$this->add_control(
			'tagline',
			array(
				'label'   => esc_html__( 'Tagline', 'visarzo-core' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __( 'WHY CHOOSE visarzo-core', 'visarzo-core' ),
			)
		);

		$this->add_control(
			'title',
			array(
				'label'       => esc_html__( 'Title', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'rows'        => 0,
				'default'     => __( 'Countless Benefits & Easy Processing', 'visarzo-core' ),
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),

			)
		);

		$this->add_control(
			'html_tag',
			array(
				'label'   => esc_html__( 'Html Tag', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'h1'   => esc_html__( 'H1', 'visarzo-core' ),
					'h2'   => esc_html__( 'H2', 'visarzo-core' ),
					'h3'   => esc_html__( 'H3', 'visarzo-core' ),
					'h4'   => esc_html__( 'H4', 'visarzo-core' ),
					'h5'   => esc_html__( 'H5', 'visarzo-core' ),
					'h6'   => esc_html__( 'H6', 'visarzo-core' ),
					'div'  => esc_html__( 'div', 'visarzo-core' ),
					'span' => esc_html__( 'span', 'visarzo-core' ),
					'p'    => esc_html__( 'p', 'visarzo-core' ),
				),
				'default' => 'h2',

			)
		);

		$this->add_control(
			'content',
			array(
				'label'       => esc_html__( 'Content', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),

			)
		);
		$this->add_control(
			'bg_image',
			array(
				'label'   => esc_html__( 'Background Image', 'visarzo-core' ),
				'type'    => Controls_Manager::MEDIA,
				'default' => array(
					'url' => Utils::get_placeholder_image_src(),
				),

			)
		);

		$this->add_control(
			'image',
			array(
				'label'   => esc_html__( 'Image', 'visarzo-core' ),
				'type'    => Controls_Manager::MEDIA,
				'default' => array(
					'url' => Utils::get_placeholder_image_src(),
				),

			)
		);
		$this->end_controls_section();

		$this->start_controls_section(
			'item',
			array(
				'label' => esc_html__( 'ITEM', 'visarzo-core' ),
			)
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'item_title',
			array(
				'label'   => esc_html__( 'Title', 'visarzo-core' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __( 'Legal Immigration Success', 'visarzo-core' ),
			)
		);

		$repeater->add_control(
			'item_html_tag',
			array(
				'label'   => esc_html__( 'Html Tag', 'visarzo-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'h1'   => esc_html__( 'H1', 'visarzo-core' ),
					'h2'   => esc_html__( 'H2', 'visarzo-core' ),
					'h3'   => esc_html__( 'H3', 'visarzo-core' ),
					'h4'   => esc_html__( 'H4', 'visarzo-core' ),
					'h5'   => esc_html__( 'H5', 'visarzo-core' ),
					'h6'   => esc_html__( 'H6', 'visarzo-core' ),
					'div'  => esc_html__( 'div', 'visarzo-core' ),
					'span' => esc_html__( 'span', 'visarzo-core' ),
					'p'    => esc_html__( 'p', 'visarzo-core' ),
				),
				'default' => 'h3',

			)
		);

		$repeater->add_control(
			'item_icon',
			array(
				'label' => esc_html__( 'Icon', 'visarzo-core' ),
				'type'  => Controls_Manager::ICONS,
			)
		);
		$repeater->add_control(
			'item_description',
			array(
				'label'       => esc_html__( 'Description', 'visarzo-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Type your description here', 'visarzo-core' ),

			)
		);
		$this->add_control(
			'items',
			array(
				'label'   => esc_html__( 'Repeater List', 'visarzo-core' ),
				'type'    => Controls_Manager::REPEATER,
				'fields'  => $repeater->get_controls(),
				'default' => array(
					array(
						'list_title'   => esc_html__( 'Title #1', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
					array(
						'list_title'   => esc_html__( 'Title #2', 'visarzo-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'visarzo-core' ),
					),
				),
			)
		);
		$this->end_controls_section();
		$this->start_controls_section(
			'style_section',
			array(
				'label' => __( 'Color', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->start_controls_tabs( 'tabs_button_style' );
		$this->start_controls_tab(
			'tab_button_normal',
			array(
				'label' => __( 'Normal', 'elementor' ),
			)
		);
		$this->add_control(
			'underline_color',
			array(
				'label'     => __( 'Underline Color', 'bisarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .sec-title:before' => 'background: {{VALUE}} !important',
					'{{WRAPPER}} .sec-title .dotted-box .dotted' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tab_button_hover',
			array(
				'label' => __( 'Hover', 'elementor' ),
			)
		);
		$this->add_control(
			'icon_hover_color',
			array(
				'label'     => __( 'Icon Color', 'bisarzo-core' ),
				'separator' => 'before',
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} #content_block_2 .content-box .inner-box .single-item:hover .icon-box' => 'background: {{VALUE}} !important',

				),
			)
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		$this->start_controls_section(
			'text_style_section',
			array(
				'label' => __( 'Text Style', 'visarzo-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'content_typography',
				'label'    => __( 'Typography', 'visarzo-core' ),
				'scheme'   => Schemes\Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .choose',
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'content_typography_2',
				'label'    => __( 'Repreter Typography', 'visarzo-core' ),
				'scheme'   => Schemes\Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .choose_item_heading',
			)
		);
		$this->end_controls_section();
	}
	protected function render() {
		$settings = $this->get_settings_for_display();
		$tagline  = $settings['tagline'];
		$title    = $settings['title'];
		$html_tag = $settings['html_tag'];
		$content  = $settings['content'];
		$bg_image = ( $settings['bg_image']['id'] != '' ) ? wp_get_attachment_image_url( $settings['bg_image']['id'], 'full' ) : $settings['bg_image']['url'];
		$image    = ( $settings['image']['id'] != '' ) ? wp_get_attachment_image_url( $settings['image']['id'], 'full' ) : $settings['image']['url'];
		if ( ! empty( $image ) ) {
			$this->add_render_attribute( 'image', 'src', $image );
			$this->add_render_attribute( 'image', 'alt', \Elementor\Control_Media::get_image_alt( $settings['image'] ) );
			$this->add_render_attribute( 'image', 'title', \Elementor\Control_Media::get_image_title( $settings['image'] ) );
			$image_html = \Elementor\Group_Control_Image_Size::get_attachment_image_html( $settings, 'full', 'image' );
		}
		?>
		<!-- choose-section -->
		<section class="choose-section bg-color-3">
			<div class="pattern-layer" style="background-image: url(<?php echo esc_url( $bg_image ); ?>);"></div>
			<figure class="image-layer wow slideInRight animated animated" data-wow-delay="00ms" data-wow-duration="1500ms"><?php echo $image_html; ?></figure>
			<div class="auto-container">
				<div id="content_block_2">
					<div class="content-box">
						<div class="sec-title">
							<p><?php echo $tagline; ?></p>
							<<?php echo $html_tag; ?> class="choose"><?php echo $title; ?></<?php echo $html_tag; ?>>
							<div class="dotted-box">
								<span class="dotted"></span>
								<span class="dotted"></span>
								<span class="dotted"></span>
							</div>
						</div>
						<div class="text">
							<p><?php echo $content; ?></p>
						</div>
						<div class="inner-box">
							<?php
							$i = 1;
							foreach ( $settings['items'] as $item ) {
								$item_title       = $item['item_title'];
								$item_html_tag    = $item['item_html_tag'];
								$item_icon        = $item['item_icon'];
								$item_description = $item['item_description'];
								?>
								<div class="single-item">
									<div class="icon-box"><?php \Elementor\Icons_Manager::render_icon( ( $item_icon ), array( 'aria-hidden' => 'true' ) ); ?></div>
									<<?php echo $item_html_tag; ?> class="choose_item_heading"><?php echo $item_title; ?></<?php echo $item_html_tag; ?>>
									<p><?php echo $item_description; ?></p>
								</div>
							<?php } ?>

						</div>
					</div>
				</div>
			</div>
		</section>
		<!-- choose-section end -->
		<?php
	}
	protected function content_templates() {    }
}
